# ////////////////////////////////////////////////////////////////////////////////////////////////////////////
# INSTITUTO TECNOLOGICO DE COSTA RICA
# Escuela de Ingenieria en Construccion
# Construction Engineering School
# https://www.tec.ac.cr
# Eng. MSc. Maikel Mendez Morales
# Email: maikel.mendez@gmail.com; mamendez@itcr.ac.cr
# https://orcid.org/0000-0003-1919-141X
# https://www.scopus.com/authid/detail.uri?authorId=51665581300
# https://scholar.google.com/citations?user=JnmSVFYAAAAJ&hl=en
# https://www.youtube.com/c/maikelmendez
# https://twitter.com/MaikelMendezM
# https://github.com/maikelonu
# Skype: maikel.mendez
# ////////////////////////////////////////////////////////////////////////////////////////////////////////////

#-------------------------------------------------------------------------------------------------------------------
# INFO: This script is intended for the RAW WGS84-netCDF masking, resampling, dating, reprojecting, conversion and 
# raster-stacking of (0.44 x 0.44) CORDEX data from RCA4 (HadGEM2, EARTH, MIROC, CanESM2 and MPI) to CRTM05 GeotiFF 
# at (25 x 25 km) for all climatic regions in Costa Rica. It also generates the ensemble-mean of the entire group.
#-------------------------------------------------------------------------------------------------------------------

#-------------------------------------------------------------------------------------------------------------------
# MANUSCRIPT TITLE:
# "Performance Evaluation of Bias Correction Methods for Climate Change Monthly Precipitation Projections 
# over Costa Rica"
# 
#-------------------------------------------------------------------------------------------------------------------

#-------------------------------------------------------------------------------------------------------------------
# INPUT FILES:

# ASC raster.format:
# mod_region.asc: Climatic Regions of Costa Rica

# Binary R format: 
# pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_195101-196012.nc
# pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-197012.nc
# pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc
# pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199012.nc
# pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_199101-200012.nc
# pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc
# pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_196101-197012.nc
# pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_197101-198012.nc
# pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_198101-199012.nc
# pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_199101-200012.nc
# pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_200101-200512.nc
# pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_195101-196012.nc
# pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-197012.nc
# pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc
# pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199012.nc
# pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_199101-200012.nc
# pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc
# pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_195101-196012.nc
# pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-197012.nc
# pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc
# pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199012.nc
# pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_199101-200012.nc
# pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc
# pr_CAM-44_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_195101-196012.nc
# pr_CAM-44_MOHC-HadGEM2-ES_historical_r1i1p1_ICTP-RegCM4-3_v4_mon_19810101-19901230.nc
# pr_CAM-44_MOHC-HadGEM2-ES_historical_r1i1p1_ICTP-RegCM4-3_v4_mon_19910101-20001230.nc
#-------------------------------------------------------------------------------------------------------------------

#-------------------------------------------------------------------------------------------------------------------
# MANUSCRIPT FIGURES:
# None
#-------------------------------------------------------------------------------------------------------------------

#-------------------------------------------------------------------------------------------------------------------
# OUTPUT FILES:
# pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_195101-198012.tif
# pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-199012.tif
# pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199512.tif
# pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_199101-200512.tif
# pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_196101-199012.tif
# pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_198101-199512.tif
# pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_198101-199512_NEW.tif
# pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_199101-200512.tif
# pr_CAM-44i_ICHEC-EC-EARTH_historical_r1i1p1_SMHI-RCA4_v1_mon_195101-198012.tif
# pr_CAM-44i_ICHEC-EC-EARTH_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199512.tif
# pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_195101-198012.tif
# pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-199012.tif
# pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199512.tif
# pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_199101-200512.tif
# pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_195101-198012.tif
# pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-199012.tif
# pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199512.tif
# pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199512_NEW.tif
# pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_199101-200512.tif
# pr_CAM-44_MOHC-HadGEM2-ES_historical_r1i1p1_ICTP-RegCM4-3_v4_mon_19610101-19901230.tif
# pr_hist	Median_Ensamble_mon_195101_198012.tif
# pr_hist	Median_Ensamble_mon_196101_199012.tif
# pr_hist	Median_Ensamble_mon_198101_199512.tif
# pr_hist	Median_Ensamble_mon_199101-200512.tif
# pr_MetOffice-HadGEM2-ES_historical_r1i1p1_PRECIS_mon_195101-198012.tif
# pr_MetOffice-HadGEM2-ES_historical_r1i1p1_PRECIS_mon_195101-199512.tif
# pr_MetOffice-HadGEM2-ES_historical_r1i1p1_PRECIS_mon_196101-199012.tif
# pr_MetOffice-HadGEM2-ES_historical_r1i1p1_PRECIS_mon_198101-199512.tif
#-------------------------------------------------------------------------------------------------------------------

#-------------------------------------------------------------------------------------------------------------------
# Workspace is cleared
#rm(list = ls())

# CRAN libraries are loaded
require(raster)
require(automap)
require(car)
require(compare)
require(DescTools)
require(doParallel)
require(doSNOW)
require(dplyr)
require(foreach)
require(forecast)
require(ggplot2)
require(ggthemes)
require(gstat)
require(ggradar)
require(intamap)
require(KScorrect)
require(lattice)
require(maptools)
require(MASS)
require(parallel)
require(pastecs)
require(plyr)
require(rcompanion)
require(readxl)
require(reshape)
require(reshape2)
require(rgdal)
require(rgeos)
require(snow)
require(sp)
require(scales)
require(tibble)
library(spatialEco)
library(chron)
library(lattice)
library(maps)
library(maptools)
library(RColorBrewer)
require(DescTools)
require(dplyr)
require(ggmap)
require(ggplot2)
require(ggthemes)
require(ncdf4)
require(ncdf4.helpers)
require(pastecs)
require(PCICt)
require(plyr)
require(readr)
require(reshape)
require(reshape2)
require(RNetCDF)
require(sp)
require(tidyr)
require(viridis)
require(weathermetrics)
require(hyfo)
require(lubridate)
require(psych)

# Working directory is defined
setwd("~/R_ITC/XLSX")            # UBUNTU-LINUX
setwd("C:/DATOS/R_ITC/XLSX")     # MS-WINDOWS

# /////////////////////////////////////////////////////////////////////////////////////
# BLOCK: PRECIS georeference is loaded
# /////////////////////////////////////////////////////////////////////////////////////

# The blank map is transformed into SpatialGridDataFrame
raster.precis <- read.asciigrid("mod_region.asc", as.image = FALSE)

# The map is transformed into RasterLayer
raster.precis <- raster(raster.precis)

# CRTM05 projection for CR is created
CRTM05 <- CRS("+proj=tmerc +lat_0=0 +lon_0=-84 +k=0.9999 +x_0=500000 +y_0=0 +ellps=WGS84 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs")

# CRTM05 projection is assigned to rasterbrick object
crs(raster.precis) <- CRTM05

# Object attributes are requested
# It can be seen that spa.res is different !!!!
image(raster.precis, col = topo.colors(64))

# A simple plot is requested
plot(raster.precis)

# A summery is requested
summary(raster.precis)

# A dummy raster is created
raster.precis.dummy <- raster.precis

# Dummy NA values are introduced
values(raster.precis.dummy) <- NA

# /////////////////////////////////////////////////////////////////////////////////////////////////////////////
# BLOCK: exploratory netCDF data analysis
# /////////////////////////////////////////////////////////////////////////////////////////////////////////////

#----------------------------------------------------------------------------------------------------------------------------------------
# HagGEM2-ES
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
ncin_decade01_historical_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_195101-196012.nc")
ncin_decade02_historical_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-197012.nc")
ncin_decade03_historical_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")

# 1961-1990 NetCDF files are open
ncin_decade04_historical_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-197012.nc")
ncin_decade05_historical_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")
ncin_decade06_historical_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199012.nc")

# 1971-2000 NetCDF files are open
ncin_decade07_historical_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")
ncin_decade08_historical_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199012.nc")
ncin_decade09_historical_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_199101-200012.nc")
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MIROC5
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
ncin_decade01_historical_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_195101-196012.nc")
ncin_decade02_historical_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-197012.nc")
ncin_decade03_historical_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")

# 1961-1990 NetCDF files are open
ncin_decade04_historical_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-197012.nc")
ncin_decade05_historical_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")
ncin_decade06_historical_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199012.nc")

# 1971-2000 NetCDF files are open
ncin_decade07_historical_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")
ncin_decade08_historical_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199012.nc")
ncin_decade09_historical_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_199101-200012.nc")
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# EARTH
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
ncin_decade01_historical_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_195101-196012.nc")
ncin_decade02_historical_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_196101-197012.nc")
ncin_decade03_historical_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")

# 1961-1990 NetCDF files are open
ncin_decade04_historical_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_196101-197012.nc")
ncin_decade05_historical_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")
ncin_decade06_historical_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_198101-199012.nc")

# 1971-2000 NetCDF files are open
ncin_decade07_historical_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")
ncin_decade08_historical_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_198101-199012.nc")
ncin_decade09_historical_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_199101-200012.nc")
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MPI
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
ncin_decade01_historical_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_195101-196012.nc")
ncin_decade02_historical_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-197012.nc")
ncin_decade03_historical_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")

# 1961-1990 NetCDF files are open
ncin_decade04_historical_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-197012.nc")
ncin_decade05_historical_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")
ncin_decade06_historical_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199012.nc")

# 1971-2000 NetCDF files are open
ncin_decade07_historical_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")
ncin_decade08_historical_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199012.nc")
ncin_decade09_historical_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_199101-200012.nc")
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# CanESM2
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
ncin_decade01_historical_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_195101-196012.nc")
ncin_decade02_historical_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-197012.nc")
ncin_decade03_historical_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")

# 1961-1990 NetCDF files are open
ncin_decade04_historical_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_196101-197012.nc")
ncin_decade05_historical_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")
ncin_decade06_historical_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199012.nc")

# 1971-2000 NetCDF files are open
ncin_decade07_historical_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_197101-198012.nc")
ncin_decade08_historical_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_198101-199012.nc")
ncin_decade09_historical_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_199101-200012.nc")
#----------------------------------------------------------------------------------------------------------------------------------------

# extract variable name, size and dimension
v <- ncin_decade01_historical_HadGEM2$var[[1]] # WARNING !!!!! ----> [[1]] for RCA4; [[4]] for RegCM04
size <- v$varsize
dims <- v$ndims
nt <- size[dims]          # length of time dimension
lat <- ncin_decade01_historical_HadGEM2$dim$lat$vals  # latitude position
lon <- ncin_decade01_historical_HadGEM2$dim$lon$vals  # longitude position

# Precipitation variable is isolated
#----------------------------------------------------------------------------------------------------------------------------------------
# HagGEM2-ES
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
v1_historical_HadGEM2 <- ncin_decade01_historical_HadGEM2$var[[2]]
v2_historical_HadGEM2 <- ncin_decade02_historical_HadGEM2$var[[2]]
v3_historical_HadGEM2 <- ncin_decade03_historical_HadGEM2$var[[2]]

# 1961-1990 NetCDF files are open
v4_historical_HadGEM2 <- ncin_decade04_historical_HadGEM2$var[[2]]
v5_historical_HadGEM2 <- ncin_decade05_historical_HadGEM2$var[[2]]
v6_historical_HadGEM2 <- ncin_decade06_historical_HadGEM2$var[[2]]

# # 1971-2000 NetCDF files are open
v7_historical_HadGEM2 <- ncin_decade07_historical_HadGEM2$var[[2]]
v8_historical_HadGEM2 <- ncin_decade08_historical_HadGEM2$var[[2]]
v9_historical_HadGEM2 <- ncin_decade09_historical_HadGEM2$var[[2]]
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MIROC5
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
v1_historical_MIROC5 <- ncin_decade01_historical_MIROC5$var[[2]]
v2_historical_MIROC5 <- ncin_decade02_historical_MIROC5$var[[2]]
v3_historical_MIROC5 <- ncin_decade03_historical_MIROC5$var[[2]]

# 1961-1990 NetCDF files are open
v4_historical_MIROC5 <- ncin_decade04_historical_MIROC5$var[[2]]
v5_historical_MIROC5 <- ncin_decade05_historical_MIROC5$var[[2]]
v6_historical_MIROC5 <- ncin_decade06_historical_MIROC5$var[[2]]

# # 1971-2000 NetCDF files are open
v7_historical_MIROC5 <- ncin_decade07_historical_MIROC5$var[[2]]
v8_historical_MIROC5 <- ncin_decade08_historical_MIROC5$var[[2]]
v9_historical_MIROC5 <- ncin_decade09_historical_MIROC5$var[[2]]
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# EARTH
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
v1_historical_EARTH <- ncin_decade01_historical_EARTH$var[[2]]
v2_historical_EARTH <- ncin_decade02_historical_EARTH$var[[2]]
v3_historical_EARTH <- ncin_decade03_historical_EARTH$var[[2]]

# 1961-1990 NetCDF files are open
v4_historical_EARTH <- ncin_decade04_historical_EARTH$var[[2]]
v5_historical_EARTH <- ncin_decade05_historical_EARTH$var[[2]]
v6_historical_EARTH <- ncin_decade06_historical_EARTH$var[[2]]

# # 1971-2000 NetCDF files are open
v7_historical_EARTH <- ncin_decade07_historical_EARTH$var[[2]]
v8_historical_EARTH <- ncin_decade08_historical_EARTH$var[[2]]
v9_historical_EARTH <- ncin_decade09_historical_EARTH$var[[2]]
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MPI
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
v1_historical_MPI <- ncin_decade01_historical_MPI$var[[2]]
v2_historical_MPI <- ncin_decade02_historical_MPI$var[[2]]
v3_historical_MPI <- ncin_decade03_historical_MPI$var[[2]]

# 1961-1990 NetCDF files are open
v4_historical_MPI <- ncin_decade04_historical_MPI$var[[2]]
v5_historical_MPI <- ncin_decade05_historical_MPI$var[[2]]
v6_historical_MPI <- ncin_decade06_historical_MPI$var[[2]]

# # 1971-2000 NetCDF files are open
v7_historical_MPI <- ncin_decade07_historical_MPI$var[[2]]
v8_historical_MPI <- ncin_decade08_historical_MPI$var[[2]]
v9_historical_MPI <- ncin_decade09_historical_MPI$var[[2]]
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# CanESM2
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
v1_historical_CanESM2 <- ncin_decade01_historical_CanESM2$var[[2]]
v2_historical_CanESM2 <- ncin_decade02_historical_CanESM2$var[[2]]
v3_historical_CanESM2 <- ncin_decade03_historical_CanESM2$var[[2]]

# 1961-1990 NetCDF files are open
v4_historical_CanESM2 <- ncin_decade04_historical_CanESM2$var[[2]]
v5_historical_CanESM2 <- ncin_decade05_historical_CanESM2$var[[2]]
v6_historical_CanESM2 <- ncin_decade06_historical_CanESM2$var[[2]]

# # 1971-2000 NetCDF files are open
v7_historical_CanESM2 <- ncin_decade07_historical_CanESM2$var[[2]]
v8_historical_CanESM2 <- ncin_decade08_historical_CanESM2$var[[2]]
v9_historical_CanESM2 <- ncin_decade09_historical_CanESM2$var[[2]]
#----------------------------------------------------------------------------------------------------------------------------------------

# NetCDF data is isolated
#----------------------------------------------------------------------------------------------------------------------------------------
# HagGEM2-ES
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
data.decade01_historical_HadGEM2 <- ncvar_get(ncin_decade01_historical_HadGEM2,v1_historical_HadGEM2)
data.decade02_historical_HadGEM2 <- ncvar_get(ncin_decade02_historical_HadGEM2,v2_historical_HadGEM2)
data.decade03_historical_HadGEM2 <- ncvar_get(ncin_decade03_historical_HadGEM2,v3_historical_HadGEM2)

# 1961-1990 NetCDF files are open
data.decade04_historical_HadGEM2 <- ncvar_get(ncin_decade04_historical_HadGEM2,v4_historical_HadGEM2)
data.decade05_historical_HadGEM2 <- ncvar_get(ncin_decade05_historical_HadGEM2,v5_historical_HadGEM2)
data.decade06_historical_HadGEM2 <- ncvar_get(ncin_decade06_historical_HadGEM2,v6_historical_HadGEM2)

# # 1971-2000 NetCDF files are open
data.decade07_historical_HadGEM2 <- ncvar_get(ncin_decade07_historical_HadGEM2,v7_historical_HadGEM2)
data.decade08_historical_HadGEM2 <- ncvar_get(ncin_decade08_historical_HadGEM2,v8_historical_HadGEM2)
data.decade09_historical_HadGEM2 <- ncvar_get(ncin_decade09_historical_HadGEM2,v9_historical_HadGEM2)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MIROC5
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
data.decade01_historical_MIROC5 <- ncvar_get(ncin_decade01_historical_MIROC5,v1_historical_MIROC5)
data.decade02_historical_MIROC5 <- ncvar_get(ncin_decade02_historical_MIROC5,v2_historical_MIROC5)
data.decade03_historical_MIROC5 <- ncvar_get(ncin_decade03_historical_MIROC5,v3_historical_MIROC5)

# 1961-1990 NetCDF files are open
data.decade04_historical_MIROC5 <- ncvar_get(ncin_decade04_historical_MIROC5,v4_historical_MIROC5)
data.decade05_historical_MIROC5 <- ncvar_get(ncin_decade05_historical_MIROC5,v5_historical_MIROC5)
data.decade06_historical_MIROC5 <- ncvar_get(ncin_decade06_historical_MIROC5,v6_historical_MIROC5)

# # 1971-2000 NetCDF files are open
data.decade07_historical_MIROC5 <- ncvar_get(ncin_decade07_historical_MIROC5,v7_historical_MIROC5)
data.decade08_historical_MIROC5 <- ncvar_get(ncin_decade08_historical_MIROC5,v8_historical_MIROC5)
data.decade09_historical_MIROC5 <- ncvar_get(ncin_decade09_historical_MIROC5,v9_historical_MIROC5)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# EARTH
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
data.decade01_historical_EARTH <- ncvar_get(ncin_decade01_historical_EARTH,v1_historical_EARTH)
data.decade02_historical_EARTH <- ncvar_get(ncin_decade02_historical_EARTH,v2_historical_EARTH)
data.decade03_historical_EARTH <- ncvar_get(ncin_decade03_historical_EARTH,v3_historical_EARTH)

# 1961-1990 NetCDF files are open
data.decade04_historical_EARTH <- ncvar_get(ncin_decade04_historical_EARTH,v4_historical_EARTH)
data.decade05_historical_EARTH <- ncvar_get(ncin_decade05_historical_EARTH,v5_historical_EARTH)
data.decade06_historical_EARTH <- ncvar_get(ncin_decade06_historical_EARTH,v6_historical_EARTH)

# # 1971-2000 NetCDF files are open
data.decade07_historical_EARTH <- ncvar_get(ncin_decade07_historical_EARTH,v7_historical_EARTH)
data.decade08_historical_EARTH <- ncvar_get(ncin_decade08_historical_EARTH,v8_historical_EARTH)
data.decade09_historical_EARTH <- ncvar_get(ncin_decade09_historical_EARTH,v9_historical_EARTH)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MPI
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
data.decade01_historical_MPI <- ncvar_get(ncin_decade01_historical_MPI,v1_historical_MPI)
data.decade02_historical_MPI <- ncvar_get(ncin_decade02_historical_MPI,v2_historical_MPI)
data.decade03_historical_MPI <- ncvar_get(ncin_decade03_historical_MPI,v3_historical_MPI)

# 1961-1990 NetCDF files are open
data.decade04_historical_MPI <- ncvar_get(ncin_decade04_historical_MPI,v4_historical_MPI)
data.decade05_historical_MPI <- ncvar_get(ncin_decade05_historical_MPI,v5_historical_MPI)
data.decade06_historical_MPI <- ncvar_get(ncin_decade06_historical_MPI,v6_historical_MPI)

# # 1971-2000 NetCDF files are open
data.decade07_historical_MPI <- ncvar_get(ncin_decade07_historical_MPI,v7_historical_MPI)
data.decade08_historical_MPI <- ncvar_get(ncin_decade08_historical_MPI,v8_historical_MPI)
data.decade09_historical_MPI <- ncvar_get(ncin_decade09_historical_MPI,v9_historical_MPI)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# CanESM2
#----------------------------------------------------------------------------------------------------------------------------------------

# 1951-1980 NetCDF files are open
data.decade01_historical_CanESM2 <- ncvar_get(ncin_decade01_historical_CanESM2,v1_historical_CanESM2)
data.decade02_historical_CanESM2 <- ncvar_get(ncin_decade02_historical_CanESM2,v2_historical_CanESM2)
data.decade03_historical_CanESM2 <- ncvar_get(ncin_decade03_historical_CanESM2,v3_historical_CanESM2)

# 1961-1990 NetCDF files are open
data.decade04_historical_CanESM2 <- ncvar_get(ncin_decade04_historical_CanESM2,v4_historical_CanESM2)
data.decade05_historical_CanESM2 <- ncvar_get(ncin_decade05_historical_CanESM2,v5_historical_CanESM2)
data.decade06_historical_CanESM2 <- ncvar_get(ncin_decade06_historical_CanESM2,v6_historical_CanESM2)

# # 1971-2000 NetCDF files are open
data.decade07_historical_CanESM2 <- ncvar_get(ncin_decade07_historical_CanESM2,v7_historical_CanESM2)
data.decade08_historical_CanESM2 <- ncvar_get(ncin_decade08_historical_CanESM2,v8_historical_CanESM2)
data.decade09_historical_CanESM2 <- ncvar_get(ncin_decade09_historical_CanESM2,v9_historical_CanESM2)
#----------------------------------------------------------------------------------------------------------------------------------------

# NetCDF data is transformed to rasterbrick
#----------------------------------------------------------------------------------------------------------------------------------------
# HadGEM2-ES
#----------------------------------------------------------------------------------------------------------------------------------------
# 1951-1980 NetCDF files are open
decade01_HadGEM2 <- raster::brick(data.decade01_historical_HadGEM2)
decade02_HadGEM2 <- raster::brick(data.decade02_historical_HadGEM2)
decade03_HadGEM2 <- raster::brick(data.decade03_historical_HadGEM2)

# 1961-1990 NetCDF files are open
decade04_HadGEM2 <- raster::brick(data.decade04_historical_HadGEM2)
decade05_HadGEM2 <- raster::brick(data.decade05_historical_HadGEM2)
decade06_HadGEM2 <- raster::brick(data.decade06_historical_HadGEM2)

# # 1971-2000 NetCDF files are open
decade07_HadGEM2 <- raster::brick(data.decade07_historical_HadGEM2)
decade08_HadGEM2 <- raster::brick(data.decade08_historical_HadGEM2)
decade09_HadGEM2 <- raster::brick(data.decade09_historical_HadGEM2)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MIROC5
#----------------------------------------------------------------------------------------------------------------------------------------
# 1951-1980 NetCDF files are open
decade01_MIROC5 <- raster::brick(data.decade01_historical_MIROC5)
decade02_MIROC5 <- raster::brick(data.decade02_historical_MIROC5)
decade03_MIROC5 <- raster::brick(data.decade03_historical_MIROC5)

# 1961-1990 NetCDF files are open
decade04_MIROC5 <- raster::brick(data.decade04_historical_MIROC5)
decade05_MIROC5 <- raster::brick(data.decade05_historical_MIROC5)
decade06_MIROC5 <- raster::brick(data.decade06_historical_MIROC5)

# # 1971-2000 NetCDF files are open
decade07_MIROC5 <- raster::brick(data.decade07_historical_MIROC5)
decade08_MIROC5 <- raster::brick(data.decade08_historical_MIROC5)
decade09_MIROC5 <- raster::brick(data.decade09_historical_MIROC5)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# EARTH
#----------------------------------------------------------------------------------------------------------------------------------------
# 1951-1980 NetCDF files are open
decade01_EARTH <- raster::brick(data.decade01_historical_EARTH)
decade02_EARTH <- raster::brick(data.decade02_historical_EARTH)
decade03_EARTH <- raster::brick(data.decade03_historical_EARTH)

# 1961-1990 NetCDF files are open
decade04_EARTH <- raster::brick(data.decade04_historical_EARTH)
decade05_EARTH <- raster::brick(data.decade05_historical_EARTH)
decade06_EARTH <- raster::brick(data.decade06_historical_EARTH)

# # 1971-2000 NetCDF files are open
decade07_EARTH <- raster::brick(data.decade07_historical_EARTH)
decade08_EARTH <- raster::brick(data.decade08_historical_EARTH)
decade09_EARTH <- raster::brick(data.decade09_historical_EARTH)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MPI
#----------------------------------------------------------------------------------------------------------------------------------------
# 1951-1980 NetCDF files are open
decade01_MPI <- raster::brick(data.decade01_historical_MPI)
decade02_MPI <- raster::brick(data.decade02_historical_MPI)
decade03_MPI <- raster::brick(data.decade03_historical_MPI)

# 1961-1990 NetCDF files are open
decade04_MPI <- raster::brick(data.decade04_historical_MPI)
decade05_MPI <- raster::brick(data.decade05_historical_MPI)
decade06_MPI <- raster::brick(data.decade06_historical_MPI)

# # 1971-2000 NetCDF files are open
decade07_MPI <- raster::brick(data.decade07_historical_MPI)
decade08_MPI <- raster::brick(data.decade08_historical_MPI)
decade09_MPI <- raster::brick(data.decade09_historical_MPI)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# CanESM2
#----------------------------------------------------------------------------------------------------------------------------------------
# 1951-1980 NetCDF files are open
decade01_CanESM2 <- raster::brick(data.decade01_historical_CanESM2)
decade02_CanESM2 <- raster::brick(data.decade02_historical_CanESM2)
decade03_CanESM2 <- raster::brick(data.decade03_historical_CanESM2)

# 1961-1990 NetCDF files are open
decade04_CanESM2 <- raster::brick(data.decade04_historical_CanESM2)
decade05_CanESM2 <- raster::brick(data.decade05_historical_CanESM2)
decade06_CanESM2 <- raster::brick(data.decade06_historical_CanESM2)

# # 1971-2000 NetCDF files are open
decade07_CanESM2 <- raster::brick(data.decade07_historical_CanESM2)
decade08_CanESM2 <- raster::brick(data.decade08_historical_CanESM2)
decade09_CanESM2 <- raster::brick(data.decade09_historical_CanESM2)
#----------------------------------------------------------------------------------------------------------------------------------------

# rasterbrick object is transposed to have the correct orientation
#----------------------------------------------------------------------------------------------------------------------------------------
# HadGEM2
#----------------------------------------------------------------------------------------------------------------------------------------
# 1951-1980 NetCDF files are open
decade01_HadGEM2 <- t(decade01_HadGEM2)
decade02_HadGEM2 <- t(decade02_HadGEM2)
decade03_HadGEM2 <- t(decade03_HadGEM2)

# 1961-1990 NetCDF files are open
decade04_HadGEM2 <- t(decade04_HadGEM2)
decade05_HadGEM2 <- t(decade05_HadGEM2)
decade06_HadGEM2 <- t(decade06_HadGEM2)

# # 1971-2000 NetCDF files are open
decade07_HadGEM2 <- t(decade07_HadGEM2)
decade08_HadGEM2 <- t(decade08_HadGEM2)
decade09_HadGEM2 <- t(decade09_HadGEM2)

# 1951-1980 NetCDF files are open
decade01_HadGEM2 <- flip(decade01_HadGEM2, direction = 2)
decade02_HadGEM2 <- flip(decade02_HadGEM2, direction = 2)
decade03_HadGEM2 <- flip(decade03_HadGEM2, direction = 2)

# 1961-1990 NetCDF files are open
decade04_HadGEM2 <- flip(decade04_HadGEM2, direction = 2)
decade05_HadGEM2 <- flip(decade05_HadGEM2, direction = 2)
decade06_HadGEM2 <- flip(decade06_HadGEM2, direction = 2)

# # 1971-2000 NetCDF files are open
decade07_HadGEM2 <- flip(decade07_HadGEM2, direction = 2)
decade08_HadGEM2 <- flip(decade08_HadGEM2, direction = 2)
decade09_HadGEM2 <- flip(decade09_HadGEM2, direction = 2)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MIROC5
#----------------------------------------------------------------------------------------------------------------------------------------
# 1951-1980 NetCDF files are open
decade01_MIROC5 <- t(decade01_MIROC5)
decade02_MIROC5 <- t(decade02_MIROC5)
decade03_MIROC5 <- t(decade03_MIROC5)

# 1961-1990 NetCDF files are open
decade04_MIROC5 <- t(decade04_MIROC5)
decade05_MIROC5 <- t(decade05_MIROC5)
decade06_MIROC5 <- t(decade06_MIROC5)

# # 1971-2000 NetCDF files are open
decade07_MIROC5 <- t(decade07_MIROC5)
decade08_MIROC5 <- t(decade08_MIROC5)
decade09_MIROC5 <- t(decade09_MIROC5)

# 1951-1980 NetCDF files are open
decade01_MIROC5 <- flip(decade01_MIROC5, direction = 2)
decade02_MIROC5 <- flip(decade02_MIROC5, direction = 2)
decade03_MIROC5 <- flip(decade03_MIROC5, direction = 2)

# 1961-1990 NetCDF files are open
decade04_MIROC5 <- flip(decade04_MIROC5, direction = 2)
decade05_MIROC5 <- flip(decade05_MIROC5, direction = 2)
decade06_MIROC5 <- flip(decade06_MIROC5, direction = 2)

# # 1971-2000 NetCDF files are open
decade07_MIROC5 <- flip(decade07_MIROC5, direction = 2)
decade08_MIROC5 <- flip(decade08_MIROC5, direction = 2)
decade09_MIROC5 <- flip(decade09_MIROC5, direction = 2)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# EARTH
#----------------------------------------------------------------------------------------------------------------------------------------
# 1951-1980 NetCDF files are open
decade01_EARTH <- t(decade01_EARTH)
decade02_EARTH <- t(decade02_EARTH)
decade03_EARTH <- t(decade03_EARTH)

# 1961-1990 NetCDF files are open
decade04_EARTH <- t(decade04_EARTH)
decade05_EARTH <- t(decade05_EARTH)
decade06_EARTH <- t(decade06_EARTH)

# # 1971-2000 NetCDF files are open
decade07_EARTH <- t(decade07_EARTH)
decade08_EARTH <- t(decade08_EARTH)
decade09_EARTH <- t(decade09_EARTH)

# 1951-1980 NetCDF files are open
decade01_EARTH <- flip(decade01_EARTH, direction = 2)
decade02_EARTH <- flip(decade02_EARTH, direction = 2)
decade03_EARTH <- flip(decade03_EARTH, direction = 2)

# 1961-1990 NetCDF files are open
decade04_EARTH <- flip(decade04_EARTH, direction = 2)
decade05_EARTH <- flip(decade05_EARTH, direction = 2)
decade06_EARTH <- flip(decade06_EARTH, direction = 2)

# # 1971-2000 NetCDF files are open
decade07_EARTH <- flip(decade07_EARTH, direction = 2)
decade08_EARTH <- flip(decade08_EARTH, direction = 2)
decade09_EARTH <- flip(decade09_EARTH, direction = 2)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MPI
#----------------------------------------------------------------------------------------------------------------------------------------
# 1951-1980 NetCDF files are open
decade01_MPI <- t(decade01_MPI)
decade02_MPI <- t(decade02_MPI)
decade03_MPI <- t(decade03_MPI)

# 1961-1990 NetCDF files are open
decade04_MPI <- t(decade04_MPI)
decade05_MPI <- t(decade05_MPI)
decade06_MPI <- t(decade06_MPI)

# # 1971-2000 NetCDF files are open
decade07_MPI <- t(decade07_MPI)
decade08_MPI <- t(decade08_MPI)
decade09_MPI <- t(decade09_MPI)

# 1951-1980 NetCDF files are open
decade01_MPI <- flip(decade01_MPI, direction = 2)
decade02_MPI <- flip(decade02_MPI, direction = 2)
decade03_MPI <- flip(decade03_MPI, direction = 2)

# 1961-1990 NetCDF files are open
decade04_MPI <- flip(decade04_MPI, direction = 2)
decade05_MPI <- flip(decade05_MPI, direction = 2)
decade06_MPI <- flip(decade06_MPI, direction = 2)

# # 1971-2000 NetCDF files are open
decade07_MPI <- flip(decade07_MPI, direction = 2)
decade08_MPI <- flip(decade08_MPI, direction = 2)
decade09_MPI <- flip(decade09_MPI, direction = 2)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# CanESM2
#----------------------------------------------------------------------------------------------------------------------------------------
# 1951-1980 NetCDF files are open
decade01_CanESM2 <- t(decade01_CanESM2)
decade02_CanESM2 <- t(decade02_CanESM2)
decade03_CanESM2 <- t(decade03_CanESM2)

# 1961-1990 NetCDF files are open
decade04_CanESM2 <- t(decade04_CanESM2)
decade05_CanESM2 <- t(decade05_CanESM2)
decade06_CanESM2 <- t(decade06_CanESM2)

# # 1971-2000 NetCDF files are open
decade07_CanESM2 <- t(decade07_CanESM2)
decade08_CanESM2 <- t(decade08_CanESM2)
decade09_CanESM2 <- t(decade09_CanESM2)

# 1951-1980 NetCDF files are open
decade01_CanESM2 <- flip(decade01_CanESM2, direction = 2)
decade02_CanESM2 <- flip(decade02_CanESM2, direction = 2)
decade03_CanESM2 <- flip(decade03_CanESM2, direction = 2)

# 1961-1990 NetCDF files are open
decade04_CanESM2 <- flip(decade04_CanESM2, direction = 2)
decade05_CanESM2 <- flip(decade05_CanESM2, direction = 2)
decade06_CanESM2 <- flip(decade06_CanESM2, direction = 2)

# # 1971-2000 NetCDF files are open
decade07_CanESM2 <- flip(decade07_CanESM2, direction = 2)
decade08_CanESM2 <- flip(decade08_CanESM2, direction = 2)
decade09_CanESM2 <- flip(decade09_CanESM2, direction = 2)
#----------------------------------------------------------------------------------------------------------------------------------------

# Raster object extents are defined based on Lat + Long
#----------------------------------------------------------------------------------------------------------------------------------------	
# HadGEM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
extent(decade01_HadGEM2) <- extent(c(range(lon), range(lat)))
extent(decade02_HadGEM2) <- extent(c(range(lon), range(lat)))
extent(decade03_HadGEM2) <- extent(c(range(lon), range(lat)))

# 1961-1990 NetCDF files are open	
extent(decade04_HadGEM2) <- extent(c(range(lon), range(lat)))
extent(decade05_HadGEM2) <- extent(c(range(lon), range(lat)))
extent(decade06_HadGEM2) <- extent(c(range(lon), range(lat)))

# # 1971-2000 NetCDF files are open	
extent(decade07_HadGEM2) <- extent(c(range(lon), range(lat)))
extent(decade08_HadGEM2) <- extent(c(range(lon), range(lat)))
extent(decade09_HadGEM2) <- extent(c(range(lon), range(lat)))
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MIROC5	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
extent(decade01_MIROC5) <- extent(c(range(lon), range(lat)))
extent(decade02_MIROC5) <- extent(c(range(lon), range(lat)))
extent(decade03_MIROC5) <- extent(c(range(lon), range(lat)))

# 1961-1990 NetCDF files are open	
extent(decade04_MIROC5) <- extent(c(range(lon), range(lat)))
extent(decade05_MIROC5) <- extent(c(range(lon), range(lat)))
extent(decade06_MIROC5) <- extent(c(range(lon), range(lat)))

# # 1971-2000 NetCDF files are open	
extent(decade07_MIROC5) <- extent(c(range(lon), range(lat)))
extent(decade08_MIROC5) <- extent(c(range(lon), range(lat)))
extent(decade09_MIROC5) <- extent(c(range(lon), range(lat)))
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# EARTH	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
extent(decade01_EARTH) <- extent(c(range(lon), range(lat)))
extent(decade02_EARTH) <- extent(c(range(lon), range(lat)))
extent(decade03_EARTH) <- extent(c(range(lon), range(lat)))

# 1961-1990 NetCDF files are open	
extent(decade04_EARTH) <- extent(c(range(lon), range(lat)))
extent(decade05_EARTH) <- extent(c(range(lon), range(lat)))
extent(decade06_EARTH) <- extent(c(range(lon), range(lat)))

# # 1971-2000 NetCDF files are open	
extent(decade07_EARTH) <- extent(c(range(lon), range(lat)))
extent(decade08_EARTH) <- extent(c(range(lon), range(lat)))
extent(decade09_EARTH) <- extent(c(range(lon), range(lat)))
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MPI	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
extent(decade01_MPI) <- extent(c(range(lon), range(lat)))
extent(decade02_MPI) <- extent(c(range(lon), range(lat)))
extent(decade03_MPI) <- extent(c(range(lon), range(lat)))

# 1961-1990 NetCDF files are open	
extent(decade04_MPI) <- extent(c(range(lon), range(lat)))
extent(decade05_MPI) <- extent(c(range(lon), range(lat)))
extent(decade06_MPI) <- extent(c(range(lon), range(lat)))

# # 1971-2000 NetCDF files are open	
extent(decade07_MPI) <- extent(c(range(lon), range(lat)))
extent(decade08_MPI) <- extent(c(range(lon), range(lat)))
extent(decade09_MPI) <- extent(c(range(lon), range(lat)))
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# CanESM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
extent(decade01_CanESM2) <- extent(c(range(lon), range(lat)))
extent(decade02_CanESM2) <- extent(c(range(lon), range(lat)))
extent(decade03_CanESM2) <- extent(c(range(lon), range(lat)))

# 1961-1990 NetCDF files are open	
extent(decade04_CanESM2) <- extent(c(range(lon), range(lat)))
extent(decade05_CanESM2) <- extent(c(range(lon), range(lat)))
extent(decade06_CanESM2) <- extent(c(range(lon), range(lat)))

# # 1971-2000 NetCDF files are open	
extent(decade07_CanESM2) <- extent(c(range(lon), range(lat)))
extent(decade08_CanESM2) <- extent(c(range(lon), range(lat)))
extent(decade09_CanESM2) <- extent(c(range(lon), range(lat)))
#----------------------------------------------------------------------------------------------------------------------------------------	

# WGS84 crs is defined
# Raster object extents are defined based on Lat + Long
#----------------------------------------------------------------------------------------------------------------------------------------	
# HadGEM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
proj4string(decade01_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade02_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade03_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")

# 1961-1990 NetCDF files are open	
proj4string(decade04_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade05_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade06_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")

# # 1971-2000 NetCDF files are open	
proj4string(decade07_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade08_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade09_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MIROC5	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
proj4string(decade01_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade02_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade03_MIROC5) <- CRS("+proj=longlat +datum=WGS84")

# 1961-1990 NetCDF files are open	
proj4string(decade04_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade05_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade06_MIROC5) <- CRS("+proj=longlat +datum=WGS84")

# # 1971-2000 NetCDF files are open	
proj4string(decade07_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade08_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade09_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# EARTH	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
proj4string(decade01_EARTH) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade02_EARTH) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade03_EARTH) <- CRS("+proj=longlat +datum=WGS84")

# 1961-1990 NetCDF files are open	
proj4string(decade04_EARTH) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade05_EARTH) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade06_EARTH) <- CRS("+proj=longlat +datum=WGS84")

# # 1971-2000 NetCDF files are open	
proj4string(decade07_EARTH) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade08_EARTH) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade09_EARTH) <- CRS("+proj=longlat +datum=WGS84")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MPI	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
proj4string(decade01_MPI) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade02_MPI) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade03_MPI) <- CRS("+proj=longlat +datum=WGS84")

# 1961-1990 NetCDF files are open	
proj4string(decade04_MPI) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade05_MPI) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade06_MPI) <- CRS("+proj=longlat +datum=WGS84")

# # 1971-2000 NetCDF files are open	
proj4string(decade07_MPI) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade08_MPI) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade09_MPI) <- CRS("+proj=longlat +datum=WGS84")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# CanESM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
proj4string(decade01_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade02_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade03_CanESM2) <- CRS("+proj=longlat +datum=WGS84")

# 1961-1990 NetCDF files are open	
proj4string(decade04_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade05_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade06_CanESM2) <- CRS("+proj=longlat +datum=WGS84")

# # 1971-2000 NetCDF files are open	
proj4string(decade07_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade08_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade09_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
#----------------------------------------------------------------------------------------------------------------------------------------	

# Units are transformed from [kg m-2 s-1] to mm/month
#----------------------------------------------------------------------------------------------------------------------------------------	
# HadGEM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
decade01_HadGEM2 <- decade01_HadGEM2*30*86400
decade02_HadGEM2 <- decade02_HadGEM2*30*86400
decade03_HadGEM2 <- decade03_HadGEM2*30*86400

# 1961-1990 NetCDF files are open	
decade04_HadGEM2 <- decade04_HadGEM2*30*86400
decade05_HadGEM2 <- decade05_HadGEM2*30*86400
decade06_HadGEM2 <- decade06_HadGEM2*30*86400

# # 1971-2000 NetCDF files are open	
decade07_HadGEM2 <- decade07_HadGEM2*30*86400
decade08_HadGEM2 <- decade08_HadGEM2*30*86400
decade09_HadGEM2 <- decade09_HadGEM2*30*86400
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MIROC5	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
decade01_MIROC5 <- decade01_MIROC5*30*86400
decade02_MIROC5 <- decade02_MIROC5*30*86400
decade03_MIROC5 <- decade03_MIROC5*30*86400

# 1961-1990 NetCDF files are open	
decade04_MIROC5 <- decade04_MIROC5*30*86400
decade05_MIROC5 <- decade05_MIROC5*30*86400
decade06_MIROC5 <- decade06_MIROC5*30*86400

# # 1971-2000 NetCDF files are open	
decade07_MIROC5 <- decade07_MIROC5*30*86400
decade08_MIROC5 <- decade08_MIROC5*30*86400
decade09_MIROC5 <- decade09_MIROC5*30*86400
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# EARTH	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
decade01_EARTH <- decade01_EARTH*30*86400
decade02_EARTH <- decade02_EARTH*30*86400
decade03_EARTH <- decade03_EARTH*30*86400

# 1961-1990 NetCDF files are open	
decade04_EARTH <- decade04_EARTH*30*86400
decade05_EARTH <- decade05_EARTH*30*86400
decade06_EARTH <- decade06_EARTH*30*86400

# # 1971-2000 NetCDF files are open	
decade07_EARTH <- decade07_EARTH*30*86400
decade08_EARTH <- decade08_EARTH*30*86400
decade09_EARTH <- decade09_EARTH*30*86400
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MPI	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
decade01_MPI <- decade01_MPI*30*86400
decade02_MPI <- decade02_MPI*30*86400
decade03_MPI <- decade03_MPI*30*86400

# 1961-1990 NetCDF files are open	
decade04_MPI <- decade04_MPI*30*86400
decade05_MPI <- decade05_MPI*30*86400
decade06_MPI <- decade06_MPI*30*86400

# # 1971-2000 NetCDF files are open	
decade07_MPI <- decade07_MPI*30*86400
decade08_MPI <- decade08_MPI*30*86400
decade09_MPI <- decade09_MPI*30*86400
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# CanESM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
decade01_CanESM2 <- decade01_CanESM2*30*86400
decade02_CanESM2 <- decade02_CanESM2*30*86400
decade03_CanESM2 <- decade03_CanESM2*30*86400

# 1961-1990 NetCDF files are open	
decade04_CanESM2 <- decade04_CanESM2*30*86400
decade05_CanESM2 <- decade05_CanESM2*30*86400
decade06_CanESM2 <- decade06_CanESM2*30*86400

# # 1971-2000 NetCDF files are open	
decade07_CanESM2 <- decade07_CanESM2*30*86400
decade08_CanESM2 <- decade08_CanESM2*30*86400
decade09_CanESM2 <- decade09_CanESM2*30*86400
#----------------------------------------------------------------------------------------------------------------------------------------	

# Rasterbrick object is reprojected
#----------------------------------------------------------------------------------------------------------------------------------------	
# HadGEM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
brick01_HadGEM2 <- projectRaster(decade01_HadGEM2, raster.precis.dummy, method="bilinear")
brick02_HadGEM2 <- projectRaster(decade02_HadGEM2, raster.precis.dummy, method="bilinear")
brick03_HadGEM2 <- projectRaster(decade03_HadGEM2, raster.precis.dummy, method="bilinear")

# 1961-1990 NetCDF files are open	
brick04_HadGEM2 <- projectRaster(decade04_HadGEM2, raster.precis.dummy, method="bilinear")
brick05_HadGEM2 <- projectRaster(decade05_HadGEM2, raster.precis.dummy, method="bilinear")
brick06_HadGEM2 <- projectRaster(decade06_HadGEM2, raster.precis.dummy, method="bilinear")

# # 1971-2000 NetCDF files are open	
brick07_HadGEM2 <- projectRaster(decade07_HadGEM2, raster.precis.dummy, method="bilinear")
brick08_HadGEM2 <- projectRaster(decade08_HadGEM2, raster.precis.dummy, method="bilinear")
brick09_HadGEM2 <- projectRaster(decade09_HadGEM2, raster.precis.dummy, method="bilinear")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MIROC5	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
brick01_MIROC5 <- projectRaster(decade01_MIROC5, raster.precis.dummy, method="bilinear")
brick02_MIROC5 <- projectRaster(decade02_MIROC5, raster.precis.dummy, method="bilinear")
brick03_MIROC5 <- projectRaster(decade03_MIROC5, raster.precis.dummy, method="bilinear")

# 1961-1990 NetCDF files are open	
brick04_MIROC5 <- projectRaster(decade04_MIROC5, raster.precis.dummy, method="bilinear")
brick05_MIROC5 <- projectRaster(decade05_MIROC5, raster.precis.dummy, method="bilinear")
brick06_MIROC5 <- projectRaster(decade06_MIROC5, raster.precis.dummy, method="bilinear")

# # 1971-2000 NetCDF files are open	
brick07_MIROC5 <- projectRaster(decade07_MIROC5, raster.precis.dummy, method="bilinear")
brick08_MIROC5 <- projectRaster(decade08_MIROC5, raster.precis.dummy, method="bilinear")
brick09_MIROC5 <- projectRaster(decade09_MIROC5, raster.precis.dummy, method="bilinear")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# EARTH	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
brick01_EARTH <- projectRaster(decade01_EARTH, raster.precis.dummy, method="bilinear")
brick02_EARTH <- projectRaster(decade02_EARTH, raster.precis.dummy, method="bilinear")
brick03_EARTH <- projectRaster(decade03_EARTH, raster.precis.dummy, method="bilinear")

# 1961-1990 NetCDF files are open	
brick04_EARTH <- projectRaster(decade04_EARTH, raster.precis.dummy, method="bilinear")
brick05_EARTH <- projectRaster(decade05_EARTH, raster.precis.dummy, method="bilinear")
brick06_EARTH <- projectRaster(decade06_EARTH, raster.precis.dummy, method="bilinear")

# # 1971-2000 NetCDF files are open	
brick07_EARTH <- projectRaster(decade07_EARTH, raster.precis.dummy, method="bilinear")
brick08_EARTH <- projectRaster(decade08_EARTH, raster.precis.dummy, method="bilinear")
brick09_EARTH <- projectRaster(decade09_EARTH, raster.precis.dummy, method="bilinear")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MPI	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
brick01_MPI <- projectRaster(decade01_MPI, raster.precis.dummy, method="bilinear")
brick02_MPI <- projectRaster(decade02_MPI, raster.precis.dummy, method="bilinear")
brick03_MPI <- projectRaster(decade03_MPI, raster.precis.dummy, method="bilinear")

# 1961-1990 NetCDF files are open	
brick04_MPI <- projectRaster(decade04_MPI, raster.precis.dummy, method="bilinear")
brick05_MPI <- projectRaster(decade05_MPI, raster.precis.dummy, method="bilinear")
brick06_MPI <- projectRaster(decade06_MPI, raster.precis.dummy, method="bilinear")

# # 1971-2000 NetCDF files are open	
brick07_MPI <- projectRaster(decade07_MPI, raster.precis.dummy, method="bilinear")
brick08_MPI <- projectRaster(decade08_MPI, raster.precis.dummy, method="bilinear")
brick09_MPI <- projectRaster(decade09_MPI, raster.precis.dummy, method="bilinear")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# CanESM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
brick01_CanESM2 <- projectRaster(decade01_CanESM2, raster.precis.dummy, method="bilinear")
brick02_CanESM2 <- projectRaster(decade02_CanESM2, raster.precis.dummy, method="bilinear")
brick03_CanESM2 <- projectRaster(decade03_CanESM2, raster.precis.dummy, method="bilinear")

# 1961-1990 NetCDF files are open	
brick04_CanESM2 <- projectRaster(decade04_CanESM2, raster.precis.dummy, method="bilinear")
brick05_CanESM2 <- projectRaster(decade05_CanESM2, raster.precis.dummy, method="bilinear")
brick06_CanESM2 <- projectRaster(decade06_CanESM2, raster.precis.dummy, method="bilinear")

# # 1971-2000 NetCDF files are open	
brick07_CanESM2 <- projectRaster(decade07_CanESM2, raster.precis.dummy, method="bilinear")
brick08_CanESM2 <- projectRaster(decade08_CanESM2, raster.precis.dummy, method="bilinear")
brick09_CanESM2 <- projectRaster(decade09_CanESM2, raster.precis.dummy, method="bilinear")
#----------------------------------------------------------------------------------------------------------------------------------------	

# Rasterbrick object is masked
#----------------------------------------------------------------------------------------------------------------------------------------	
# HadGEM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
brick01_HadGEM2 <- mask(brick01_HadGEM2, raster.precis)
brick02_HadGEM2 <- mask(brick02_HadGEM2, raster.precis)
brick03_HadGEM2 <- mask(brick03_HadGEM2, raster.precis)

# 1961-1990 NetCDF files are open	
brick04_HadGEM2 <- mask(brick04_HadGEM2, raster.precis)
brick05_HadGEM2 <- mask(brick05_HadGEM2, raster.precis)
brick06_HadGEM2 <- mask(brick06_HadGEM2, raster.precis)

# # 1971-2000 NetCDF files are open	
brick07_HadGEM2 <- mask(brick07_HadGEM2, raster.precis)
brick08_HadGEM2 <- mask(brick08_HadGEM2, raster.precis)
brick09_HadGEM2 <- mask(brick09_HadGEM2, raster.precis)
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MIROC5	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
brick01_MIROC5 <- mask(brick01_MIROC5, raster.precis)
brick02_MIROC5 <- mask(brick02_MIROC5, raster.precis)
brick03_MIROC5 <- mask(brick03_MIROC5, raster.precis)

# 1961-1990 NetCDF files are open	
brick04_MIROC5 <- mask(brick04_MIROC5, raster.precis)
brick05_MIROC5 <- mask(brick05_MIROC5, raster.precis)
brick06_MIROC5 <- mask(brick06_MIROC5, raster.precis)

# # 1971-2000 NetCDF files are open	
brick07_MIROC5 <- mask(brick07_MIROC5, raster.precis)
brick08_MIROC5 <- mask(brick08_MIROC5, raster.precis)
brick09_MIROC5 <- mask(brick09_MIROC5, raster.precis)
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# EARTH	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
brick01_EARTH <- mask(brick01_EARTH, raster.precis)
brick02_EARTH <- mask(brick02_EARTH, raster.precis)
brick03_EARTH <- mask(brick03_EARTH, raster.precis)

# 1961-1990 NetCDF files are open	
brick04_EARTH <- mask(brick04_EARTH, raster.precis)
brick05_EARTH <- mask(brick05_EARTH, raster.precis)
brick06_EARTH <- mask(brick06_EARTH, raster.precis)

# # 1971-2000 NetCDF files are open	
brick07_EARTH <- mask(brick07_EARTH, raster.precis)
brick08_EARTH <- mask(brick08_EARTH, raster.precis)
brick09_EARTH <- mask(brick09_EARTH, raster.precis)
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MPI	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
brick01_MPI <- mask(brick01_MPI, raster.precis)
brick02_MPI <- mask(brick02_MPI, raster.precis)
brick03_MPI <- mask(brick03_MPI, raster.precis)

# 1961-1990 NetCDF files are open	
brick04_MPI <- mask(brick04_MPI, raster.precis)
brick05_MPI <- mask(brick05_MPI, raster.precis)
brick06_MPI <- mask(brick06_MPI, raster.precis)

# # 1971-2000 NetCDF files are open	
brick07_MPI <- mask(brick07_MPI, raster.precis)
brick08_MPI <- mask(brick08_MPI, raster.precis)
brick09_MPI <- mask(brick09_MPI, raster.precis)
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# CanESM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open	
brick01_CanESM2 <- mask(brick01_CanESM2, raster.precis)
brick02_CanESM2 <- mask(brick02_CanESM2, raster.precis)
brick03_CanESM2 <- mask(brick03_CanESM2, raster.precis)

# 1961-1990 NetCDF files are open	
brick04_CanESM2 <- mask(brick04_CanESM2, raster.precis)
brick05_CanESM2 <- mask(brick05_CanESM2, raster.precis)
brick06_CanESM2 <- mask(brick06_CanESM2, raster.precis)

# # 1971-2000 NetCDF files are open	
brick07_CanESM2 <- mask(brick07_CanESM2, raster.precis)
brick08_CanESM2 <- mask(brick08_CanESM2, raster.precis)
brick09_CanESM2 <- mask(brick09_CanESM2, raster.precis)
#----------------------------------------------------------------------------------------------------------------------------------------	

# PRECIS netCDF/ GeoTIFF rcp26 Time-series are loaded
#--------------------------------------------------------------------------------------------------------------------------------------
ncin_hist_1951_1980_PRECIS <- raster::stack("pr_MetOffice-HadGEM2-ES_historical_r1i1p1_PRECIS_mon_195101-198012.tif")
ncin_hist_1961_1990_PRECIS <- raster::stack("pr_MetOffice-HadGEM2-ES_historical_r1i1p1_PRECIS_mon_196101-199012.tif")
ncin_hist_1981_1995_PRECIS <- raster::stack("pr_MetOffice-HadGEM2-ES_historical_r1i1p1_PRECIS_mon_198101-199512.tif")
#--------------------------------------------------------------------------------------------------------------------------------------

# A plot is requested for verification purposes
plot(ncin_hist_1951_1980_PRECIS[[1]])
plot(brick01_HadGEM2[[1]])
plot(brick01_MIROC5[[1]])
plot(brick01_EARTH[[1]])
plot(brick01_MPI[[1]])
plot(brick01_CanESM2[[1]])

# Rasterbrick objects are blended into a rasterstack object
#----------------------------------------------------------------------------------------------------------------------------------------	
# 1951-1980 NetCDF files are open
brick_raw_total_1951_1980_PRECIS <- stack(ncin_hist_1951_1980_PRECIS) # 360 layers
brick_raw_total_1951_1980_HadGEM2 <- stack(brick01_HadGEM2, brick02_HadGEM2, brick03_HadGEM2) # 360 layers
brick_raw_total_1951_1980_MIROC5 <- stack(brick01_MIROC5, brick02_MIROC5, brick03_MIROC5) # 360 layers
brick_raw_total_1951_1980_EARTH <- stack(brick01_EARTH, brick02_EARTH, brick03_EARTH) # 360 layers
brick_raw_total_1951_1980_MPI <- stack(brick01_MPI, brick02_MPI, brick03_MPI) # 360 layers
brick_raw_total_1951_1980_CanESM2 <- stack(brick01_CanESM2, brick02_CanESM2, brick03_CanESM2) # 360 layers
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# 1961-1990 NetCDF files are open
brick_raw_total_1961_1990_PRECIS <- stack(ncin_hist_1961_1990_PRECIS) # 360 layers
brick_raw_total_1961_1990_HadGEM2 <- stack(brick04_HadGEM2, brick05_HadGEM2, brick06_HadGEM2) # 360 layers
brick_raw_total_1961_1990_MIROC5 <- stack(brick04_MIROC5, brick05_MIROC5, brick06_MIROC5) # 360 layers
brick_raw_total_1961_1990_EARTH <- stack(brick04_EARTH, brick05_EARTH, brick06_EARTH) # 360 layers
brick_raw_total_1961_1990_MPI <- stack(brick04_MPI, brick05_MPI, brick06_MPI) # 360 layers
brick_raw_total_1961_1990_CanESM2 <- stack(brick04_CanESM2, brick05_CanESM2, brick06_CanESM2) # 360 layers
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# # 1981-1995 NetCDF files are open
brick_raw_total_1981_1995_PRECIS <- stack(ncin_hist_1981_1995_PRECIS[[1:180]]) # 180 layers
brick_raw_total_1981_1995_HadGEM2 <- stack(brick07_HadGEM2, brick08_HadGEM2[[1:60]]) # 180 layers
brick_raw_total_1981_1995_MIROC5 <- stack(brick07_MIROC5, brick08_MIROC5[[1:60]]) # 180 layers
brick_raw_total_1981_1995_EARTH <- stack(brick07_EARTH, brick08_EARTH[[1:60]]) # 180 layers
brick_raw_total_1981_1995_MPI <- stack(brick07_MPI, brick08_MPI[[1:60]]) # 180 layers
brick_raw_total_1981_1995_CanESM2 <- stack(brick07_CanESM2, brick08_CanESM2[[1:60]]) # 180 layers
#----------------------------------------------------------------------------------------------------------------------------------------	

# Historical 1961-1990 date vector is created
dates_1951_1980 <- seq(as.Date("1951-01-01"), as.Date("1980-12-31"), by = "1 month")
dates_1961_1990 <- seq(as.Date("1961-01-01"), as.Date("1990-12-31"), by = "1 month")
dates_1981_1995 <- seq(as.Date("1981-01-01"), as.Date("1995-12-31"), by = "1 month")

# Dates are -printed- into period 1951_1980
# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
brick_raw_total_1951_1980_PRECIS <- setZ(brick_raw_total_1951_1980_PRECIS, dates_1951_1980, name="time")
brick_raw_total_1951_1980_HadGEM2 <- setZ(brick_raw_total_1951_1980_HadGEM2, dates_1951_1980, name="time")
brick_raw_total_1951_1980_MIROC5 <- setZ(brick_raw_total_1951_1980_MIROC5, dates_1951_1980, name="time")
brick_raw_total_1951_1980_EARTH <- setZ(brick_raw_total_1951_1980_EARTH, dates_1951_1980, name="time")
brick_raw_total_1951_1980_MPI <- setZ(brick_raw_total_1951_1980_MPI, dates_1951_1980, name="time")
brick_raw_total_1951_1980_CanESM2 <- setZ(brick_raw_total_1951_1980_CanESM2, dates_1951_1980, name="time")

# Dates are -printed- into period 1961_1990
# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
brick_raw_total_1961_1990_PRECIS <- setZ(brick_raw_total_1961_1990_PRECIS, dates_1961_1990, name="time")
brick_raw_total_1961_1990_HadGEM2 <- setZ(brick_raw_total_1961_1990_HadGEM2, dates_1961_1990, name="time")
brick_raw_total_1961_1990_MIROC5 <- setZ(brick_raw_total_1961_1990_MIROC5, dates_1961_1990, name="time")
brick_raw_total_1961_1990_EARTH <- setZ(brick_raw_total_1961_1990_EARTH, dates_1961_1990, name="time")
brick_raw_total_1961_1990_MPI <- setZ(brick_raw_total_1961_1990_MPI, dates_1961_1990, name="time")
brick_raw_total_1961_1990_CanESM2 <- setZ(brick_raw_total_1961_1990_CanESM2, dates_1961_1990, name="time")

# Dates are -printed- into period 1981_1995
# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
brick_raw_total_1981_1995_PRECIS <- setZ(brick_raw_total_1981_1995_PRECIS, dates_1981_1995, name="time")
brick_raw_total_1981_1995_HadGEM2 <- setZ(brick_raw_total_1981_1995_HadGEM2, dates_1981_1995, name="time")
brick_raw_total_1981_1995_MIROC5 <- setZ(brick_raw_total_1981_1995_MIROC5, dates_1981_1995, name="time")
brick_raw_total_1981_1995_EARTH <- setZ(brick_raw_total_1981_1995_EARTH, dates_1981_1995, name="time")
brick_raw_total_1981_1995_MPI <- setZ(brick_raw_total_1981_1995_MPI, dates_1981_1995, name="time")
brick_raw_total_1981_1995_CanESM2 <- setZ(brick_raw_total_1981_1995_CanESM2, dates_1981_1995, name="time")

#----------------------------------------------------------------------------------------------------------------------------------------
# Overlay raster is executed for mean of the ensemble for 1951_1980 dataset
brick_raw_total_1951_1980_ENSEMBLE <- overlay(brick_raw_total_1951_1980_PRECIS,
                                              brick_raw_total_1951_1980_HadGEM2,
                                              brick_raw_total_1951_1980_MIROC5,
                                              brick_raw_total_1951_1980_EARTH,
                                              brick_raw_total_1951_1980_MPI,
                                              brick_raw_total_1951_1980_CanESM2,
                                              fun = mean)

#----------------------------------------------------------------------------------------------------------------------------------------
# Overlay raster is executed for mean of the ensemble for 1961_1990 dataset
brick_raw_total_1961_1990_ENSEMBLE <- overlay(brick_raw_total_1961_1990_PRECIS,
                                              brick_raw_total_1961_1990_HadGEM2,
                                              brick_raw_total_1961_1990_MIROC5,
                                              brick_raw_total_1961_1990_EARTH,
                                              brick_raw_total_1961_1990_MPI,
                                              brick_raw_total_1961_1990_CanESM2,
                                              fun = mean)

#----------------------------------------------------------------------------------------------------------------------------------------
# Overlay raster is executed for mean of the ensemble for 1981_1995 dataset
brick_raw_total_1981_1995_ENSEMBLE <- overlay(brick_raw_total_1981_1995_PRECIS,
                                              brick_raw_total_1981_1995_HadGEM2,
                                              brick_raw_total_1981_1995_MIROC5,
                                              brick_raw_total_1981_1995_EARTH,
                                              brick_raw_total_1981_1995_MPI,
                                              brick_raw_total_1981_1995_CanESM2,
                                              fun = mean)
# Dates are -printed- into the ensemble mean
brick_raw_total_1951_1980_ENSEMBLE <- setZ(brick_raw_total_1951_1980_ENSEMBLE, dates_1951_1980, name="time")
brick_raw_total_1961_1990_ENSEMBLE <- setZ(brick_raw_total_1961_1990_ENSEMBLE, dates_1961_1990, name="time")
brick_raw_total_1981_1995_ENSEMBLE <- setZ(brick_raw_total_1981_1995_ENSEMBLE, dates_1981_1995, name="time")

#----------------------------------------------------------------------------------------------------------------------------------------
# RasterLayer is exported to GeoTIFF format
# 1951_1980 dataset
writeRaster(brick_raw_total_1951_1980_PRECIS, "Raw_crtm05_PRECIS_1951_1980.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1951_1980_HadGEM2, "Raw_crtm05_HadGEM2_1951_1980.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1951_1980_MIROC5, "Raw_crtm05_MIROC5_1951_1980.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1951_1980_EARTH, "Raw_crtm05_EARTH_1951_1980.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1951_1980_MPI, "Raw_crtm05_MPI_1951_1980.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1951_1980_CanESM2, "Raw_crtm05_CanESM2_1951_1980.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1951_1980_ENSEMBLE, "Raw_crtm05_ENSEMBLE_1951_1980.tif", format="GTiff", overwrite=TRUE)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# RasterLayer is exported to GeoTIFF format
# 1961_1990 dataset
writeRaster(brick_raw_total_1961_1990_PRECIS, "Raw_crtm05_PRECIS_1961_1990.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1961_1990_HadGEM2, "Raw_crtm05_HadGEM2_1961_1990.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1961_1990_MIROC5, "Raw_crtm05_MIROC5_1961_1990.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1961_1990_EARTH, "Raw_crtm05_EARTH_1961_1990.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1961_1990_MPI, "Raw_crtm05_MPI_1961_1990.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1961_1990_CanESM2, "Raw_crtm05_CanESM2_1961_1990.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1961_1990_ENSEMBLE, "Raw_crtm05_ENSEMBLE_1961_1990.tif", format="GTiff", overwrite=TRUE)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# RasterLayer is exported to GeoTIFF format
# 1981_1995 dataset
writeRaster(brick_raw_total_1981_1995_PRECIS, "Raw_crtm05_PRECIS_1981_1995.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1981_1995_HadGEM2, "Raw_crtm05_HadGEM2_1981_1995.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1981_1995_MIROC5, "Raw_crtm05_MIROC5_1981_1995.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1981_1995_EARTH, "Raw_crtm05_EARTH_1981_1995.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1981_1995_MPI, "Raw_crtm05_MPI_1981_1995.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1981_1995_CanESM2, "Raw_crtm05_CanESM2_1981_1995.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_1981_1995_ENSEMBLE, "Raw_crtm05_ENSEMBLE_1981_1995.tif", format="GTiff", overwrite=TRUE)
#----------------------------------------------------------------------------------------------------------------------------------------

# /////////////////////////////////////////////////////////////////////////////////////
# BLOCK: NetCDF transformation
# /////////////////////////////////////////////////////////////////////////////////////

#------------------------------------------------------------------------------
# RasterStack object is externally exported to NetCDF
# BEWARE: This is an extremelly slow operation !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
# BEWARE: CRTM05 !!!!
#------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# RasterLayer is exported to netCDF format
# 1951_1980 dataset
writeRaster(brick_raw_total_1951_1980_PRECIS, "Raw_crtm05_PRECIS_1951_1980.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1951_1980_HadGEM2, "Raw_crtm05_HadGEM2_1951_1980.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1951_1980_MIROC5, "Raw_crtm05_MIROC5_1951_1980.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1951_1980_EARTH, "Raw_crtm05_EARTH_1951_1980.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1951_1980_MPI, "Raw_crtm05_MPI_1951_1980.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1951_1980_CanESM2, "Raw_crtm05_CanESM2_1951_1980.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1951_1980_ENSEMBLE, "Raw_crtm05_ENSEMBLE_1951_1980.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# RasterLayer is exported to netCDF format
# 1961_1990 dataset
writeRaster(brick_raw_total_1961_1990_PRECIS, "Raw_crtm05_PRECIS_1961_1990.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1961_1990_HadGEM2, "Raw_crtm05_HadGEM2_1961_1990.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1961_1990_MIROC5, "Raw_crtm05_MIROC5_1961_1990.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1961_1990_EARTH, "Raw_crtm05_EARTH_1961_1990.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1961_1990_MPI, "Raw_crtm05_MPI_1961_1990.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1961_1990_CanESM2, "Raw_crtm05_CanESM2_1961_1990.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1961_1990_ENSEMBLE, "Raw_crtm05_ENSEMBLE_1961_1990.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# RasterLayer is exported to netCDF format
# 1981_1995 dataset
writeRaster(brick_raw_total_1981_1995_PRECIS, "Raw_crtm05_PRECIS_1981_1995.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1981_1995_HadGEM2, "Raw_crtm05_HadGEM2_1981_1995.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1981_1995_MIROC5, "Raw_crtm05_MIROC5_1981_1995.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1981_1995_EARTH, "Raw_crtm05_EARTH_1981_1995.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1981_1995_MPI, "Raw_crtm05_MPI_1981_1995.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1981_1995_CanESM2, "Raw_crtm05_CanESM2_1981_1995.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_1981_1995_ENSEMBLE, "Raw_crtm05_ENSEMBLE_1981_1995.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------
# END OF CODE
#----------------------------------------------------------------------------------------------------