# ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
# INSTITUTO TECNOLOGICO DE COSTA RICA
# Escuela de Ingenieria en Construccion
# Construction Engineering School
# https://www.tec.ac.cr
# Eng. MSc. Maikel Mendez Morales
# Email: maikel.mendez@gmail.com; mamendez@itcr.ac.cr
# https://orcid.org/0000-0003-1919-141X
# https://www.scopus.com/authid/detail.uri?authorId=51665581300
# https://scholar.google.com/citations?user=JnmSVFYAAAAJ&hl=en
# https://www.youtube.com/c/maikelmendez
# https://twitter.com/MaikelMendezM
# https://github.com/maikelonu
# Skype: maikel.mendez
# ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#-----------------------------------------------------------------------------------------------------------------------------------------------------
# INFO: This script is intended for the execution of raster-based bias-corrected data by {R-Hyfo}, including empirical 
# quantile mapping (EQM), gamma quantile mapping (GQM)and linear scaling (SCALING) for the period 1981-1995 (15 years)
#-----------------------------------------------------------------------------------------------------------------------------------------------------

#-----------------------------------------------------------------------------------------------------------------------------------------------------
# MANUSCRIPT TITLE:
# "Performance Evaluation of Bias Correction Methods for Monthly Precipitation 
#  Projections over Costa Rica"
#-----------------------------------------------------------------------------------------------------------------------------------------------------

#-----------------------------------------------------------------------------------------------------------------------------------------------------
# INPUT FILES:

# netCDF format: all *.nc files included in the following lists

# 1951-1980 period **
# hist_1951_1980_IMN.nc
# hist_1951_1980_GPCC.nc
# hist_1951_1980_PRECIS.nc
# hist_1951_1980_CanESM2.nc
# hist_1951_1980_MIROC.nc
# hist_1951_1980_EARTH.nc
# hist_1951_1980_HadGEM2.nc
# hist_1951_1980_ENSAMBLE.nc

# 1981-1995 period **
# hist_1981_1995_IMN.nc
# hist_1981_1995_GPCC.nc
# hist_1981_1995_PRECIS.nc
# hist_1981_1995_CanESM2.nc
# hist_1981_1995_MIROC.nc
# hist_1981_1995_EARTH.nc
# hist_1981_1995_HadGEM2.nc
# hist_1981_1995_ENSAMBLE.nc
#-----------------------------------------------------------------------------------------------------------------------------------------------------

#-----------------------------------------------------------------------------------------------------------------------------------------------------
# MANUSCRIPT FIGURES:
# None
#-----------------------------------------------------------------------------------------------------------------------------------------------------

#-----------------------------------------------------------------------------------------------------------------------------------------------------
# OUTPUT FILES:
# Individual netCDF files as listed per month:

# EQM **
# GPCC_1981_1995_EQM_BC_JAN.nc,	GPCC_1981_1995_EQM_BC_FEB.nc,	GPCC_1981_1995_EQM_BC_MAR.nc,	GPCC_1981_1995_EQM_BC_APR.nc,	GPCC_1981_1995_EQM_BC_MAY.nc,	GPCC_1981_1995_EQM_BC_JUN.nc,	GPCC_1981_1995_EQM_BC_JUL.nc,	GPCC_1981_1995_EQM_BC_AUG.nc,	GPCC_1981_1995_EQM_BC_SEP.nc,	GPCC_1981_1995_EQM_BC_OCT.nc,	GPCC_1981_1995_EQM_BC_NOV.nc,	GPCC_1981_1995_EQM_BC_DEC.nc,
# PRECIS_1981_1995_EQM_BC_JAN.nc,	PRECIS_1981_1995_EQM_BC_FEB.nc,	PRECIS_1981_1995_EQM_BC_MAR.nc,	PRECIS_1981_1995_EQM_BC_APR.nc,	PRECIS_1981_1995_EQM_BC_MAY.nc,	PRECIS_1981_1995_EQM_BC_JUN.nc,	PRECIS_1981_1995_EQM_BC_JUL.nc,	PRECIS_1981_1995_EQM_BC_AUG.nc,	PRECIS_1981_1995_EQM_BC_SEP.nc,	PRECIS_1981_1995_EQM_BC_OCT.nc,	PRECIS_1981_1995_EQM_BC_NOV.nc,	PRECIS_1981_1995_EQM_BC_DEC.nc,
# CanESM2_1981_1995_EQM.BC_JAN.nc,	CanESM2_1981_1995_EQM.BC_FEB.nc,	CanESM2_1981_1995_EQM.BC_MAR.nc,	CanESM2_1981_1995_EQM.BC_APR.nc,	CanESM2_1981_1995_EQM.BC_MAY.nc,	CanESM2_1981_1995_EQM.BC_JUN.nc,	CanESM2_1981_1995_EQM.BC_JUL.nc,	CanESM2_1981_1995_EQM.BC_AUG.nc,	CanESM2_1981_1995_EQM.BC_SEP.nc,	CanESM2_1981_1995_EQM.BC_OCT.nc,	CanESM2_1981_1995_EQM.BC_NOV.nc,	CanESM2_1981_1995_EQM.BC_DEC.nc,
# MIROC_1981_1995_EQM_BC_JAN.nc,	MIROC_1981_1995_EQM_BC_FEB.nc,	MIROC_1981_1995_EQM_BC_MAR.nc,	MIROC_1981_1995_EQM_BC_APR.nc,	MIROC_1981_1995_EQM_BC_MAY.nc,	MIROC_1981_1995_EQM_BC_JUN.nc,	MIROC_1981_1995_EQM_BC_JUL.nc,	MIROC_1981_1995_EQM_BC_AUG.nc,	MIROC_1981_1995_EQM_BC_SEP.nc,	MIROC_1981_1995_EQM_BC_OCT.nc,	MIROC_1981_1995_EQM_BC_NOV.nc,	MIROC_1981_1995_EQM_BC_DEC.nc,
# EARTH_1981_1995_EQM_BC_JAN.nc,	EARTH_1981_1995_EQM_BC_FEB.nc,	EARTH_1981_1995_EQM_BC_MAR.nc,	EARTH_1981_1995_EQM_BC_APR.nc,	EARTH_1981_1995_EQM_BC_MAY.nc,	EARTH_1981_1995_EQM_BC_JUN.nc,	EARTH_1981_1995_EQM_BC_JUL.nc,	EARTH_1981_1995_EQM_BC_AUG.nc,	EARTH_1981_1995_EQM_BC_SEP.nc,	EARTH_1981_1995_EQM_BC_OCT.nc,	EARTH_1981_1995_EQM_BC_NOV.nc,	EARTH_1981_1995_EQM_BC_DEC.nc,
# HadGEM2_1981_1995_EQM_BC_JAN.nc,	HadGEM2_1981_1995_EQM_BC_FEB.nc,	HadGEM2_1981_1995_EQM_BC_MAR.nc,	HadGEM2_1981_1995_EQM_BC_APR.nc,	HadGEM2_1981_1995_EQM_BC_MAY.nc,	HadGEM2_1981_1995_EQM_BC_JUN.nc,	HadGEM2_1981_1995_EQM_BC_JUL.nc,	HadGEM2_1981_1995_EQM_BC_AUG.nc,	HadGEM2_1981_1995_EQM_BC_SEP.nc,	HadGEM2_1981_1995_EQM_BC_OCT.nc,	HadGEM2_1981_1995_EQM_BC_NOV.nc,	HadGEM2_1981_1995_EQM_BC_DEC.nc,
# ENSAMBLE_1981_1995_EQM_BC_JAN.nc,	ENSAMBLE_1981_1995_EQM_BC_FEB.nc,	ENSAMBLE_1981_1995_EQM_BC_MAR.nc,	ENSAMBLE_1981_1995_EQM_BC_APR.nc,	ENSAMBLE_1981_1995_EQM_BC_MAY.nc,	ENSAMBLE_1981_1995_EQM_BC_JUN.nc,	ENSAMBLE_1981_1995_EQM_BC_JUL.nc,	ENSAMBLE_1981_1995_EQM_BC_AUG.nc,	ENSAMBLE_1981_1995_EQM_BC_SEP.nc,	ENSAMBLE_1981_1995_EQM_BC_OCT.nc,	ENSAMBLE_1981_1995_EQM_BC_NOV.nc,	ENSAMBLE_1981_1995_EQM_BC_DEC.nc,

# GQM **
# GPCC_1981_1995_GQM_BC_JAN.nc,	GPCC_1981_1995_GQM_BC_FEB.nc,	GPCC_1981_1995_GQM_BC_MAR.nc,	GPCC_1981_1995_GQM_BC_APR.nc,	GPCC_1981_1995_GQM_BC_MAY.nc,	GPCC_1981_1995_GQM_BC_JUN.nc,	GPCC_1981_1995_GQM_BC_JUL.nc,	GPCC_1981_1995_GQM_BC_AUG.nc,	GPCC_1981_1995_GQM_BC_SEP.nc,	GPCC_1981_1995_GQM_BC_OCT.nc,	GPCC_1981_1995_GQM_BC_NOV.nc,	GPCC_1981_1995_GQM_BC_DEC.nc,
# PRECIS_1981_1995_GQM_BC_JAN.nc,	PRECIS_1981_1995_GQM_BC_FEB.nc,	PRECIS_1981_1995_GQM_BC_MAR.nc,	PRECIS_1981_1995_GQM_BC_APR.nc,	PRECIS_1981_1995_GQM_BC_MAY.nc,	PRECIS_1981_1995_GQM_BC_JUN.nc,	PRECIS_1981_1995_GQM_BC_JUL.nc,	PRECIS_1981_1995_GQM_BC_AUG.nc,	PRECIS_1981_1995_GQM_BC_SEP.nc,	PRECIS_1981_1995_GQM_BC_OCT.nc,	PRECIS_1981_1995_GQM_BC_NOV.nc,	PRECIS_1981_1995_GQM_BC_DEC.nc,
# CanESM2_1981_1995_GQM.BC_JAN.nc,	CanESM2_1981_1995_GQM.BC_FEB.nc,	CanESM2_1981_1995_GQM.BC_MAR.nc,	CanESM2_1981_1995_GQM.BC_APR.nc,	CanESM2_1981_1995_GQM.BC_MAY.nc,	CanESM2_1981_1995_GQM.BC_JUN.nc,	CanESM2_1981_1995_GQM.BC_JUL.nc,	CanESM2_1981_1995_GQM.BC_AUG.nc,	CanESM2_1981_1995_GQM.BC_SEP.nc,	CanESM2_1981_1995_GQM.BC_OCT.nc,	CanESM2_1981_1995_GQM.BC_NOV.nc,	CanESM2_1981_1995_GQM.BC_DEC.nc,
# MIROC_1981_1995_GQM_BC_JAN.nc,	MIROC_1981_1995_GQM_BC_FEB.nc,	MIROC_1981_1995_GQM_BC_MAR.nc,	MIROC_1981_1995_GQM_BC_APR.nc,	MIROC_1981_1995_GQM_BC_MAY.nc,	MIROC_1981_1995_GQM_BC_JUN.nc,	MIROC_1981_1995_GQM_BC_JUL.nc,	MIROC_1981_1995_GQM_BC_AUG.nc,	MIROC_1981_1995_GQM_BC_SEP.nc,	MIROC_1981_1995_GQM_BC_OCT.nc,	MIROC_1981_1995_GQM_BC_NOV.nc,	MIROC_1981_1995_GQM_BC_DEC.nc,
# EARTH_1981_1995_GQM_BC_JAN.nc,	EARTH_1981_1995_GQM_BC_FEB.nc,	EARTH_1981_1995_GQM_BC_MAR.nc,	EARTH_1981_1995_GQM_BC_APR.nc,	EARTH_1981_1995_GQM_BC_MAY.nc,	EARTH_1981_1995_GQM_BC_JUN.nc,	EARTH_1981_1995_GQM_BC_JUL.nc,	EARTH_1981_1995_GQM_BC_AUG.nc,	EARTH_1981_1995_GQM_BC_SEP.nc,	EARTH_1981_1995_GQM_BC_OCT.nc,	EARTH_1981_1995_GQM_BC_NOV.nc,	EARTH_1981_1995_GQM_BC_DEC.nc,
# HadGEM2_1981_1995_GQM_BC_JAN.nc,	HadGEM2_1981_1995_GQM_BC_FEB.nc,	HadGEM2_1981_1995_GQM_BC_MAR.nc,	HadGEM2_1981_1995_GQM_BC_APR.nc,	HadGEM2_1981_1995_GQM_BC_MAY.nc,	HadGEM2_1981_1995_GQM_BC_JUN.nc,	HadGEM2_1981_1995_GQM_BC_JUL.nc,	HadGEM2_1981_1995_GQM_BC_AUG.nc,	HadGEM2_1981_1995_GQM_BC_SEP.nc,	HadGEM2_1981_1995_GQM_BC_OCT.nc,	HadGEM2_1981_1995_GQM_BC_NOV.nc,	HadGEM2_1981_1995_GQM_BC_DEC.nc,
# ENSAMBLE_1981_1995_GQM_BC_JAN.nc,	ENSAMBLE_1981_1995_GQM_BC_FEB.nc,	ENSAMBLE_1981_1995_GQM_BC_MAR.nc,	ENSAMBLE_1981_1995_GQM_BC_APR.nc,	ENSAMBLE_1981_1995_GQM_BC_MAY.nc,	ENSAMBLE_1981_1995_GQM_BC_JUN.nc,	ENSAMBLE_1981_1995_GQM_BC_JUL.nc,	ENSAMBLE_1981_1995_GQM_BC_AUG.nc,	ENSAMBLE_1981_1995_GQM_BC_SEP.nc,	ENSAMBLE_1981_1995_GQM_BC_OCT.nc,	ENSAMBLE_1981_1995_GQM_BC_NOV.nc,	ENSAMBLE_1981_1995_GQM_BC_DEC.nc,

# SCALING **
# GPCC_1981_1995_SCALING_BC_JAN.nc,	GPCC_1981_1995_SCALING_BC_FEB.nc,	GPCC_1981_1995_SCALING_BC_MAR.nc,	GPCC_1981_1995_SCALING_BC_APR.nc,	GPCC_1981_1995_SCALING_BC_MAY.nc,	GPCC_1981_1995_SCALING_BC_JUN.nc,	GPCC_1981_1995_SCALING_BC_JUL.nc,	GPCC_1981_1995_SCALING_BC_AUG.nc,	GPCC_1981_1995_SCALING_BC_SEP.nc,	GPCC_1981_1995_SCALING_BC_OCT.nc,	GPCC_1981_1995_SCALING_BC_NOV.nc,	GPCC_1981_1995_SCALING_BC_DEC.nc,
# PRECIS_1981_1995_SCALING_BC_JAN.nc,	PRECIS_1981_1995_SCALING_BC_FEB.nc,	PRECIS_1981_1995_SCALING_BC_MAR.nc,	PRECIS_1981_1995_SCALING_BC_APR.nc,	PRECIS_1981_1995_SCALING_BC_MAY.nc,	PRECIS_1981_1995_SCALING_BC_JUN.nc,	PRECIS_1981_1995_SCALING_BC_JUL.nc,	PRECIS_1981_1995_SCALING_BC_AUG.nc,	PRECIS_1981_1995_SCALING_BC_SEP.nc,	PRECIS_1981_1995_SCALING_BC_OCT.nc,	PRECIS_1981_1995_SCALING_BC_NOV.nc,	PRECIS_1981_1995_SCALING_BC_DEC.nc,
# CanESM2_1981_1995_SCALING.BC_JAN.nc,	CanESM2_1981_1995_SCALING.BC_FEB.nc,	CanESM2_1981_1995_SCALING.BC_MAR.nc,	CanESM2_1981_1995_SCALING.BC_APR.nc,	CanESM2_1981_1995_SCALING.BC_MAY.nc,	CanESM2_1981_1995_SCALING.BC_JUN.nc,	CanESM2_1981_1995_SCALING.BC_JUL.nc,	CanESM2_1981_1995_SCALING.BC_AUG.nc,	CanESM2_1981_1995_SCALING.BC_SEP.nc,	CanESM2_1981_1995_SCALING.BC_OCT.nc,	CanESM2_1981_1995_SCALING.BC_NOV.nc,	CanESM2_1981_1995_SCALING.BC_DEC.nc,
# MIROC_1981_1995_SCALING_BC_JAN.nc,	MIROC_1981_1995_SCALING_BC_FEB.nc,	MIROC_1981_1995_SCALING_BC_MAR.nc,	MIROC_1981_1995_SCALING_BC_APR.nc,	MIROC_1981_1995_SCALING_BC_MAY.nc,	MIROC_1981_1995_SCALING_BC_JUN.nc,	MIROC_1981_1995_SCALING_BC_JUL.nc,	MIROC_1981_1995_SCALING_BC_AUG.nc,	MIROC_1981_1995_SCALING_BC_SEP.nc,	MIROC_1981_1995_SCALING_BC_OCT.nc,	MIROC_1981_1995_SCALING_BC_NOV.nc,	MIROC_1981_1995_SCALING_BC_DEC.nc,
# EARTH_1981_1995_SCALING_BC_JAN.nc,	EARTH_1981_1995_SCALING_BC_FEB.nc,	EARTH_1981_1995_SCALING_BC_MAR.nc,	EARTH_1981_1995_SCALING_BC_APR.nc,	EARTH_1981_1995_SCALING_BC_MAY.nc,	EARTH_1981_1995_SCALING_BC_JUN.nc,	EARTH_1981_1995_SCALING_BC_JUL.nc,	EARTH_1981_1995_SCALING_BC_AUG.nc,	EARTH_1981_1995_SCALING_BC_SEP.nc,	EARTH_1981_1995_SCALING_BC_OCT.nc,	EARTH_1981_1995_SCALING_BC_NOV.nc,	EARTH_1981_1995_SCALING_BC_DEC.nc,
# HadGEM2_1981_1995_SCALING_BC_JAN.nc,	HadGEM2_1981_1995_SCALING_BC_FEB.nc,	HadGEM2_1981_1995_SCALING_BC_MAR.nc,	HadGEM2_1981_1995_SCALING_BC_APR.nc,	HadGEM2_1981_1995_SCALING_BC_MAY.nc,	HadGEM2_1981_1995_SCALING_BC_JUN.nc,	HadGEM2_1981_1995_SCALING_BC_JUL.nc,	HadGEM2_1981_1995_SCALING_BC_AUG.nc,	HadGEM2_1981_1995_SCALING_BC_SEP.nc,	HadGEM2_1981_1995_SCALING_BC_OCT.nc,	HadGEM2_1981_1995_SCALING_BC_NOV.nc,	HadGEM2_1981_1995_SCALING_BC_DEC.nc,
# ENSAMBLE_1981_1995_SCALING_BC_JAN.nc,	ENSAMBLE_1981_1995_SCALING_BC_FEB.nc,	ENSAMBLE_1981_1995_SCALING_BC_MAR.nc,	ENSAMBLE_1981_1995_SCALING_BC_APR.nc,	ENSAMBLE_1981_1995_SCALING_BC_MAY.nc,	ENSAMBLE_1981_1995_SCALING_BC_JUN.nc,	ENSAMBLE_1981_1995_SCALING_BC_JUL.nc,	ENSAMBLE_1981_1995_SCALING_BC_AUG.nc,	ENSAMBLE_1981_1995_SCALING_BC_SEP.nc,	ENSAMBLE_1981_1995_SCALING_BC_OCT.nc,	ENSAMBLE_1981_1995_SCALING_BC_NOV.nc,	ENSAMBLE_1981_1995_SCALING_BC_DEC.nc,

# DUMMY RAW **
# GPCC_1981_1995_RAW_BC_JAN.nc,	GPCC_1981_1995_RAW_BC_FEB.nc,	GPCC_1981_1995_RAW_BC_MAR.nc,	GPCC_1981_1995_RAW_BC_APR.nc,	GPCC_1981_1995_RAW_BC_MAY.nc,	GPCC_1981_1995_RAW_BC_JUN.nc,	GPCC_1981_1995_RAW_BC_JUL.nc,	GPCC_1981_1995_RAW_BC_AUG.nc,	GPCC_1981_1995_RAW_BC_SEP.nc,	GPCC_1981_1995_RAW_BC_OCT.nc,	GPCC_1981_1995_RAW_BC_NOV.nc,	GPCC_1981_1995_RAW_BC_DEC.nc,
# PRECIS_1981_1995_RAW_BC_JAN.nc,	PRECIS_1981_1995_RAW_BC_FEB.nc,	PRECIS_1981_1995_RAW_BC_MAR.nc,	PRECIS_1981_1995_RAW_BC_APR.nc,	PRECIS_1981_1995_RAW_BC_MAY.nc,	PRECIS_1981_1995_RAW_BC_JUN.nc,	PRECIS_1981_1995_RAW_BC_JUL.nc,	PRECIS_1981_1995_RAW_BC_AUG.nc,	PRECIS_1981_1995_RAW_BC_SEP.nc,	PRECIS_1981_1995_RAW_BC_OCT.nc,	PRECIS_1981_1995_RAW_BC_NOV.nc,	PRECIS_1981_1995_RAW_BC_DEC.nc,
# CanESM2_1981_1995_RAW.BC_JAN.nc,	CanESM2_1981_1995_RAW.BC_FEB.nc,	CanESM2_1981_1995_RAW.BC_MAR.nc,	CanESM2_1981_1995_RAW.BC_APR.nc,	CanESM2_1981_1995_RAW.BC_MAY.nc,	CanESM2_1981_1995_RAW.BC_JUN.nc,	CanESM2_1981_1995_RAW.BC_JUL.nc,	CanESM2_1981_1995_RAW.BC_AUG.nc,	CanESM2_1981_1995_RAW.BC_SEP.nc,	CanESM2_1981_1995_RAW.BC_OCT.nc,	CanESM2_1981_1995_RAW.BC_NOV.nc,	CanESM2_1981_1995_RAW.BC_DEC.nc,
# MIROC_1981_1995_RAW_BC_JAN.nc,	MIROC_1981_1995_RAW_BC_FEB.nc,	MIROC_1981_1995_RAW_BC_MAR.nc,	MIROC_1981_1995_RAW_BC_APR.nc,	MIROC_1981_1995_RAW_BC_MAY.nc,	MIROC_1981_1995_RAW_BC_JUN.nc,	MIROC_1981_1995_RAW_BC_JUL.nc,	MIROC_1981_1995_RAW_BC_AUG.nc,	MIROC_1981_1995_RAW_BC_SEP.nc,	MIROC_1981_1995_RAW_BC_OCT.nc,	MIROC_1981_1995_RAW_BC_NOV.nc,	MIROC_1981_1995_RAW_BC_DEC.nc,
# EARTH_1981_1995_RAW_BC_JAN.nc,	EARTH_1981_1995_RAW_BC_FEB.nc,	EARTH_1981_1995_RAW_BC_MAR.nc,	EARTH_1981_1995_RAW_BC_APR.nc,	EARTH_1981_1995_RAW_BC_MAY.nc,	EARTH_1981_1995_RAW_BC_JUN.nc,	EARTH_1981_1995_RAW_BC_JUL.nc,	EARTH_1981_1995_RAW_BC_AUG.nc,	EARTH_1981_1995_RAW_BC_SEP.nc,	EARTH_1981_1995_RAW_BC_OCT.nc,	EARTH_1981_1995_RAW_BC_NOV.nc,	EARTH_1981_1995_RAW_BC_DEC.nc,
# HadGEM2_1981_1995_RAW_BC_JAN.nc,	HadGEM2_1981_1995_RAW_BC_FEB.nc,	HadGEM2_1981_1995_RAW_BC_MAR.nc,	HadGEM2_1981_1995_RAW_BC_APR.nc,	HadGEM2_1981_1995_RAW_BC_MAY.nc,	HadGEM2_1981_1995_RAW_BC_JUN.nc,	HadGEM2_1981_1995_RAW_BC_JUL.nc,	HadGEM2_1981_1995_RAW_BC_AUG.nc,	HadGEM2_1981_1995_RAW_BC_SEP.nc,	HadGEM2_1981_1995_RAW_BC_OCT.nc,	HadGEM2_1981_1995_RAW_BC_NOV.nc,	HadGEM2_1981_1995_RAW_BC_DEC.nc,
# ENSAMBLE_1981_1995_RAW_BC_JAN.nc,	ENSAMBLE_1981_1995_RAW_BC_FEB.nc,	ENSAMBLE_1981_1995_RAW_BC_MAR.nc,	ENSAMBLE_1981_1995_RAW_BC_APR.nc,	ENSAMBLE_1981_1995_RAW_BC_MAY.nc,	ENSAMBLE_1981_1995_RAW_BC_JUN.nc,	ENSAMBLE_1981_1995_RAW_BC_JUL.nc,	ENSAMBLE_1981_1995_RAW_BC_AUG.nc,	ENSAMBLE_1981_1995_RAW_BC_SEP.nc,	ENSAMBLE_1981_1995_RAW_BC_OCT.nc,	ENSAMBLE_1981_1995_RAW_BC_NOV.nc,	ENSAMBLE_1981_1995_RAW_BC_DEC.nc,
#-----------------------------------------------------------------------------------------------------------------------------------------------------

#-----------------------------------------------------------------------------------------------------------------------------------------------------
# Workspace is cleared
#rm(list = ls())

# CRAN libraries are loaded
require(raster)
require(automap)
require(car)
require(chron)
require(compare)
require(DescTools)
require(doParallel)
require(downscaleR)
require(dplyr)
require(forecast)
require(ggmap)
require(ggplot2)
require(gstat)
require(hyfo)
require(intamap)
require(KScorrect)
require(lattice)
require(maps)
require(maptools)
require(MASS)
require(ncdf4)
require(ncdf4.helpers)
require(parallel)
require(pastecs)
require(PCICt)
require(plyr)
require(RColorBrewer)
require(rcompanion)
require(readxl)
require(reshape)
require(reshape2)
require(rgdal)
require(rgeos)
require(scales)
require(snow)
require(sp)
require(spatialEco)
require(tibble)

# Working directory is defined
setwd("/mnt/BACKUP/R_ITC/XLSX")  # UBUNTU-LINUX
setwd("C:/DATOS/R_ITC/XLSX")     # MS-WINDOWS

# ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
# BLOCK: PRECIS georeference is loaded
# ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

# The blank map is transformed into SpatialGridDataFrame
raster.precis <- read.asciigrid("mod_region.asc", as.image = FALSE)

# The map is transformed into RasterLayer
raster.precis <- raster(raster.precis)

# CRTM05 projection for CR is created
CRTM05 <- CRS("+proj=tmerc +lat_0=0 +lon_0=-84 +k=0.9999 +x_0=500000 +y_0=0 +ellps=WGS84 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs")

# CRTM05 projection is assigned to rasterbrick object
crs(raster.precis) <- CRTM05

# Object attributes are requested
# It can be seen that spa.res is different !!!!
image(raster.precis, col = topo.colors(64))

# A simple plot is requested
plot(raster.precis)

# A summery is requested
summary(raster.precis)

# A dummy raster is created
raster.precis.dummy <- raster.precis

# Dummy NA values are introduced
values(raster.precis.dummy) <- NA

# ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
# BLOCK: Excution of Bias-Correction by {R-Hyfo} EQM, GQM, SCALING
# ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

V.select.month <- c("JAN", "FEB", "MAR", "APR", "MAY", "JUN", "JUL", "AUG", "SEP", "OCT", "NOV", "DEC")


for(i in 1:12) { # Main loop is initiated
  
  # Month of the year MUST be manually selected
  #i = ((12))
  
  # netCDF/ GeoTIFF 1951-1980 Time-series ared loaded
  #--------------------------------------------------------------------------------------------------------------------------------------
  ncin_hist_1951_1980_IMN <- loadNcdf(filePath="hist_1951_1980_IMN.nc", varname="Precipitation", year = 1951:1980, month = i) #c(1:12)
  ncin_hist_1951_1980_GPCC <- loadNcdf(filePath="hist_1951_1980_GPCC.nc", varname="Precipitation", year = 1951:1980, month = i) #c(1:12)
  ncin_hist_1951_1980_PRECIS <- loadNcdf(filePath="hist_1951_1980_PRECIS.nc", varname="Precipitation", year = 1951:1980, month = i) #c(1:12)
  ncin_hist_1951_1980_CanESM2 <- loadNcdf(filePath="Raw_crtm05_CanESM2_1951_1980.nc", varname="Precipitation", year = 1951:1980, month = i) #c(1:12)
  ncin_hist_1951_1980_MIROC <- loadNcdf(filePath="Raw_crtm05_MIROC5_1951_1980.nc", varname="Precipitation", year = 1951:1980, month = i) #c(1:12)
  ncin_hist_1951_1980_EARTH <- loadNcdf(filePath="Raw_crtm05_EARTH_1951_1980.nc", varname="Precipitation", year = 1951:1980, month = i) #c(1:12)
  ncin_hist_1951_1980_HadGEM2 <- loadNcdf(filePath="Raw_crtm05_HadGEM2_1951_1980.nc", varname="Precipitation", year = 1951:1980, month = i) #c(1:12)
  ncin_hist_1951_1980_MPI <- loadNcdf(filePath="Raw_crtm05_MPI_1951_1980.nc", varname="Precipitation", year = 1951:1980, month = i) #c(1:12)
  ncin_hist_1951_1980_ENSAMBLE <- loadNcdf(filePath="Raw_crtm05_ENSEMBLE_1951_1980.nc", varname="Precipitation", year = 1951:1980, month = i) #c(1:12)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # netCDF/ GeoTIFF 1981-1995 Time-series ared loaded
  #--------------------------------------------------------------------------------------------------------------------------------------
  ncin_hist_1981_1995_IMN <- loadNcdf(filePath="hist_1981_1995_IMN.nc", varname="Precipitation", year = 1981:1995, month = i) #c(1:12)
  ncin_hist_1981_1995_GPCC <- loadNcdf(filePath="hist_1981_1995_GPCC.nc", varname="Precipitation", year = 1981:1995, month = i) #c(1:12)
  ncin_hist_1981_1995_PRECIS <- loadNcdf(filePath="hist_1981_1995_PRECIS.nc", varname="Precipitation", year = 1981:1995, month = i) #c(1:12)
  ncin_hist_1981_1995_CanESM2 <- loadNcdf(filePath="Raw_crtm05_CanESM2_1981_1995.nc", varname="Precipitation", year = 1981:1995, month = i) #c(1:12)
  ncin_hist_1981_1995_MIROC <- loadNcdf(filePath="Raw_crtm05_MIROC5_1981_1995.nc", varname="Precipitation", year = 1981:1995, month = i) #c(1:12)
  ncin_hist_1981_1995_EARTH <- loadNcdf(filePath="Raw_crtm05_EARTH_1981_1995.nc", varname="Precipitation", year = 1981:1995, month = i) #c(1:12)
  ncin_hist_1981_1995_HadGEM2 <- loadNcdf(filePath="Raw_crtm05_HadGEM2_1981_1995.nc", varname="Precipitation", year = 1981:1995, month = i) #c(1:12)
  ncin_hist_1981_1995_MPI <- loadNcdf(filePath="Raw_crtm05_MPI_1981_1995.nc", varname="Precipitation", year = 1981:1995, month = i) #c(1:12)
  ncin_hist_1981_1995_ENSAMBLE <- loadNcdf(filePath="Raw_crtm05_ENSEMBLE_1981_1995.nc", varname="Precipitation", year = 1981:1995, month = i) #c(1:12)ecipitation", year = 1981:1995, month = i) #c(1:12)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # EQM biasCorrect {hyfo} is used to bias-correct the input timeseries hyfo dataset for the period 1981-1995
  #--------------------------------------------------------------------------------------------------------------------------------------
  GPCC_1981_1995.EQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_GPCC, frc = ncin_hist_1981_1995_GPCC, method = "eqm", extrapolate = "no", preci = TRUE)
  PRECIS_1981_1995.EQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_PRECIS, frc = ncin_hist_1981_1995_PRECIS, method = "eqm", extrapolate = "no", preci = TRUE)
  CanESM2_1981_1995.EQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_CanESM2, frc = ncin_hist_1981_1995_CanESM2, method = "eqm", extrapolate = "no", preci = TRUE)
  MIROC_1981_1995.EQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_MIROC, frc = ncin_hist_1981_1995_MIROC, method = "eqm", extrapolate = "no", preci = TRUE)
  EARTH_1981_1995.EQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_EARTH, frc = ncin_hist_1981_1995_EARTH, method = "eqm", extrapolate = "no", preci = TRUE)
  HadGEM2_1981_1995.EQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_HadGEM2, frc = ncin_hist_1981_1995_HadGEM2, method = "eqm", extrapolate = "no", preci = TRUE)
  MPI_1981_1995.EQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_MPI, frc = ncin_hist_1981_1995_MPI, method = "eqm", extrapolate = "no", preci = TRUE)
  ENSAMBLE_1981_1995.EQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_ENSAMBLE, frc = ncin_hist_1981_1995_ENSAMBLE, method = "eqm", extrapolate = "no", preci = TRUE)
  
  # GQM biasCorrect {hyfo} is used to bias-correct the input timeseries hyfo dataset for the period 1981-1995
  #--------------------------------------------------------------------------------------------------------------------------------------
  GPCC_1981_1995.GQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_GPCC, frc = ncin_hist_1981_1995_GPCC, method = "gqm",  extrapolate = "constant", preci = TRUE)
  PRECIS_1981_1995.GQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_PRECIS, frc = ncin_hist_1981_1995_PRECIS, method = "eqm",  extrapolate = "constant", preci = TRUE)
  CanESM2_1981_1995.GQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_CanESM2, frc = ncin_hist_1981_1995_CanESM2, method = "gqm",  extrapolate = "constant", preci = TRUE)
  MIROC_1981_1995.GQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_MIROC, frc = ncin_hist_1981_1995_MIROC, method = "gqm",  extrapolate = "constant", preci = TRUE)
  EARTH_1981_1995.GQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_EARTH, frc = ncin_hist_1981_1995_EARTH, method = "eqm",  extrapolate = "constant", preci = TRUE)
  HadGEM2_1981_1995.GQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_HadGEM2, frc = ncin_hist_1981_1995_HadGEM2, method = "gqm", extrapolate = "constant", preci = TRUE)
  MPI_1981_1995.GQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_MPI, frc = ncin_hist_1981_1995_MPI, method = "gqm", extrapolate = "constant", preci = TRUE)
  ENSAMBLE_1981_1995.GQM.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_ENSAMBLE, frc = ncin_hist_1981_1995_ENSAMBLE, method = "eqm",  extrapolate = "constant", preci = TRUE)
  
  # SCALING biasCorrect {hyfo} is used to bias-correct the input timeseries hyfo dataset for the period 1981-1995
  #--------------------------------------------------------------------------------------------------------------------------------------
  GPCC_1981_1995.SCALING.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_GPCC, frc = ncin_hist_1981_1995_GPCC, method = "scaling", extrapolate = "constant", preci = TRUE)
  PRECIS_1981_1995.SCALING.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_PRECIS, frc = ncin_hist_1981_1995_PRECIS, method = "scaling", extrapolate = "constant", preci = TRUE)
  CanESM2_1981_1995.SCALING.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_CanESM2, frc = ncin_hist_1981_1995_CanESM2, method = "scaling", extrapolate = "constant", preci = TRUE)
  MIROC_1981_1995.SCALING.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_MIROC, frc = ncin_hist_1981_1995_MIROC, method = "scaling", extrapolate = "constant", preci = TRUE)
  EARTH_1981_1995.SCALING.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_EARTH, frc = ncin_hist_1981_1995_EARTH, method = "scaling", extrapolate = "constant", preci = TRUE)
  HadGEM2_1981_1995.SCALING.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_HadGEM2, frc = ncin_hist_1981_1995_HadGEM2, method = "scaling", extrapolate = "constant", preci = TRUE)
  MPI_1981_1995.SCALING.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_MPI, frc = ncin_hist_1981_1995_MPI, method = "scaling", extrapolate = "constant", preci = TRUE)
  ENSAMBLE_1981_1995.SCALING.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_ENSAMBLE, frc = ncin_hist_1981_1995_ENSAMBLE, method = "scaling", extrapolate = "constant", preci = TRUE)
  
  # DUMMY-RAW biasCorrect {hyfo} is used to bias-correct the input timeseries hyfo dataset for the period 1981-1995
  #--------------------------------------------------------------------------------------------------------------------------------------
  GPCC_1981_1995.RAW.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_GPCC, frc = ncin_hist_1981_1995_GPCC, method = "gpqm", extrapolate = "constant", preci = TRUE)
  PRECIS_1981_1995.RAW.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_PRECIS, frc = ncin_hist_1981_1995_PRECIS, method = "gpqm", extrapolate = "constant", preci = TRUE)
  CanESM2_1981_1995.RAW.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_CanESM2, frc = ncin_hist_1981_1995_CanESM2, method = "gpqm", extrapolate = "constant", preci = TRUE)
  MIROC_1981_1995.RAW.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_MIROC, frc = ncin_hist_1981_1995_MIROC, method = "gpqm", extrapolate = "constant", preci = TRUE)
  EARTH_1981_1995.RAW.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_EARTH, frc = ncin_hist_1981_1995_EARTH, method = "gpqm", extrapolate = "constant", preci = TRUE)
  HadGEM2_1981_1995.RAW.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_HadGEM2, frc = ncin_hist_1981_1995_HadGEM2, method = "gpqm", extrapolate = "constant", preci = TRUE)
  MPI_1981_1995.RAW.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_MPI, frc = ncin_hist_1981_1995_MPI, method = "gpqm", extrapolate = "constant", preci = TRUE)
  ENSAMBLE_1981_1995.RAW.BC <- biasCorrect(obs = ncin_hist_1951_1980_IMN, hindcast = ncin_hist_1951_1980_ENSAMBLE, frc = ncin_hist_1981_1995_ENSAMBLE, method = "gpqm", extrapolate = "constant", preci = TRUE)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # EQM writeNcdf {hyfo} is used write raster objects to netCDF files for the period 1981-1995
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeNcdf(gridData=GPCC_1981_1995.EQM.BC,filePath=paste0("GPCC_1981_1995_EQM_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=PRECIS_1981_1995.EQM.BC,filePath=paste0("PRECIS_1981_1995_EQM_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=CanESM2_1981_1995.EQM.BC,filePath=paste0("CanESM2_1981_1995_EQM.BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=MIROC_1981_1995.EQM.BC,filePath=paste0("MIROC_1981_1995_EQM_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=EARTH_1981_1995.EQM.BC,filePath=paste0("EARTH_1981_1995_EQM_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=HadGEM2_1981_1995.EQM.BC,filePath=paste0("HadGEM2_1981_1995_EQM_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=MPI_1981_1995.EQM.BC,filePath=paste0("MPI_1981_1995_EQM_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=ENSAMBLE_1981_1995.EQM.BC,filePath=paste0("ENSAMBLE_1981_1995_EQM_BC_",V.select.month[i],".nc"))
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # GQM writeNcdf {hyfo} is used write raster objects to netCDF files for the period 1981-1995
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeNcdf(gridData=GPCC_1981_1995.GQM.BC,filePath=paste0("GPCC_1981_1995_GQM_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=PRECIS_1981_1995.GQM.BC,filePath=paste0("PRECIS_1981_1995_GQM_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=CanESM2_1981_1995.GQM.BC,filePath=paste0("CanESM2_1981_1995_GQM.BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=MIROC_1981_1995.GQM.BC,filePath=paste0("MIROC_1981_1995_GQM_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=EARTH_1981_1995.GQM.BC,filePath=paste0("EARTH_1981_1995_GQM_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=HadGEM2_1981_1995.GQM.BC,filePath=paste0("HadGEM2_1981_1995_GQM_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=MPI_1981_1995.GQM.BC,filePath=paste0("MPI_1981_1995_GQM_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=ENSAMBLE_1981_1995.GQM.BC,filePath=paste0("ENSAMBLE_1981_1995_GQM_BC_",V.select.month[i],".nc"))
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # SCALING writeNcdf {hyfo} is used write raster objects to netCDF files for the period 1981-1995
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeNcdf(gridData=GPCC_1981_1995.SCALING.BC,filePath=paste0("GPCC_1981_1995_SCALING_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=PRECIS_1981_1995.SCALING.BC,filePath=paste0("PRECIS_1981_1995_SCALING_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=CanESM2_1981_1995.SCALING.BC,filePath=paste0("CanESM2_1981_1995_SCALING.BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=MIROC_1981_1995.SCALING.BC,filePath=paste0("MIROC_1981_1995_SCALING_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=EARTH_1981_1995.SCALING.BC,filePath=paste0("EARTH_1981_1995_SCALING_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=HadGEM2_1981_1995.SCALING.BC,filePath=paste0("HadGEM2_1981_1995_SCALING_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=MPI_1981_1995.SCALING.BC,filePath=paste0("MPI_1981_1995_SCALING_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=ENSAMBLE_1981_1995.SCALING.BC,filePath=paste0("ENSAMBLE_1981_1995_SCALING_BC_",V.select.month[i],".nc"))
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # DUMMY-RAW writeNcdf {hyfo} is used write raster objects to netCDF files for the period 1981-1995
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeNcdf(gridData=GPCC_1981_1995.RAW.BC,filePath=paste0("GPCC_1981_1995_RAW_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=PRECIS_1981_1995.RAW.BC,filePath=paste0("PRECIS_1981_1995_RAW_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=CanESM2_1981_1995.RAW.BC,filePath=paste0("CanESM2_1981_1995_RAW.BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=MIROC_1981_1995.RAW.BC,filePath=paste0("MIROC_1981_1995_RAW_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=EARTH_1981_1995.RAW.BC,filePath=paste0("EARTH_1981_1995_RAW_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=HadGEM2_1981_1995.RAW.BC,filePath=paste0("HadGEM2_1981_1995_RAW_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=MPI_1981_1995.RAW.BC,filePath=paste0("MPI_1981_1995_RAW_BC_",V.select.month[i],".nc"))
  writeNcdf(gridData=ENSAMBLE_1981_1995.RAW.BC,filePath=paste0("ENSAMBLE_1981_1995_RAW_BC_",V.select.month[i],".nc"))
  #--------------------------------------------------------------------------------------------------------------------------------------
  
} # Main loop is closed

#----------------------------------------------------------------------------------------------------
# END OF CODE
#----------------------------------------------------------------------------------------------------