# ////////////////////////////////////////////////////////////////////////////////////////////////////////////
# INSTITUTO TECNOLOGICO DE COSTA RICA
# Escuela de Ingenieria en Construccion
# Construction Engineering School
# https://www.tec.ac.cr
# Eng. MSc. Maikel Mendez Morales
# Email: maikel.mendez@gmail.com; mamendez@itcr.ac.cr
# https://orcid.org/0000-0003-1919-141X
# https://www.scopus.com/authid/detail.uri?authorId=51665581300
# https://scholar.google.com/citations?user=JnmSVFYAAAAJ&hl=en
# https://www.youtube.com/c/maikelmendez
# https://twitter.com/MaikelMendezM
# https://github.com/maikelonu
# Skype: maikel.mendez
# ////////////////////////////////////////////////////////////////////////////////////////////////////////////

#-------------------------------------------------------------------------------------------------------------------
# INFO: This script is intended for the generation 
#-------------------------------------------------------------------------------------------------------------------

#-------------------------------------------------------------------------------------------------------------------
# MANUSCRIPT TITLE:
# "Performance Evaluation of Bias Correction Methods for Monthly Precipitation 
#  Projections over Costa Rica"
#-------------------------------------------------------------------------------------------------------------------

#-------------------------------------------------------------------------------------------------------------------
# INPUT FILES:

# Binary R format: 
# None

# TXT-ASCII format:
# None
#-------------------------------------------------------------------------------------------------------------------

#-------------------------------------------------------------------------------------------------------------------
# MANUSCRIPT FIGURES:
# None
#-------------------------------------------------------------------------------------------------------------------

#-------------------------------------------------------------------------------------------------------------------
# OUTPUT FILES:
# None
#-------------------------------------------------------------------------------------------------------------------

#-------------------------------------------------------------------------------------------------------------------
# Workspace is cleared
#rm(list = ls())

# CRAN libraries are loaded
require(raster)
require(automap)
require(car)
require(compare)
require(DescTools)
require(doParallel)
require(doSNOW)
require(dplyr)
require(foreach)
require(forecast)
require(ggplot2)
require(ggthemes)
require(gstat)
require(ggradar)
require(intamap)
require(KScorrect)
require(lattice)
require(maptools)
require(MASS)
require(parallel)
require(pastecs)
require(plyr)
require(rcompanion)
require(readxl)
require(reshape)
require(reshape2)
require(rgdal)
require(rgeos)
require(snow)
require(sp)
require(scales)
require(tibble)
library(spatialEco)
library(chron)
library(lattice)
library(maps)
library(maptools)
library(RColorBrewer)
require(DescTools)
require(dplyr)
require(ggmap)
require(ggplot2)
require(ggthemes)
require(ncdf4)
require(ncdf4.helpers)
require(pastecs)
require(PCICt)
require(plyr)
require(readr)
require(reshape)
require(reshape2)
require(RNetCDF)
require(sp)
require(tidyr)
require(viridis)
require(weathermetrics)
require(hyfo)
require(lubridate)
require(psych)
require(raster)
require(automap)
require(car)
require(chron)
require(compare)
require(DescTools)
require(doParallel)
require(downscaleR)
require(dplyr)
require(forecast)
require(ggmap)
require(ggplot2)
require(gstat)
require(hyfo)
require(intamap)
require(KScorrect)
require(lattice)
require(loadeR)
require(loadeR.2nc)
require(loadeR.java)
require(maps)
require(maptools)
require(MASS)
require(ncdf4)
require(ncdf4.helpers)
require(parallel)
require(pastecs)
require(PCICt)
require(plyr)
require(RColorBrewer)
require(rcompanion)
require(readxl)
require(reshape)
require(reshape2)
require(rgdal)
require(rgeos)
require(scales)
require(snow)
require(sp)
require(spatialEco)
require(tibble)
require(transformeR)

# Working directory is defined
setwd("~/R_ITC/XLSX/FUTURE_ENSEMBLE")            # UBUNTU-LINUX
setwd("C:/DATOS/R_ITC/XLSX/FUTURE_ENSEMBLE")     # MS-WINDOWS

# /////////////////////////////////////////////////////////////////////////////////////
# BLOCK: PRECIS georeference is loaded
# /////////////////////////////////////////////////////////////////////////////////////

# The blank map is transformed into SpatialGridDataFrame
raster.precis <- read.asciigrid("mod_region.asc", as.image = FALSE)

# The map is transformed into RasterLayer
raster.precis <- raster(raster.precis)

# CRTM05 projection for CR is created
CRTM05 <- CRS("+proj=tmerc +lat_0=0 +lon_0=-84 +k=0.9999 +x_0=500000 +y_0=0 +ellps=WGS84 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs")

# CRTM05 projection is assigned to rasterbrick object
crs(raster.precis) <- CRTM05

# Object attributes are requested
# It can be seen that spa.res is different !!!!
image(raster.precis, col = topo.colors(64))

# A simple plot is requested
plot(raster.precis)

# A summery is requested
summary(raster.precis)

# A dummy raster is created
raster.precis.dummy <- raster.precis

# Dummy NA values are introduced
values(raster.precis.dummy) <- NA

# /////////////////////////////////////////////////////////////////////////////////////////////////////////////
# BLOCK: exploratory netCDF data analysis
# /////////////////////////////////////////////////////////////////////////////////////////////////////////////

#----------------------------------------------------------------------------------------------------------------------------------------
# HagGEM2-ES
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
ncin_decade01_rcp85_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon_201101-202012.nc")
ncin_decade02_rcp85_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon_202101-203012.nc")
ncin_decade03_rcp85_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon_203101-204012.nc")

# 2041-2070 NetCDF files are open
ncin_decade04_rcp85_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon_204101-205012.nc")
ncin_decade05_rcp85_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon_205101-206012.nc")
ncin_decade06_rcp85_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon_206101-207012.nc")

# 2071-2100 NetCDF files are open
ncin_decade07_rcp85_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon_207101-208012.nc")
ncin_decade08_rcp85_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon_208101-209012.nc")
ncin_decade09_rcp85_HadGEM2 <- nc_open("pr_CAM-44i_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon_209101-209912.nc")
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MIROC5
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
ncin_decade01_rcp85_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_201101-202012.nc")
ncin_decade02_rcp85_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_202101-203012.nc")
ncin_decade03_rcp85_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_203101-204012.nc")

# 2041-2070 NetCDF files are open
ncin_decade04_rcp85_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_204101-205012.nc")
ncin_decade05_rcp85_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_205101-206012.nc")
ncin_decade06_rcp85_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_206101-207012.nc")

# 2071-2100 NetCDF files are open
ncin_decade07_rcp85_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_207101-208012.nc")
ncin_decade08_rcp85_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_208101-209012.nc")
ncin_decade09_rcp85_MIROC5 <- nc_open("pr_CAM-44i_MIROC-MIROC5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_209101-210012.nc")
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# EARTH
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
ncin_decade01_rcp85_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon_201101-202012.nc")
ncin_decade02_rcp85_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon_202101-203012.nc")
ncin_decade03_rcp85_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon_203101-204012.nc")

# 2041-2070 NetCDF files are open
ncin_decade04_rcp85_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon_204101-205012.nc")
ncin_decade05_rcp85_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon_205101-206012.nc")
ncin_decade06_rcp85_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon_206101-207012.nc")

# 2071-2100 NetCDF files are open
ncin_decade07_rcp85_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon_207101-208012.nc")
ncin_decade08_rcp85_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon_208101-209012.nc")
ncin_decade09_rcp85_EARTH <- nc_open("pr_CAM-44i_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon_209101-210012.nc")
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MPI
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
ncin_decade01_rcp85_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_201101-202012.nc")
ncin_decade02_rcp85_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_202101-203012.nc")
ncin_decade03_rcp85_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_203101-204012.nc")

# 2041-2070 NetCDF files are open
ncin_decade04_rcp85_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_204101-205012.nc")
ncin_decade05_rcp85_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_205101-206012.nc")
ncin_decade06_rcp85_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_206101-207012.nc")

# 2071-2100 NetCDF files are open
ncin_decade07_rcp85_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_207101-208012.nc")
ncin_decade08_rcp85_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_208101-209012.nc")
ncin_decade09_rcp85_MPI <- nc_open("pr_CAM-44i_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_209101-210012.nc")
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# CanESM2
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
ncin_decade01_rcp85_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_rcp85_r1i1p1_SMHI-RCA4_v1_mon_201101-202012.nc")
ncin_decade02_rcp85_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_rcp85_r1i1p1_SMHI-RCA4_v1_mon_202101-203012.nc")
ncin_decade03_rcp85_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_rcp85_r1i1p1_SMHI-RCA4_v1_mon_203101-204012.nc")

# 2041-2070 NetCDF files are open
ncin_decade04_rcp85_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_rcp85_r1i1p1_SMHI-RCA4_v1_mon_204101-205012.nc")
ncin_decade05_rcp85_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_rcp85_r1i1p1_SMHI-RCA4_v1_mon_205101-206012.nc")
ncin_decade06_rcp85_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_rcp85_r1i1p1_SMHI-RCA4_v1_mon_206101-207012.nc")

# 2071-2100 NetCDF files are open
ncin_decade07_rcp85_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_rcp85_r1i1p1_SMHI-RCA4_v1_mon_207101-208012.nc")
ncin_decade08_rcp85_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_rcp85_r1i1p1_SMHI-RCA4_v1_mon_208101-209012.nc")
ncin_decade09_rcp85_CanESM2 <- nc_open("pr_CAM-44i_CCCma-CanESM2_rcp85_r1i1p1_SMHI-RCA4_v1_mon_209101-210012.nc")
#----------------------------------------------------------------------------------------------------------------------------------------

# extract variable name, size and dimension
v <- ncin_decade01_rcp85_HadGEM2$var[[1]] # WARNING !!!!! ----> [[1]] for RCA4; [[4]] for RegCM04
size <- v$varsize
dims <- v$ndims
nt <- size[dims]          # length of time dimension
lat <- ncin_decade01_rcp85_HadGEM2$dim$lat$vals  # latitude position
lon <- ncin_decade01_rcp85_HadGEM2$dim$lon$vals  # longitude position

# Precipitation variable is isolated
#----------------------------------------------------------------------------------------------------------------------------------------
# HagGEM2-ES
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
v1_rcp85_HadGEM2 <- ncin_decade01_rcp85_HadGEM2$var[[2]]
v2_rcp85_HadGEM2 <- ncin_decade02_rcp85_HadGEM2$var[[2]]
v3_rcp85_HadGEM2 <- ncin_decade03_rcp85_HadGEM2$var[[2]]

# 2041-2070 NetCDF files are open
v4_rcp85_HadGEM2 <- ncin_decade04_rcp85_HadGEM2$var[[2]]
v5_rcp85_HadGEM2 <- ncin_decade05_rcp85_HadGEM2$var[[2]]
v6_rcp85_HadGEM2 <- ncin_decade06_rcp85_HadGEM2$var[[2]]

# 2071-2100 NetCDF files are open
v7_rcp85_HadGEM2 <- ncin_decade07_rcp85_HadGEM2$var[[2]]
v8_rcp85_HadGEM2 <- ncin_decade08_rcp85_HadGEM2$var[[2]]
v9_rcp85_HadGEM2 <- ncin_decade09_rcp85_HadGEM2$var[[2]]
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MIROC5
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
v1_rcp85_MIROC5 <- ncin_decade01_rcp85_MIROC5$var[[2]]
v2_rcp85_MIROC5 <- ncin_decade02_rcp85_MIROC5$var[[2]]
v3_rcp85_MIROC5 <- ncin_decade03_rcp85_MIROC5$var[[2]]

# 2041-2070 NetCDF files are open
v4_rcp85_MIROC5 <- ncin_decade04_rcp85_MIROC5$var[[2]]
v5_rcp85_MIROC5 <- ncin_decade05_rcp85_MIROC5$var[[2]]
v6_rcp85_MIROC5 <- ncin_decade06_rcp85_MIROC5$var[[2]]

# 2071-2100 NetCDF files are open
v7_rcp85_MIROC5 <- ncin_decade07_rcp85_MIROC5$var[[2]]
v8_rcp85_MIROC5 <- ncin_decade08_rcp85_MIROC5$var[[2]]
v9_rcp85_MIROC5 <- ncin_decade09_rcp85_MIROC5$var[[2]]
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# EARTH
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
v1_rcp85_EARTH <- ncin_decade01_rcp85_EARTH$var[[2]]
v2_rcp85_EARTH <- ncin_decade02_rcp85_EARTH$var[[2]]
v3_rcp85_EARTH <- ncin_decade03_rcp85_EARTH$var[[2]]

# 2041-2070 NetCDF files are open
v4_rcp85_EARTH <- ncin_decade04_rcp85_EARTH$var[[2]]
v5_rcp85_EARTH <- ncin_decade05_rcp85_EARTH$var[[2]]
v6_rcp85_EARTH <- ncin_decade06_rcp85_EARTH$var[[2]]

# 2071-2100 NetCDF files are open
v7_rcp85_EARTH <- ncin_decade07_rcp85_EARTH$var[[2]]
v8_rcp85_EARTH <- ncin_decade08_rcp85_EARTH$var[[2]]
v9_rcp85_EARTH <- ncin_decade09_rcp85_EARTH$var[[2]]
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MPI
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
v1_rcp85_MPI <- ncin_decade01_rcp85_MPI$var[[2]]
v2_rcp85_MPI <- ncin_decade02_rcp85_MPI$var[[2]]
v3_rcp85_MPI <- ncin_decade03_rcp85_MPI$var[[2]]

# 2041-2070 NetCDF files are open
v4_rcp85_MPI <- ncin_decade04_rcp85_MPI$var[[2]]
v5_rcp85_MPI <- ncin_decade05_rcp85_MPI$var[[2]]
v6_rcp85_MPI <- ncin_decade06_rcp85_MPI$var[[2]]

# 2071-2100 NetCDF files are open
v7_rcp85_MPI <- ncin_decade07_rcp85_MPI$var[[2]]
v8_rcp85_MPI <- ncin_decade08_rcp85_MPI$var[[2]]
v9_rcp85_MPI <- ncin_decade09_rcp85_MPI$var[[2]]
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# CanESM2
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
v1_rcp85_CanESM2 <- ncin_decade01_rcp85_CanESM2$var[[2]]
v2_rcp85_CanESM2 <- ncin_decade02_rcp85_CanESM2$var[[2]]
v3_rcp85_CanESM2 <- ncin_decade03_rcp85_CanESM2$var[[2]]

# 2041-2070 NetCDF files are open
v4_rcp85_CanESM2 <- ncin_decade04_rcp85_CanESM2$var[[2]]
v5_rcp85_CanESM2 <- ncin_decade05_rcp85_CanESM2$var[[2]]
v6_rcp85_CanESM2 <- ncin_decade06_rcp85_CanESM2$var[[2]]

# 2071-2100 NetCDF files are open
v7_rcp85_CanESM2 <- ncin_decade07_rcp85_CanESM2$var[[2]]
v8_rcp85_CanESM2 <- ncin_decade08_rcp85_CanESM2$var[[2]]
v9_rcp85_CanESM2 <- ncin_decade09_rcp85_CanESM2$var[[2]]
#----------------------------------------------------------------------------------------------------------------------------------------

# NetCDF data is isolated
#----------------------------------------------------------------------------------------------------------------------------------------
# HagGEM2-ES
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
data.decade01_rcp85_HadGEM2 <- ncvar_get(ncin_decade01_rcp85_HadGEM2,v1_rcp85_HadGEM2)
data.decade02_rcp85_HadGEM2 <- ncvar_get(ncin_decade02_rcp85_HadGEM2,v2_rcp85_HadGEM2)
data.decade03_rcp85_HadGEM2 <- ncvar_get(ncin_decade03_rcp85_HadGEM2,v3_rcp85_HadGEM2)

# 2041-2070 NetCDF files are open
data.decade04_rcp85_HadGEM2 <- ncvar_get(ncin_decade04_rcp85_HadGEM2,v4_rcp85_HadGEM2)
data.decade05_rcp85_HadGEM2 <- ncvar_get(ncin_decade05_rcp85_HadGEM2,v5_rcp85_HadGEM2)
data.decade06_rcp85_HadGEM2 <- ncvar_get(ncin_decade06_rcp85_HadGEM2,v6_rcp85_HadGEM2)

# 2071-2100 NetCDF files are open
data.decade07_rcp85_HadGEM2 <- ncvar_get(ncin_decade07_rcp85_HadGEM2,v7_rcp85_HadGEM2)
data.decade08_rcp85_HadGEM2 <- ncvar_get(ncin_decade08_rcp85_HadGEM2,v8_rcp85_HadGEM2)
data.decade09_rcp85_HadGEM2 <- ncvar_get(ncin_decade09_rcp85_HadGEM2,v9_rcp85_HadGEM2)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MIROC5
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
data.decade01_rcp85_MIROC5 <- ncvar_get(ncin_decade01_rcp85_MIROC5,v1_rcp85_MIROC5)
data.decade02_rcp85_MIROC5 <- ncvar_get(ncin_decade02_rcp85_MIROC5,v2_rcp85_MIROC5)
data.decade03_rcp85_MIROC5 <- ncvar_get(ncin_decade03_rcp85_MIROC5,v3_rcp85_MIROC5)

# 2041-2070 NetCDF files are open
data.decade04_rcp85_MIROC5 <- ncvar_get(ncin_decade04_rcp85_MIROC5,v4_rcp85_MIROC5)
data.decade05_rcp85_MIROC5 <- ncvar_get(ncin_decade05_rcp85_MIROC5,v5_rcp85_MIROC5)
data.decade06_rcp85_MIROC5 <- ncvar_get(ncin_decade06_rcp85_MIROC5,v6_rcp85_MIROC5)

# 2071-2100 NetCDF files are open
data.decade07_rcp85_MIROC5 <- ncvar_get(ncin_decade07_rcp85_MIROC5,v7_rcp85_MIROC5)
data.decade08_rcp85_MIROC5 <- ncvar_get(ncin_decade08_rcp85_MIROC5,v8_rcp85_MIROC5)
data.decade09_rcp85_MIROC5 <- ncvar_get(ncin_decade09_rcp85_MIROC5,v9_rcp85_MIROC5)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# EARTH
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
data.decade01_rcp85_EARTH <- ncvar_get(ncin_decade01_rcp85_EARTH,v1_rcp85_EARTH)
data.decade02_rcp85_EARTH <- ncvar_get(ncin_decade02_rcp85_EARTH,v2_rcp85_EARTH)
data.decade03_rcp85_EARTH <- ncvar_get(ncin_decade03_rcp85_EARTH,v3_rcp85_EARTH)

# 2041-2070 NetCDF files are open
data.decade04_rcp85_EARTH <- ncvar_get(ncin_decade04_rcp85_EARTH,v4_rcp85_EARTH)
data.decade05_rcp85_EARTH <- ncvar_get(ncin_decade05_rcp85_EARTH,v5_rcp85_EARTH)
data.decade06_rcp85_EARTH <- ncvar_get(ncin_decade06_rcp85_EARTH,v6_rcp85_EARTH)

# 2071-2100 NetCDF files are open
data.decade07_rcp85_EARTH <- ncvar_get(ncin_decade07_rcp85_EARTH,v7_rcp85_EARTH)
data.decade08_rcp85_EARTH <- ncvar_get(ncin_decade08_rcp85_EARTH,v8_rcp85_EARTH)
data.decade09_rcp85_EARTH <- ncvar_get(ncin_decade09_rcp85_EARTH,v9_rcp85_EARTH)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MPI
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
data.decade01_rcp85_MPI <- ncvar_get(ncin_decade01_rcp85_MPI,v1_rcp85_MPI)
data.decade02_rcp85_MPI <- ncvar_get(ncin_decade02_rcp85_MPI,v2_rcp85_MPI)
data.decade03_rcp85_MPI <- ncvar_get(ncin_decade03_rcp85_MPI,v3_rcp85_MPI)

# 2041-2070 NetCDF files are open
data.decade04_rcp85_MPI <- ncvar_get(ncin_decade04_rcp85_MPI,v4_rcp85_MPI)
data.decade05_rcp85_MPI <- ncvar_get(ncin_decade05_rcp85_MPI,v5_rcp85_MPI)
data.decade06_rcp85_MPI <- ncvar_get(ncin_decade06_rcp85_MPI,v6_rcp85_MPI)

# 2071-2100 NetCDF files are open
data.decade07_rcp85_MPI <- ncvar_get(ncin_decade07_rcp85_MPI,v7_rcp85_MPI)
data.decade08_rcp85_MPI <- ncvar_get(ncin_decade08_rcp85_MPI,v8_rcp85_MPI)
data.decade09_rcp85_MPI <- ncvar_get(ncin_decade09_rcp85_MPI,v9_rcp85_MPI)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# CanESM2
#----------------------------------------------------------------------------------------------------------------------------------------

# 2011-2040 NetCDF files are open
data.decade01_rcp85_CanESM2 <- ncvar_get(ncin_decade01_rcp85_CanESM2,v1_rcp85_CanESM2)
data.decade02_rcp85_CanESM2 <- ncvar_get(ncin_decade02_rcp85_CanESM2,v2_rcp85_CanESM2)
data.decade03_rcp85_CanESM2 <- ncvar_get(ncin_decade03_rcp85_CanESM2,v3_rcp85_CanESM2)

# 2041-2070 NetCDF files are open
data.decade04_rcp85_CanESM2 <- ncvar_get(ncin_decade04_rcp85_CanESM2,v4_rcp85_CanESM2)
data.decade05_rcp85_CanESM2 <- ncvar_get(ncin_decade05_rcp85_CanESM2,v5_rcp85_CanESM2)
data.decade06_rcp85_CanESM2 <- ncvar_get(ncin_decade06_rcp85_CanESM2,v6_rcp85_CanESM2)

# 2071-2100 NetCDF files are open
data.decade07_rcp85_CanESM2 <- ncvar_get(ncin_decade07_rcp85_CanESM2,v7_rcp85_CanESM2)
data.decade08_rcp85_CanESM2 <- ncvar_get(ncin_decade08_rcp85_CanESM2,v8_rcp85_CanESM2)
data.decade09_rcp85_CanESM2 <- ncvar_get(ncin_decade09_rcp85_CanESM2,v9_rcp85_CanESM2)
#----------------------------------------------------------------------------------------------------------------------------------------

# NetCDF data is transformed to rasterbrick
#----------------------------------------------------------------------------------------------------------------------------------------
# HadGEM2-ES
#----------------------------------------------------------------------------------------------------------------------------------------
# 2011-2040 NetCDF files are open
decade01_HadGEM2 <- raster::brick(data.decade01_rcp85_HadGEM2)
decade02_HadGEM2 <- raster::brick(data.decade02_rcp85_HadGEM2)
decade03_HadGEM2 <- raster::brick(data.decade03_rcp85_HadGEM2)

# 2041-2070 NetCDF files are open
decade04_HadGEM2 <- raster::brick(data.decade04_rcp85_HadGEM2)
decade05_HadGEM2 <- raster::brick(data.decade05_rcp85_HadGEM2)
decade06_HadGEM2 <- raster::brick(data.decade06_rcp85_HadGEM2)

# 2071-2100 NetCDF files are open
decade07_HadGEM2 <- raster::brick(data.decade07_rcp85_HadGEM2)
decade08_HadGEM2 <- raster::brick(data.decade08_rcp85_HadGEM2)
decade09_HadGEM2 <- raster::brick(data.decade09_rcp85_HadGEM2)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MIROC5
#----------------------------------------------------------------------------------------------------------------------------------------
# 2011-2040 NetCDF files are open
decade01_MIROC5 <- raster::brick(data.decade01_rcp85_MIROC5)
decade02_MIROC5 <- raster::brick(data.decade02_rcp85_MIROC5)
decade03_MIROC5 <- raster::brick(data.decade03_rcp85_MIROC5)

# 2041-2070 NetCDF files are open
decade04_MIROC5 <- raster::brick(data.decade04_rcp85_MIROC5)
decade05_MIROC5 <- raster::brick(data.decade05_rcp85_MIROC5)
decade06_MIROC5 <- raster::brick(data.decade06_rcp85_MIROC5)

# 2071-2100 NetCDF files are open
decade07_MIROC5 <- raster::brick(data.decade07_rcp85_MIROC5)
decade08_MIROC5 <- raster::brick(data.decade08_rcp85_MIROC5)
decade09_MIROC5 <- raster::brick(data.decade09_rcp85_MIROC5)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# EARTH
#----------------------------------------------------------------------------------------------------------------------------------------
# 2011-2040 NetCDF files are open
decade01_EARTH <- raster::brick(data.decade01_rcp85_EARTH)
decade02_EARTH <- raster::brick(data.decade02_rcp85_EARTH)
decade03_EARTH <- raster::brick(data.decade03_rcp85_EARTH)

# 2041-2070 NetCDF files are open
decade04_EARTH <- raster::brick(data.decade04_rcp85_EARTH)
decade05_EARTH <- raster::brick(data.decade05_rcp85_EARTH)
decade06_EARTH <- raster::brick(data.decade06_rcp85_EARTH)

# 2071-2100 NetCDF files are open
decade07_EARTH <- raster::brick(data.decade07_rcp85_EARTH)
decade08_EARTH <- raster::brick(data.decade08_rcp85_EARTH)
decade09_EARTH <- raster::brick(data.decade09_rcp85_EARTH)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MPI
#----------------------------------------------------------------------------------------------------------------------------------------
# 2011-2040 NetCDF files are open
decade01_MPI <- raster::brick(data.decade01_rcp85_MPI)
decade02_MPI <- raster::brick(data.decade02_rcp85_MPI)
decade03_MPI <- raster::brick(data.decade03_rcp85_MPI)

# 2041-2070 NetCDF files are open
decade04_MPI <- raster::brick(data.decade04_rcp85_MPI)
decade05_MPI <- raster::brick(data.decade05_rcp85_MPI)
decade06_MPI <- raster::brick(data.decade06_rcp85_MPI)

# 2071-2100 NetCDF files are open
decade07_MPI <- raster::brick(data.decade07_rcp85_MPI)
decade08_MPI <- raster::brick(data.decade08_rcp85_MPI)
decade09_MPI <- raster::brick(data.decade09_rcp85_MPI)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# CanESM2
#----------------------------------------------------------------------------------------------------------------------------------------
# 2011-2040 NetCDF files are open
decade01_CanESM2 <- raster::brick(data.decade01_rcp85_CanESM2)
decade02_CanESM2 <- raster::brick(data.decade02_rcp85_CanESM2)
decade03_CanESM2 <- raster::brick(data.decade03_rcp85_CanESM2)

# 2041-2070 NetCDF files are open
decade04_CanESM2 <- raster::brick(data.decade04_rcp85_CanESM2)
decade05_CanESM2 <- raster::brick(data.decade05_rcp85_CanESM2)
decade06_CanESM2 <- raster::brick(data.decade06_rcp85_CanESM2)

# 2071-2100 NetCDF files are open
decade07_CanESM2 <- raster::brick(data.decade07_rcp85_CanESM2)
decade08_CanESM2 <- raster::brick(data.decade08_rcp85_CanESM2)
decade09_CanESM2 <- raster::brick(data.decade09_rcp85_CanESM2)
#----------------------------------------------------------------------------------------------------------------------------------------

# rasterbrick object is transposed to have the correct orientation
#----------------------------------------------------------------------------------------------------------------------------------------
# HadGEM2
#----------------------------------------------------------------------------------------------------------------------------------------
# 2011-2040 NetCDF files are open
decade01_HadGEM2 <- t(decade01_HadGEM2)
decade02_HadGEM2 <- t(decade02_HadGEM2)
decade03_HadGEM2 <- t(decade03_HadGEM2)

# 2041-2070 NetCDF files are open
decade04_HadGEM2 <- t(decade04_HadGEM2)
decade05_HadGEM2 <- t(decade05_HadGEM2)
decade06_HadGEM2 <- t(decade06_HadGEM2)

# 2071-2100 NetCDF files are open
decade07_HadGEM2 <- t(decade07_HadGEM2)
decade08_HadGEM2 <- t(decade08_HadGEM2)
decade09_HadGEM2 <- t(decade09_HadGEM2)

# 2011-2040 NetCDF files are open
decade01_HadGEM2 <- flip(decade01_HadGEM2, direction = 2)
decade02_HadGEM2 <- flip(decade02_HadGEM2, direction = 2)
decade03_HadGEM2 <- flip(decade03_HadGEM2, direction = 2)

# 2041-2070 NetCDF files are open
decade04_HadGEM2 <- flip(decade04_HadGEM2, direction = 2)
decade05_HadGEM2 <- flip(decade05_HadGEM2, direction = 2)
decade06_HadGEM2 <- flip(decade06_HadGEM2, direction = 2)

# 1971-2000 NetCDF files are open
decade07_HadGEM2 <- flip(decade07_HadGEM2, direction = 2)
decade08_HadGEM2 <- flip(decade08_HadGEM2, direction = 2)
decade09_HadGEM2 <- flip(decade09_HadGEM2, direction = 2)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MIROC5
#----------------------------------------------------------------------------------------------------------------------------------------
# 2011-2040 NetCDF files are open
decade01_MIROC5 <- t(decade01_MIROC5)
decade02_MIROC5 <- t(decade02_MIROC5)
decade03_MIROC5 <- t(decade03_MIROC5)

# 2041-2070 NetCDF files are open
decade04_MIROC5 <- t(decade04_MIROC5)
decade05_MIROC5 <- t(decade05_MIROC5)
decade06_MIROC5 <- t(decade06_MIROC5)

# 2071-2100 NetCDF files are open
decade07_MIROC5 <- t(decade07_MIROC5)
decade08_MIROC5 <- t(decade08_MIROC5)
decade09_MIROC5 <- t(decade09_MIROC5)

# 2011-2040 NetCDF files are open
decade01_MIROC5 <- flip(decade01_MIROC5, direction = 2)
decade02_MIROC5 <- flip(decade02_MIROC5, direction = 2)
decade03_MIROC5 <- flip(decade03_MIROC5, direction = 2)

# 2041-2070 NetCDF files are open
decade04_MIROC5 <- flip(decade04_MIROC5, direction = 2)
decade05_MIROC5 <- flip(decade05_MIROC5, direction = 2)
decade06_MIROC5 <- flip(decade06_MIROC5, direction = 2)

# 1971-2000 NetCDF files are open
decade07_MIROC5 <- flip(decade07_MIROC5, direction = 2)
decade08_MIROC5 <- flip(decade08_MIROC5, direction = 2)
decade09_MIROC5 <- flip(decade09_MIROC5, direction = 2)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# EARTH
#----------------------------------------------------------------------------------------------------------------------------------------
# 2011-2040 NetCDF files are open
decade01_EARTH <- t(decade01_EARTH)
decade02_EARTH <- t(decade02_EARTH)
decade03_EARTH <- t(decade03_EARTH)

# 2041-2070 NetCDF files are open
decade04_EARTH <- t(decade04_EARTH)
decade05_EARTH <- t(decade05_EARTH)
decade06_EARTH <- t(decade06_EARTH)

# 2071-2100 NetCDF files are open
decade07_EARTH <- t(decade07_EARTH)
decade08_EARTH <- t(decade08_EARTH)
decade09_EARTH <- t(decade09_EARTH)

# 2011-2040 NetCDF files are open
decade01_EARTH <- flip(decade01_EARTH, direction = 2)
decade02_EARTH <- flip(decade02_EARTH, direction = 2)
decade03_EARTH <- flip(decade03_EARTH, direction = 2)

# 2041-2070 NetCDF files are open
decade04_EARTH <- flip(decade04_EARTH, direction = 2)
decade05_EARTH <- flip(decade05_EARTH, direction = 2)
decade06_EARTH <- flip(decade06_EARTH, direction = 2)

# 1971-2000 NetCDF files are open
decade07_EARTH <- flip(decade07_EARTH, direction = 2)
decade08_EARTH <- flip(decade08_EARTH, direction = 2)
decade09_EARTH <- flip(decade09_EARTH, direction = 2)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# MPI
#----------------------------------------------------------------------------------------------------------------------------------------
# 2011-2040 NetCDF files are open
decade01_MPI <- t(decade01_MPI)
decade02_MPI <- t(decade02_MPI)
decade03_MPI <- t(decade03_MPI)

# 2041-2070 NetCDF files are open
decade04_MPI <- t(decade04_MPI)
decade05_MPI <- t(decade05_MPI)
decade06_MPI <- t(decade06_MPI)

# 2071-2100 NetCDF files are open
decade07_MPI <- t(decade07_MPI)
decade08_MPI <- t(decade08_MPI)
decade09_MPI <- t(decade09_MPI)

# 2011-2040 NetCDF files are open
decade01_MPI <- flip(decade01_MPI, direction = 2)
decade02_MPI <- flip(decade02_MPI, direction = 2)
decade03_MPI <- flip(decade03_MPI, direction = 2)

# 2041-2070 NetCDF files are open
decade04_MPI <- flip(decade04_MPI, direction = 2)
decade05_MPI <- flip(decade05_MPI, direction = 2)
decade06_MPI <- flip(decade06_MPI, direction = 2)

# 1971-2000 NetCDF files are open
decade07_MPI <- flip(decade07_MPI, direction = 2)
decade08_MPI <- flip(decade08_MPI, direction = 2)
decade09_MPI <- flip(decade09_MPI, direction = 2)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# CanESM2
#----------------------------------------------------------------------------------------------------------------------------------------
# 2011-2040 NetCDF files are open
decade01_CanESM2 <- t(decade01_CanESM2)
decade02_CanESM2 <- t(decade02_CanESM2)
decade03_CanESM2 <- t(decade03_CanESM2)

# 2041-2070 NetCDF files are open
decade04_CanESM2 <- t(decade04_CanESM2)
decade05_CanESM2 <- t(decade05_CanESM2)
decade06_CanESM2 <- t(decade06_CanESM2)

# 2071-2100 NetCDF files are open
decade07_CanESM2 <- t(decade07_CanESM2)
decade08_CanESM2 <- t(decade08_CanESM2)
decade09_CanESM2 <- t(decade09_CanESM2)

# 2011-2040 NetCDF files are open
decade01_CanESM2 <- flip(decade01_CanESM2, direction = 2)
decade02_CanESM2 <- flip(decade02_CanESM2, direction = 2)
decade03_CanESM2 <- flip(decade03_CanESM2, direction = 2)

# 2041-2070 NetCDF files are open
decade04_CanESM2 <- flip(decade04_CanESM2, direction = 2)
decade05_CanESM2 <- flip(decade05_CanESM2, direction = 2)
decade06_CanESM2 <- flip(decade06_CanESM2, direction = 2)

# 1971-2000 NetCDF files are open
decade07_CanESM2 <- flip(decade07_CanESM2, direction = 2)
decade08_CanESM2 <- flip(decade08_CanESM2, direction = 2)
decade09_CanESM2 <- flip(decade09_CanESM2, direction = 2)
#----------------------------------------------------------------------------------------------------------------------------------------

# Raster object extents are defined based on Lat + Long
#----------------------------------------------------------------------------------------------------------------------------------------	
# HadGEM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
extent(decade01_HadGEM2) <- extent(c(range(lon), range(lat)))
extent(decade02_HadGEM2) <- extent(c(range(lon), range(lat)))
extent(decade03_HadGEM2) <- extent(c(range(lon), range(lat)))

# 2041-2070 NetCDF files are open	
extent(decade04_HadGEM2) <- extent(c(range(lon), range(lat)))
extent(decade05_HadGEM2) <- extent(c(range(lon), range(lat)))
extent(decade06_HadGEM2) <- extent(c(range(lon), range(lat)))

# 2071-2100 NetCDF files are open	
extent(decade07_HadGEM2) <- extent(c(range(lon), range(lat)))
extent(decade08_HadGEM2) <- extent(c(range(lon), range(lat)))
extent(decade09_HadGEM2) <- extent(c(range(lon), range(lat)))
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MIROC5	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
extent(decade01_MIROC5) <- extent(c(range(lon), range(lat)))
extent(decade02_MIROC5) <- extent(c(range(lon), range(lat)))
extent(decade03_MIROC5) <- extent(c(range(lon), range(lat)))

# 2041-2070 NetCDF files are open	
extent(decade04_MIROC5) <- extent(c(range(lon), range(lat)))
extent(decade05_MIROC5) <- extent(c(range(lon), range(lat)))
extent(decade06_MIROC5) <- extent(c(range(lon), range(lat)))

# 2071-2100 NetCDF files are open	
extent(decade07_MIROC5) <- extent(c(range(lon), range(lat)))
extent(decade08_MIROC5) <- extent(c(range(lon), range(lat)))
extent(decade09_MIROC5) <- extent(c(range(lon), range(lat)))
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# EARTH	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
extent(decade01_EARTH) <- extent(c(range(lon), range(lat)))
extent(decade02_EARTH) <- extent(c(range(lon), range(lat)))
extent(decade03_EARTH) <- extent(c(range(lon), range(lat)))

# 2041-2070 NetCDF files are open	
extent(decade04_EARTH) <- extent(c(range(lon), range(lat)))
extent(decade05_EARTH) <- extent(c(range(lon), range(lat)))
extent(decade06_EARTH) <- extent(c(range(lon), range(lat)))

# 2071-2100 NetCDF files are open	
extent(decade07_EARTH) <- extent(c(range(lon), range(lat)))
extent(decade08_EARTH) <- extent(c(range(lon), range(lat)))
extent(decade09_EARTH) <- extent(c(range(lon), range(lat)))
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MPI	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
extent(decade01_MPI) <- extent(c(range(lon), range(lat)))
extent(decade02_MPI) <- extent(c(range(lon), range(lat)))
extent(decade03_MPI) <- extent(c(range(lon), range(lat)))

# 2041-2070 NetCDF files are open	
extent(decade04_MPI) <- extent(c(range(lon), range(lat)))
extent(decade05_MPI) <- extent(c(range(lon), range(lat)))
extent(decade06_MPI) <- extent(c(range(lon), range(lat)))

# 2071-2100 NetCDF files are open	
extent(decade07_MPI) <- extent(c(range(lon), range(lat)))
extent(decade08_MPI) <- extent(c(range(lon), range(lat)))
extent(decade09_MPI) <- extent(c(range(lon), range(lat)))
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# CanESM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
extent(decade01_CanESM2) <- extent(c(range(lon), range(lat)))
extent(decade02_CanESM2) <- extent(c(range(lon), range(lat)))
extent(decade03_CanESM2) <- extent(c(range(lon), range(lat)))

# 2041-2070 NetCDF files are open	
extent(decade04_CanESM2) <- extent(c(range(lon), range(lat)))
extent(decade05_CanESM2) <- extent(c(range(lon), range(lat)))
extent(decade06_CanESM2) <- extent(c(range(lon), range(lat)))

# 2071-2100 NetCDF files are open	
extent(decade07_CanESM2) <- extent(c(range(lon), range(lat)))
extent(decade08_CanESM2) <- extent(c(range(lon), range(lat)))
extent(decade09_CanESM2) <- extent(c(range(lon), range(lat)))
#----------------------------------------------------------------------------------------------------------------------------------------	

# WGS84 crs is defined
# Raster object extents are defined based on Lat + Long
#----------------------------------------------------------------------------------------------------------------------------------------	
# HadGEM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
proj4string(decade01_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade02_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade03_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")

# 2041-2070 NetCDF files are open	
proj4string(decade04_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade05_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade06_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")

# 2071-2100 NetCDF files are open	
proj4string(decade07_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade08_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade09_HadGEM2) <- CRS("+proj=longlat +datum=WGS84")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MIROC5	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
proj4string(decade01_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade02_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade03_MIROC5) <- CRS("+proj=longlat +datum=WGS84")

# 2041-2070 NetCDF files are open	
proj4string(decade04_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade05_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade06_MIROC5) <- CRS("+proj=longlat +datum=WGS84")

# 2071-2100 NetCDF files are open	
proj4string(decade07_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade08_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade09_MIROC5) <- CRS("+proj=longlat +datum=WGS84")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# EARTH	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
proj4string(decade01_EARTH) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade02_EARTH) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade03_EARTH) <- CRS("+proj=longlat +datum=WGS84")

# 2041-2070 NetCDF files are open	
proj4string(decade04_EARTH) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade05_EARTH) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade06_EARTH) <- CRS("+proj=longlat +datum=WGS84")

# 2071-2100 NetCDF files are open	
proj4string(decade07_EARTH) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade08_EARTH) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade09_EARTH) <- CRS("+proj=longlat +datum=WGS84")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MPI	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
proj4string(decade01_MPI) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade02_MPI) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade03_MPI) <- CRS("+proj=longlat +datum=WGS84")

# 2041-2070 NetCDF files are open	
proj4string(decade04_MPI) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade05_MPI) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade06_MPI) <- CRS("+proj=longlat +datum=WGS84")

# 2071-2100 NetCDF files are open	
proj4string(decade07_MPI) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade08_MPI) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade09_MPI) <- CRS("+proj=longlat +datum=WGS84")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# CanESM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
proj4string(decade01_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade02_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade03_CanESM2) <- CRS("+proj=longlat +datum=WGS84")

# 2041-2070 NetCDF files are open	
proj4string(decade04_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade05_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade06_CanESM2) <- CRS("+proj=longlat +datum=WGS84")

# 2071-2100 NetCDF files are open	
proj4string(decade07_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade08_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
proj4string(decade09_CanESM2) <- CRS("+proj=longlat +datum=WGS84")
#----------------------------------------------------------------------------------------------------------------------------------------	

# Units are transformed from [kg m-2 s-1] to mm/month
#----------------------------------------------------------------------------------------------------------------------------------------	
# HadGEM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
decade01_HadGEM2 <- decade01_HadGEM2*30*86400
decade02_HadGEM2 <- decade02_HadGEM2*30*86400
decade03_HadGEM2 <- decade03_HadGEM2*30*86400

# 2041-2070 NetCDF files are open	
decade04_HadGEM2 <- decade04_HadGEM2*30*86400
decade05_HadGEM2 <- decade05_HadGEM2*30*86400
decade06_HadGEM2 <- decade06_HadGEM2*30*86400

# 2071-2100 NetCDF files are open	
decade07_HadGEM2 <- decade07_HadGEM2*30*86400
decade08_HadGEM2 <- decade08_HadGEM2*30*86400
decade09_HadGEM2 <- decade09_HadGEM2*30*86400
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MIROC5	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
decade01_MIROC5 <- decade01_MIROC5*30*86400
decade02_MIROC5 <- decade02_MIROC5*30*86400
decade03_MIROC5 <- decade03_MIROC5*30*86400

# 2041-2070 NetCDF files are open	
decade04_MIROC5 <- decade04_MIROC5*30*86400
decade05_MIROC5 <- decade05_MIROC5*30*86400
decade06_MIROC5 <- decade06_MIROC5*30*86400

# 2071-2100 NetCDF files are open	
decade07_MIROC5 <- decade07_MIROC5*30*86400
decade08_MIROC5 <- decade08_MIROC5*30*86400
decade09_MIROC5 <- decade09_MIROC5*30*86400
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# EARTH	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
decade01_EARTH <- decade01_EARTH*30*86400
decade02_EARTH <- decade02_EARTH*30*86400
decade03_EARTH <- decade03_EARTH*30*86400

# 2041-2070 NetCDF files are open	
decade04_EARTH <- decade04_EARTH*30*86400
decade05_EARTH <- decade05_EARTH*30*86400
decade06_EARTH <- decade06_EARTH*30*86400

# 2071-2100 NetCDF files are open	
decade07_EARTH <- decade07_EARTH*30*86400
decade08_EARTH <- decade08_EARTH*30*86400
decade09_EARTH <- decade09_EARTH*30*86400
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MPI	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
decade01_MPI <- decade01_MPI*30*86400
decade02_MPI <- decade02_MPI*30*86400
decade03_MPI <- decade03_MPI*30*86400

# 2041-2070 NetCDF files are open	
decade04_MPI <- decade04_MPI*30*86400
decade05_MPI <- decade05_MPI*30*86400
decade06_MPI <- decade06_MPI*30*86400

# 2071-2100 NetCDF files are open	
decade07_MPI <- decade07_MPI*30*86400
decade08_MPI <- decade08_MPI*30*86400
decade09_MPI <- decade09_MPI*30*86400
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# CanESM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
decade01_CanESM2 <- decade01_CanESM2*30*86400
decade02_CanESM2 <- decade02_CanESM2*30*86400
decade03_CanESM2 <- decade03_CanESM2*30*86400

# 2041-2070 NetCDF files are open	
decade04_CanESM2 <- decade04_CanESM2*30*86400
decade05_CanESM2 <- decade05_CanESM2*30*86400
decade06_CanESM2 <- decade06_CanESM2*30*86400

# 2071-2100 NetCDF files are open	
decade07_CanESM2 <- decade07_CanESM2*30*86400
decade08_CanESM2 <- decade08_CanESM2*30*86400
decade09_CanESM2 <- decade09_CanESM2*30*86400
#----------------------------------------------------------------------------------------------------------------------------------------	

# Rasterbrick object is reprojected
#----------------------------------------------------------------------------------------------------------------------------------------	
# HadGEM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
brick01_HadGEM2 <- projectRaster(decade01_HadGEM2, raster.precis.dummy, method="bilinear")
brick02_HadGEM2 <- projectRaster(decade02_HadGEM2, raster.precis.dummy, method="bilinear")
brick03_HadGEM2 <- projectRaster(decade03_HadGEM2, raster.precis.dummy, method="bilinear")

# 2041-2070 NetCDF files are open	
brick04_HadGEM2 <- projectRaster(decade04_HadGEM2, raster.precis.dummy, method="bilinear")
brick05_HadGEM2 <- projectRaster(decade05_HadGEM2, raster.precis.dummy, method="bilinear")
brick06_HadGEM2 <- projectRaster(decade06_HadGEM2, raster.precis.dummy, method="bilinear")

# 2071-2100 NetCDF files are open	
brick07_HadGEM2 <- projectRaster(decade07_HadGEM2, raster.precis.dummy, method="bilinear")
brick08_HadGEM2 <- projectRaster(decade08_HadGEM2, raster.precis.dummy, method="bilinear")
brick09_HadGEM2 <- projectRaster(decade09_HadGEM2, raster.precis.dummy, method="bilinear")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MIROC5	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
brick01_MIROC5 <- projectRaster(decade01_MIROC5, raster.precis.dummy, method="bilinear")
brick02_MIROC5 <- projectRaster(decade02_MIROC5, raster.precis.dummy, method="bilinear")
brick03_MIROC5 <- projectRaster(decade03_MIROC5, raster.precis.dummy, method="bilinear")

# 2041-2070 NetCDF files are open	
brick04_MIROC5 <- projectRaster(decade04_MIROC5, raster.precis.dummy, method="bilinear")
brick05_MIROC5 <- projectRaster(decade05_MIROC5, raster.precis.dummy, method="bilinear")
brick06_MIROC5 <- projectRaster(decade06_MIROC5, raster.precis.dummy, method="bilinear")

# 2071-2100 NetCDF files are open	
brick07_MIROC5 <- projectRaster(decade07_MIROC5, raster.precis.dummy, method="bilinear")
brick08_MIROC5 <- projectRaster(decade08_MIROC5, raster.precis.dummy, method="bilinear")
brick09_MIROC5 <- projectRaster(decade09_MIROC5, raster.precis.dummy, method="bilinear")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# EARTH	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
brick01_EARTH <- projectRaster(decade01_EARTH, raster.precis.dummy, method="bilinear")
brick02_EARTH <- projectRaster(decade02_EARTH, raster.precis.dummy, method="bilinear")
brick03_EARTH <- projectRaster(decade03_EARTH, raster.precis.dummy, method="bilinear")

# 2041-2070 NetCDF files are open	
brick04_EARTH <- projectRaster(decade04_EARTH, raster.precis.dummy, method="bilinear")
brick05_EARTH <- projectRaster(decade05_EARTH, raster.precis.dummy, method="bilinear")
brick06_EARTH <- projectRaster(decade06_EARTH, raster.precis.dummy, method="bilinear")

# 2071-2100 NetCDF files are open	
brick07_EARTH <- projectRaster(decade07_EARTH, raster.precis.dummy, method="bilinear")
brick08_EARTH <- projectRaster(decade08_EARTH, raster.precis.dummy, method="bilinear")
brick09_EARTH <- projectRaster(decade09_EARTH, raster.precis.dummy, method="bilinear")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MPI	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
brick01_MPI <- projectRaster(decade01_MPI, raster.precis.dummy, method="bilinear")
brick02_MPI <- projectRaster(decade02_MPI, raster.precis.dummy, method="bilinear")
brick03_MPI <- projectRaster(decade03_MPI, raster.precis.dummy, method="bilinear")

# 2041-2070 NetCDF files are open	
brick04_MPI <- projectRaster(decade04_MPI, raster.precis.dummy, method="bilinear")
brick05_MPI <- projectRaster(decade05_MPI, raster.precis.dummy, method="bilinear")
brick06_MPI <- projectRaster(decade06_MPI, raster.precis.dummy, method="bilinear")

# 2071-2100 NetCDF files are open	
brick07_MPI <- projectRaster(decade07_MPI, raster.precis.dummy, method="bilinear")
brick08_MPI <- projectRaster(decade08_MPI, raster.precis.dummy, method="bilinear")
brick09_MPI <- projectRaster(decade09_MPI, raster.precis.dummy, method="bilinear")
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# CanESM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
brick01_CanESM2 <- projectRaster(decade01_CanESM2, raster.precis.dummy, method="bilinear")
brick02_CanESM2 <- projectRaster(decade02_CanESM2, raster.precis.dummy, method="bilinear")
brick03_CanESM2 <- projectRaster(decade03_CanESM2, raster.precis.dummy, method="bilinear")

# 2041-2070 NetCDF files are open	
brick04_CanESM2 <- projectRaster(decade04_CanESM2, raster.precis.dummy, method="bilinear")
brick05_CanESM2 <- projectRaster(decade05_CanESM2, raster.precis.dummy, method="bilinear")
brick06_CanESM2 <- projectRaster(decade06_CanESM2, raster.precis.dummy, method="bilinear")

# 2071-2100 NetCDF files are open	
brick07_CanESM2 <- projectRaster(decade07_CanESM2, raster.precis.dummy, method="bilinear")
brick08_CanESM2 <- projectRaster(decade08_CanESM2, raster.precis.dummy, method="bilinear")
brick09_CanESM2 <- projectRaster(decade09_CanESM2, raster.precis.dummy, method="bilinear")
#----------------------------------------------------------------------------------------------------------------------------------------	

# Rasterbrick object is masked
#----------------------------------------------------------------------------------------------------------------------------------------	
# HadGEM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
brick01_HadGEM2 <- mask(brick01_HadGEM2, raster.precis)
brick02_HadGEM2 <- mask(brick02_HadGEM2, raster.precis)
brick03_HadGEM2 <- mask(brick03_HadGEM2, raster.precis)

# 2041-2070 NetCDF files are open	
brick04_HadGEM2 <- mask(brick04_HadGEM2, raster.precis)
brick05_HadGEM2 <- mask(brick05_HadGEM2, raster.precis)
brick06_HadGEM2 <- mask(brick06_HadGEM2, raster.precis)

# 2071-2100 NetCDF files are open	
brick07_HadGEM2 <- mask(brick07_HadGEM2, raster.precis)
brick08_HadGEM2 <- mask(brick08_HadGEM2, raster.precis)
brick09_HadGEM2 <- mask(brick09_HadGEM2, raster.precis)
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MIROC5	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
brick01_MIROC5 <- mask(brick01_MIROC5, raster.precis)
brick02_MIROC5 <- mask(brick02_MIROC5, raster.precis)
brick03_MIROC5 <- mask(brick03_MIROC5, raster.precis)

# 2041-2070 NetCDF files are open	
brick04_MIROC5 <- mask(brick04_MIROC5, raster.precis)
brick05_MIROC5 <- mask(brick05_MIROC5, raster.precis)
brick06_MIROC5 <- mask(brick06_MIROC5, raster.precis)

# 2071-2100 NetCDF files are open	
brick07_MIROC5 <- mask(brick07_MIROC5, raster.precis)
brick08_MIROC5 <- mask(brick08_MIROC5, raster.precis)
brick09_MIROC5 <- mask(brick09_MIROC5, raster.precis)
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# EARTH	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
brick01_EARTH <- mask(brick01_EARTH, raster.precis)
brick02_EARTH <- mask(brick02_EARTH, raster.precis)
brick03_EARTH <- mask(brick03_EARTH, raster.precis)

# 2041-2070 NetCDF files are open	
brick04_EARTH <- mask(brick04_EARTH, raster.precis)
brick05_EARTH <- mask(brick05_EARTH, raster.precis)
brick06_EARTH <- mask(brick06_EARTH, raster.precis)

# 2071-2100 NetCDF files are open	
brick07_EARTH <- mask(brick07_EARTH, raster.precis)
brick08_EARTH <- mask(brick08_EARTH, raster.precis)
brick09_EARTH <- mask(brick09_EARTH, raster.precis)
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# MPI	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
brick01_MPI <- mask(brick01_MPI, raster.precis)
brick02_MPI <- mask(brick02_MPI, raster.precis)
brick03_MPI <- mask(brick03_MPI, raster.precis)

# 2041-2070 NetCDF files are open	
brick04_MPI <- mask(brick04_MPI, raster.precis)
brick05_MPI <- mask(brick05_MPI, raster.precis)
brick06_MPI <- mask(brick06_MPI, raster.precis)

# 2071-2100 NetCDF files are open	
brick07_MPI <- mask(brick07_MPI, raster.precis)
brick08_MPI <- mask(brick08_MPI, raster.precis)
brick09_MPI <- mask(brick09_MPI, raster.precis)
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# CanESM2	
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open	
brick01_CanESM2 <- mask(brick01_CanESM2, raster.precis)
brick02_CanESM2 <- mask(brick02_CanESM2, raster.precis)
brick03_CanESM2 <- mask(brick03_CanESM2, raster.precis)

# 2041-2070 NetCDF files are open	
brick04_CanESM2 <- mask(brick04_CanESM2, raster.precis)
brick05_CanESM2 <- mask(brick05_CanESM2, raster.precis)
brick06_CanESM2 <- mask(brick06_CanESM2, raster.precis)

# 2071-2100 NetCDF files are open	
brick07_CanESM2 <- mask(brick07_CanESM2, raster.precis)
brick08_CanESM2 <- mask(brick08_CanESM2, raster.precis)
brick09_CanESM2 <- mask(brick09_CanESM2, raster.precis)
#----------------------------------------------------------------------------------------------------------------------------------------	

# PRECIS netCDF/ GeoTIFF rcp85 Time-series are loaded
#--------------------------------------------------------------------------------------------------------------------------------------
ncin_rcp85_2011_2040_PRECIS <- raster::stack("RCP85_2011_2040.nc")
ncin_rcp85_2041_2070_PRECIS <- raster::stack("RCP85_2041_2070.nc")
ncin_rcp85_2071_2100_PRECIS <- raster::stack("RCP85_2071_2100.nc")
#--------------------------------------------------------------------------------------------------------------------------------------

# A plot is requested for verification purposes
plot(ncin_rcp85_2011_2040_PRECIS[[1]])
plot(brick01_HadGEM2[[1]])
plot(brick01_MIROC5[[1]])
plot(brick01_EARTH[[1]])
plot(brick01_MPI[[1]])
plot(brick01_CanESM2[[1]])

# Rasterbrick objects are blended into a rasterstack object
#----------------------------------------------------------------------------------------------------------------------------------------	
# 2011-2040 NetCDF files are open
brick_raw_total_2011_2040_PRECIS <- stack(ncin_rcp85_2011_2040_PRECIS) # 360 layers
brick_raw_total_2011_2040_HadGEM2 <- stack(brick01_HadGEM2, brick02_HadGEM2, brick03_HadGEM2) # 360 layers
brick_raw_total_2011_2040_MIROC5 <- stack(brick01_MIROC5, brick02_MIROC5, brick03_MIROC5) # 360 layers
brick_raw_total_2011_2040_EARTH <- stack(brick01_EARTH, brick02_EARTH, brick03_EARTH) # 360 layers
brick_raw_total_2011_2040_MPI <- stack(brick01_MPI, brick02_MPI, brick03_MPI) # 360 layers
brick_raw_total_2011_2040_CanESM2 <- stack(brick01_CanESM2, brick02_CanESM2, brick03_CanESM2) # 360 layers
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# 2041-2070 NetCDF files are open
brick_raw_total_2041_2070_PRECIS <- stack(ncin_rcp85_2041_2070_PRECIS) # 360 layers
brick_raw_total_2041_2070_HadGEM2 <- stack(brick04_HadGEM2, brick05_HadGEM2, brick06_HadGEM2) # 360 layers
brick_raw_total_2041_2070_MIROC5 <- stack(brick04_MIROC5, brick05_MIROC5, brick06_MIROC5) # 360 layers
brick_raw_total_2041_2070_EARTH <- stack(brick04_EARTH, brick05_EARTH, brick06_EARTH) # 360 layers
brick_raw_total_2041_2070_MPI <- stack(brick04_MPI, brick05_MPI, brick06_MPI) # 360 layers
brick_raw_total_2041_2070_CanESM2 <- stack(brick04_CanESM2, brick05_CanESM2, brick06_CanESM2) # 360 layers
#----------------------------------------------------------------------------------------------------------------------------------------	

#----------------------------------------------------------------------------------------------------------------------------------------	
# 2071-2100 NetCDF files are open
brick_raw_total_2071_2100_PRECIS <- stack(ncin_rcp85_2071_2100_PRECIS[[1:347]], brick09_EARTH[[108:120]]) # 360 layers
brick_raw_total_2071_2100_HadGEM2 <- stack(brick07_HadGEM2, brick08_HadGEM2, brick09_HadGEM2[[1:107]],brick09_EARTH[[108:120]]) # 360 layers
brick_raw_total_2071_2100_MIROC5 <- stack(brick07_MIROC5, brick08_MIROC5, brick09_MIROC5) # 360 layers
brick_raw_total_2071_2100_EARTH <- stack(brick07_EARTH, brick08_EARTH, brick09_EARTH) # 360 layers
brick_raw_total_2071_2100_MPI <- stack(brick07_MPI, brick08_MPI, brick09_MPI) # 360 layers
brick_raw_total_2071_2100_CanESM2 <- stack(brick07_CanESM2, brick08_CanESM2, brick09_CanESM2) # 360 layers
#----------------------------------------------------------------------------------------------------------------------------------------	

# Historical 1961-1990 date vector is created
dates_hist <- seq(as.Date("1961-01-01"), as.Date("1990-12-31"), by = "1 month")
dates_1951_1980 <- seq(as.Date("1951-01-01"), as.Date("1980-12-31"), by = "1 month")
dates_1961_1990 <- seq(as.Date("1961-01-01"), as.Date("1990-12-31"), by = "1 month")
dates_1981_1995 <- seq(as.Date("1981-01-01"), as.Date("1995-12-31"), by = "1 month")
dates_1991_2005 <- seq(as.Date("1991-01-01"), as.Date("2005-12-31"), by = "1 month")
dates_2011_2040 <- seq(as.Date("2011-01-01"), as.Date("2040-12-31"), by = "1 month")
dates_2041_2070 <- seq(as.Date("2041-01-01"), as.Date("2070-12-31"), by = "1 month")
dates_2071_2100 <- seq(as.Date("2071-01-01"), as.Date("2100-12-31"), by = "1 month")

# Dates are -printed- into period 2011_2040
# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
brick_raw_total_2011_2040_PRECIS <- setZ(brick_raw_total_2011_2040_PRECIS, dates_2011_2040, name="time")
brick_raw_total_2011_2040_HadGEM2 <- setZ(brick_raw_total_2011_2040_HadGEM2, dates_2011_2040, name="time")
brick_raw_total_2011_2040_MIROC5 <- setZ(brick_raw_total_2011_2040_MIROC5, dates_2011_2040, name="time")
brick_raw_total_2011_2040_EARTH <- setZ(brick_raw_total_2011_2040_EARTH, dates_2011_2040, name="time")
brick_raw_total_2011_2040_MPI <- setZ(brick_raw_total_2011_2040_MPI, dates_2011_2040, name="time")
brick_raw_total_2011_2040_CanESM2 <- setZ(brick_raw_total_2011_2040_CanESM2, dates_2011_2040, name="time")

# Dates are -printed- into period 2041_2070
# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
brick_raw_total_2041_2070_PRECIS <- setZ(brick_raw_total_2041_2070_PRECIS, dates_2041_2070, name="time")
brick_raw_total_2041_2070_HadGEM2 <- setZ(brick_raw_total_2041_2070_HadGEM2, dates_2041_2070, name="time")
brick_raw_total_2041_2070_MIROC5 <- setZ(brick_raw_total_2041_2070_MIROC5, dates_2041_2070, name="time")
brick_raw_total_2041_2070_EARTH <- setZ(brick_raw_total_2041_2070_EARTH, dates_2041_2070, name="time")
brick_raw_total_2041_2070_MPI <- setZ(brick_raw_total_2041_2070_MPI, dates_2041_2070, name="time")
brick_raw_total_2041_2070_CanESM2 <- setZ(brick_raw_total_2041_2070_CanESM2, dates_2041_2070, name="time")

# Dates are -printed- into period 2071_2100
# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
brick_raw_total_2071_2100_PRECIS <- setZ(brick_raw_total_2071_2100_PRECIS, dates_2071_2100, name="time")
brick_raw_total_2071_2100_HadGEM2 <- setZ(brick_raw_total_2071_2100_HadGEM2, dates_2071_2100, name="time")
brick_raw_total_2071_2100_MIROC5 <- setZ(brick_raw_total_2071_2100_MIROC5, dates_2071_2100, name="time")
brick_raw_total_2071_2100_EARTH <- setZ(brick_raw_total_2071_2100_EARTH, dates_2071_2100, name="time")
brick_raw_total_2071_2100_MPI <- setZ(brick_raw_total_2071_2100_MPI, dates_2071_2100, name="time")
brick_raw_total_2071_2100_CanESM2 <- setZ(brick_raw_total_2071_2100_CanESM2, dates_2071_2100, name="time")

#----------------------------------------------------------------------------------------------------------------------------------------
# RasterLayer is exported to GeoTIFF format
# 2011_2040 dataset
writeRaster(brick_raw_total_2011_2040_PRECIS, "rcp85_raw_crtm05_PRECIS_2011_2040.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2011_2040_HadGEM2, "rcp85_raw_crtm05_HadGEM2_2011_2040.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2011_2040_MIROC5, "rcp85_raw_crtm05_MIROC5_2011_2040.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2011_2040_EARTH, "rcp85_raw_crtm05_EARTH_2011_2040.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2011_2040_MPI, "rcp85_raw_crtm05_MPI_2011_2040.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2011_2040_CanESM2, "rcp85_raw_crtm05_CanESM2_2011_2040.tif", format="GTiff", overwrite=TRUE)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# RasterLayer is exported to GeoTIFF format
# 2041_2070 dataset
writeRaster(brick_raw_total_2041_2070_PRECIS, "rcp85_raw_crtm05_PRECIS_2041_2070.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2041_2070_HadGEM2, "rcp85_raw_crtm05_HadGEM2_2041_2070.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2041_2070_MIROC5, "rcp85_raw_crtm05_MIROC5_2041_2070.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2041_2070_EARTH, "rcp85_raw_crtm05_EARTH_2041_2070.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2041_2070_MPI, "rcp85_raw_crtm05_MPI_2041_2070.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2041_2070_CanESM2, "rcp85_raw_crtm05_CanESM2_2041_2070.tif", format="GTiff", overwrite=TRUE)
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# RasterLayer is exported to GeoTIFF format
# 2071_2100 dataset
writeRaster(brick_raw_total_2071_2100_PRECIS, "rcp85_raw_crtm05_PRECIS_2071_2100.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2071_2100_HadGEM2, "rcp85_raw_crtm05_HadGEM2_2071_2100.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2071_2100_MIROC5, "rcp85_raw_crtm05_MIROC5_2071_2100.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2071_2100_EARTH, "rcp85_raw_crtm05_EARTH_2071_2100.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2071_2100_MPI, "rcp85_raw_crtm05_MPI_2071_2100.tif", format="GTiff", overwrite=TRUE)
writeRaster(brick_raw_total_2071_2100_CanESM2, "rcp85_raw_crtm05_CanESM2_2071_2100.tif", format="GTiff", overwrite=TRUE)
#----------------------------------------------------------------------------------------------------------------------------------------

# /////////////////////////////////////////////////////////////////////////////////////
# BLOCK: NetCDF transformation
# /////////////////////////////////////////////////////////////////////////////////////

#------------------------------------------------------------------------------
# RasterStack object is externally exported to NetCDF
# BEWARE: This is an extremelly slow operation !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
# BEWARE: CRTM05 !!!!
#------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# RasterLayer is exported to netCDF format
# 2011_2040 dataset
writeRaster(brick_raw_total_2011_2040_PRECIS, "rcp85_raw_crtm05_PRECIS_2011_2040.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2011_2040_HadGEM2, "rcp85_raw_crtm05_HadGEM2_2011_2040.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2011_2040_MIROC5, "rcp85_raw_crtm05_MIROC5_2011_2040.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2011_2040_EARTH, "rcp85_raw_crtm05_EARTH_2011_2040.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2011_2040_MPI, "rcp85_raw_crtm05_MPI_2011_2040.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2011_2040_CanESM2, "rcp85_raw_crtm05_CanESM2_2011_2040.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# RasterLayer is exported to netCDF format
# 2041_2070 dataset
writeRaster(brick_raw_total_2041_2070_PRECIS, "rcp85_raw_crtm05_PRECIS_2041_2070.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2041_2070_HadGEM2, "rcp85_raw_crtm05_HadGEM2_2041_2070.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2041_2070_MIROC5, "rcp85_raw_crtm05_MIROC5_2041_2070.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2041_2070_EARTH, "rcp85_raw_crtm05_EARTH_2041_2070.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2041_2070_MPI, "rcp85_raw_crtm05_MPI_2041_2070.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2041_2070_CanESM2, "rcp85_raw_crtm05_CanESM2_2041_2070.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
#----------------------------------------------------------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------------------------------------------------------
# RasterLayer is exported to netCDF format
# 2071_2100 dataset
writeRaster(brick_raw_total_2071_2100_PRECIS, "rcp85_raw_crtm05_PRECIS_2071_2100.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2071_2100_HadGEM2, "rcp85_raw_crtm05_HadGEM2_2071_2100.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2071_2100_MIROC5, "rcp85_raw_crtm05_MIROC5_2071_2100.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2071_2100_EARTH, "rcp85_raw_crtm05_EARTH_2071_2100.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2071_2100_MPI, "rcp85_raw_crtm05_MPI_2071_2100.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
writeRaster(brick_raw_total_2071_2100_CanESM2, "rcp85_raw_crtm05_CanESM2_2071_2100.nc", format = "CDF", overwrite = TRUE, varname = "Precipitation", varunit = "mm", longname = "totals", xname = "lon", yname = "lat", zname = "time", zunit = "numeric")
#----------------------------------------------------------------------------------------------------------------------------------------

# ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
# BLOCK: Execution of Bias Correction by loadeR/downscaleR 
# ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

V.select.month <- c("JAN", "FEB", "MAR", "APR", "MAY", "JUN", "JUL", "AUG", "SEP", "OCT", "NOV", "DEC")


for(i in 1:12) { # Main loop is initiated
  
  # Month of the year MUST be manually selected
  #i = ((1))
  
  # loadNcdf {hyfo} is used to load generic R NetCDF objects for the period 1961_1990
  #--------------------------------------------------------------------------------------------------------------------------------------
  St_ncin_hist_1961_1990_IMN <- loadNcdf(filePath="hist_1961_1990_IMN.nc", varname="Precipitation", year = 1961:1990, month = i) #c(1:12)
  St_ncin_hist_1961_1990_PRECIS <- loadNcdf(filePath="hist_1961_1990_PRECIS.nc", varname="Precipitation", year = 1961:1990, month = i) #c(1:12)
  St_ncin_hist_1961_1990_HadGEM2 <- loadNcdf(filePath="Raw_crtm05_HadGEM2_1961_1990.nc", varname="Precipitation", year = 1961:1990, month = i) #c(1:12)
  St_ncin_hist_1961_1990_MIROC <- loadNcdf(filePath="Raw_crtm05_MIROC5_1961_1990.nc", varname="Precipitation", year = 1961:1990, month = i) #c(1:12)
  St_ncin_hist_1961_1990_EARTH <- loadNcdf(filePath="Raw_crtm05_EARTH_1961_1990.nc", varname="Precipitation", year = 1961:1990, month = i) #c(1:12)
  St_ncin_hist_1961_1990_MPI <- loadNcdf(filePath="Raw_crtm05_MPI_1961_1990.nc", varname="Precipitation", year = 1961:1990, month = i) #c(1:12)
  St_ncin_hist_1961_1990_CanESM2 <- loadNcdf(filePath="Raw_crtm05_CanESM2_1961_1990.nc", varname="Precipitation", year = 1961:1990, month = i) #c(1:12)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # loadNcdf {hyfo} is used to load generic R NetCDF objects for the period 2011_2040
  #--------------------------------------------------------------------------------------------------------------------------------------
  St_ncin_rcp85_raw_crtm05_PRECIS_2011_2040 <- loadNcdf(filePath="rcp85_raw_crtm05_PRECIS_2011_2040.nc", varname="Precipitation", year = 2011:2040, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_HadGEM2_2011_2040 <- loadNcdf(filePath="rcp85_raw_crtm05_HadGEM2_2011_2040.nc", varname="Precipitation", year = 2011:2040, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_MIROC5_2011_2040 <- loadNcdf(filePath="rcp85_raw_crtm05_MIROC5_2011_2040.nc", varname="Precipitation", year = 2011:2040, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_EARTH_2011_2040 <- loadNcdf(filePath="rcp85_raw_crtm05_EARTH_2011_2040.nc", varname="Precipitation", year = 2011:2040, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_MPI_2011_2040 <- loadNcdf(filePath="rcp85_raw_crtm05_MPI_2011_2040.nc", varname="Precipitation", year = 2011:2040, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_CanESM2_2011_2040 <- loadNcdf(filePath="rcp85_raw_crtm05_CanESM2_2011_2040.nc", varname="Precipitation", year = 2011:2040, month = i) #c(1:12)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # loadNcdf {hyfo} is used to load generic R NetCDF objects for the period 2041_2070
  #--------------------------------------------------------------------------------------------------------------------------------------
  St_ncin_rcp85_raw_crtm05_PRECIS_2041_2070 <- loadNcdf(filePath="rcp85_raw_crtm05_PRECIS_2041_2070.nc", varname="Precipitation", year = 2041:2070, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_HadGEM2_2041_2070 <- loadNcdf(filePath="rcp85_raw_crtm05_HadGEM2_2041_2070.nc", varname="Precipitation", year = 2041:2070, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_MIROC5_2041_2070 <- loadNcdf(filePath="rcp85_raw_crtm05_MIROC5_2041_2070.nc", varname="Precipitation", year = 2041:2070, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_EARTH_2041_2070 <- loadNcdf(filePath="rcp85_raw_crtm05_EARTH_2041_2070.nc", varname="Precipitation", year = 2041:2070, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_MPI_2041_2070 <- loadNcdf(filePath="rcp85_raw_crtm05_MPI_2041_2070.nc", varname="Precipitation", year = 2041:2070, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_CanESM2_2041_2070 <- loadNcdf(filePath="rcp85_raw_crtm05_CanESM2_2041_2070.nc", varname="Precipitation", year = 2041:2070, month = i) #c(1:12)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # loadNcdf {hyfo} is used to load generic R NetCDF objects for the period 2071_2100
  #--------------------------------------------------------------------------------------------------------------------------------------
  St_ncin_rcp85_raw_crtm05_PRECIS_2071_2100 <- loadNcdf(filePath="rcp85_raw_crtm05_PRECIS_2071_2100.nc", varname="Precipitation", year = 2071:2100, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_HadGEM2_2071_2100 <- loadNcdf(filePath="rcp85_raw_crtm05_HadGEM2_2071_2100.nc", varname="Precipitation", year = 2071:2100, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_MIROC5_2071_2100 <- loadNcdf(filePath="rcp85_raw_crtm05_MIROC5_2071_2100.nc", varname="Precipitation", year = 2071:2100, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_EARTH_2071_2100 <- loadNcdf(filePath="rcp85_raw_crtm05_EARTH_2071_2100.nc", varname="Precipitation", year = 2071:2100, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_MPI_2071_2100 <- loadNcdf(filePath="rcp85_raw_crtm05_MPI_2071_2100.nc", varname="Precipitation", year = 2071:2100, month = i) #c(1:12)
  St_ncin_rcp85_raw_crtm05_CanESM2_2071_2100 <- loadNcdf(filePath="rcp85_raw_crtm05_CanESM2_2071_2100.nc", varname="Precipitation", year = 2071:2100, month = i) #c(1:12)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # Corresponding WGS84 XY coordinates are converted from CRTM05 via ILWIS-GIS
  xxd <- c(-85.95864235, -85.72982083, -85.5009705,-85.27209516,-85.04319862,-84.81428469,-84.58535719,-84.35641994,-84.12747674,-83.89853141,-83.66958778,-83.44064966,-83.21172086,-82.9828052,-82.75390649,-82.52502855)
  yyd <- c(11.21234599,10.98639046,10.76043146,10.53446907,10.30850336,10.08253438,9.856562224,9.630586943,9.404608612,9.178627299,8.952643074,8.726656006,8.500666165,8.274673621,8.048678443)
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # {hyfo} Lists XY CRTM05 coordinates are replaced by WGS84 for 1961_1990 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  St_ncin_hist_1961_1990_IMN$xyCoords$x <- (xxd)
  St_ncin_hist_1961_1990_IMN$xyCoords$y <- (yyd)
  St_ncin_hist_1961_1990_PRECIS$xyCoords$x <- (xxd)
  St_ncin_hist_1961_1990_PRECIS$xyCoords$y <- (yyd)
  St_ncin_hist_1961_1990_CanESM2$xyCoords$x <- (xxd)
  St_ncin_hist_1961_1990_CanESM2$xyCoords$y <- (yyd)
  St_ncin_hist_1961_1990_MIROC$xyCoords$x <- (xxd)
  St_ncin_hist_1961_1990_MIROC$xyCoords$y <- (yyd)
  St_ncin_hist_1961_1990_EARTH$xyCoords$x <- (xxd)
  St_ncin_hist_1961_1990_EARTH$xyCoords$y <- (yyd)
  St_ncin_hist_1961_1990_HadGEM2$xyCoords$x <- (xxd)
  St_ncin_hist_1961_1990_HadGEM2$xyCoords$y <- (yyd)
  St_ncin_hist_1961_1990_MPI$xyCoords$x <- (xxd)
  St_ncin_hist_1961_1990_MPI$xyCoords$y <- (yyd)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # {hyfo} Lists XY CRTM05 coordinates are replaced by WGS84 for 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  St_ncin_rcp85_raw_crtm05_PRECIS_2011_2040$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_HadGEM2_2011_2040$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_MIROC5_2011_2040$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_EARTH_2011_2040$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_MPI_2011_2040$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_CanESM2_2011_2040$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_PRECIS_2011_2040$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_HadGEM2_2011_2040$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_MIROC5_2011_2040$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_EARTH_2011_2040$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_MPI_2011_2040$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_CanESM2_2011_2040$xyCoords$y <- (yyd)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # {hyfo} Lists XY CRTM05 coordinates are replaced by WGS84 for 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  St_ncin_rcp85_raw_crtm05_PRECIS_2041_2070$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_HadGEM2_2041_2070$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_MIROC5_2041_2070$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_EARTH_2041_2070$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_MPI_2041_2070$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_CanESM2_2041_2070$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_PRECIS_2041_2070$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_HadGEM2_2041_2070$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_MIROC5_2041_2070$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_EARTH_2041_2070$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_MPI_2041_2070$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_CanESM2_2041_2070$xyCoords$y <- (yyd)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # {hyfo} Lists XY CRTM05 coordinates are replaced by WGS84 for 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  St_ncin_rcp85_raw_crtm05_PRECIS_2071_2100$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_HadGEM2_2071_2100$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_MIROC5_2071_2100$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_EARTH_2071_2100$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_MPI_2071_2100$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_CanESM2_2071_2100$xyCoords$x <- (xxd)
  St_ncin_rcp85_raw_crtm05_PRECIS_2071_2100$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_HadGEM2_2071_2100$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_MIROC5_2071_2100$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_EARTH_2071_2100$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_MPI_2071_2100$xyCoords$y <- (yyd)
  St_ncin_rcp85_raw_crtm05_CanESM2_2071_2100$xyCoords$y <- (yyd)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # {hyfo} Lists lat/long name attribues are re-printed within list-objects for 1961_1990 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  names(St_ncin_hist_1961_1990_IMN$xyCoords$x) <- c("lon")
  names(St_ncin_hist_1961_1990_IMN$xyCoords$y) <- c("lat")
  names(St_ncin_hist_1961_1990_PRECIS$xyCoords$x) <- c("lon")
  names(St_ncin_hist_1961_1990_PRECIS$xyCoords$y) <- c("lat")
  names(St_ncin_hist_1961_1990_CanESM2$xyCoords$x) <- c("lon")
  names(St_ncin_hist_1961_1990_CanESM2$xyCoords$y) <- c("lat")
  names(St_ncin_hist_1961_1990_MIROC$xyCoords$x) <- c("lon")
  names(St_ncin_hist_1961_1990_MIROC$xyCoords$y) <- c("lat")
  names(St_ncin_hist_1961_1990_EARTH$xyCoords$x) <- c("lon")
  names(St_ncin_hist_1961_1990_EARTH$xyCoords$y) <- c("lat")
  names(St_ncin_hist_1961_1990_HadGEM2$xyCoords$x) <- c("lon")
  names(St_ncin_hist_1961_1990_HadGEM2$xyCoords$y) <- c("lat")
  names(St_ncin_hist_1961_1990_MPI$xyCoords$x) <- c("lon")
  names(St_ncin_hist_1961_1990_MPI$xyCoords$y) <- c("lat")
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # {hyfo} Lists lat/long name attribues are re-printed within list-objects for 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  names(St_ncin_rcp85_raw_crtm05_PRECIS_2011_2040$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_HadGEM2_2011_2040$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_MIROC5_2011_2040$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_EARTH_2011_2040$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_MPI_2011_2040$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_CanESM2_2011_2040$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_PRECIS_2011_2040$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_HadGEM2_2011_2040$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_MIROC5_2011_2040$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_EARTH_2011_2040$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_MPI_2011_2040$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_CanESM2_2011_2040$xyCoords$y) <- c("lat")
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # {hyfo} Lists lat/long name attribues are re-printed within list-objects for 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  names(St_ncin_rcp85_raw_crtm05_PRECIS_2041_2070$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_HadGEM2_2041_2070$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_MIROC5_2041_2070$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_EARTH_2041_2070$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_MPI_2041_2070$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_CanESM2_2041_2070$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_PRECIS_2041_2070$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_HadGEM2_2041_2070$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_MIROC5_2041_2070$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_EARTH_2041_2070$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_MPI_2041_2070$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_CanESM2_2041_2070$xyCoords$y) <- c("lat")
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # {hyfo} Lists lat/long name attribues are re-printed within list-objects for 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  names(St_ncin_rcp85_raw_crtm05_PRECIS_2071_2100$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_HadGEM2_2071_2100$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_MIROC5_2071_2100$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_EARTH_2071_2100$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_MPI_2071_2100$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_CanESM2_2071_2100$xyCoords$x ) <- c("lon")
  names(St_ncin_rcp85_raw_crtm05_PRECIS_2071_2100$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_HadGEM2_2071_2100$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_MIROC5_2071_2100$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_EARTH_2071_2100$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_MPI_2071_2100$xyCoords$y) <- c("lat")
  names(St_ncin_rcp85_raw_crtm05_CanESM2_2071_2100$xyCoords$y) <- c("lat")
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # writeNcdf {hyfo} is used to externally saved NetCDF version 4.0 for 1961_1990 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeNcdf(gridData = St_ncin_hist_1961_1990_IMN, filePath = "St_ncin_hist_1961_1990_IMN.nc", version = 4)
  writeNcdf(gridData = St_ncin_hist_1961_1990_PRECIS, filePath = "St_ncin_hist_1961_1990_PRECIS.nc", version = 4)
  writeNcdf(gridData = St_ncin_hist_1961_1990_CanESM2, filePath = "St_ncin_hist_1961_1990_CanESM2.nc", version = 4)
  writeNcdf(gridData = St_ncin_hist_1961_1990_MIROC, filePath = "St_ncin_hist_1961_1990_MIROC.nc", version = 4)
  writeNcdf(gridData = St_ncin_hist_1961_1990_EARTH, filePath = "St_ncin_hist_1961_1990_EARTH.nc", version = 4)
  writeNcdf(gridData = St_ncin_hist_1961_1990_HadGEM2, filePath = "St_ncin_hist_1961_1990_HadGEM2.nc", version = 4)
  writeNcdf(gridData = St_ncin_hist_1961_1990_MPI, filePath = "St_ncin_hist_1961_1990_MPI.nc", version = 4)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # writeNcdf {hyfo} is used to externally saved NetCDF version 4.0 for 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_PRECIS_2011_2040, filePath = "St_ncin_rcp85_raw_crtm05_PRECIS_2011_2040.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_HadGEM2_2011_2040, filePath = "St_ncin_rcp85_raw_crtm05_HadGEM2_2011_2040.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_MIROC5_2011_2040, filePath = "St_ncin_rcp85_raw_crtm05_MIROC5_2011_2040.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_EARTH_2011_2040, filePath = "St_ncin_rcp85_raw_crtm05_EARTH_2011_2040.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_MPI_2011_2040, filePath = "St_ncin_rcp85_raw_crtm05_MPI_2011_2040.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_CanESM2_2011_2040, filePath = "St_ncin_rcp85_raw_crtm05_CanESM2_2011_2040.nc", version = 4)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # writeNcdf {hyfo} is used to externally saved NetCDF version 4.0 for 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_PRECIS_2041_2070, filePath = "St_ncin_rcp85_raw_crtm05_PRECIS_2041_2070.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_HadGEM2_2041_2070, filePath = "St_ncin_rcp85_raw_crtm05_HadGEM2_2041_2070.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_MIROC5_2041_2070, filePath = "St_ncin_rcp85_raw_crtm05_MIROC5_2041_2070.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_EARTH_2041_2070, filePath = "St_ncin_rcp85_raw_crtm05_EARTH_2041_2070.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_MPI_2041_2070, filePath = "St_ncin_rcp85_raw_crtm05_MPI_2041_2070.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_CanESM2_2041_2070, filePath = "St_ncin_rcp85_raw_crtm05_CanESM2_2041_2070.nc", version = 4)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # writeNcdf {hyfo} is used to externally saved NetCDF version 4.0 for 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_PRECIS_2071_2100, filePath = "St_ncin_rcp85_raw_crtm05_PRECIS_2071_2100.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_HadGEM2_2071_2100, filePath = "St_ncin_rcp85_raw_crtm05_HadGEM2_2071_2100.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_MIROC5_2071_2100, filePath = "St_ncin_rcp85_raw_crtm05_MIROC5_2071_2100.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_EARTH_2071_2100, filePath = "St_ncin_rcp85_raw_crtm05_EARTH_2071_2100.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_MPI_2071_2100, filePath = "St_ncin_rcp85_raw_crtm05_MPI_2071_2100.nc", version = 4)
  writeNcdf(gridData = St_ncin_rcp85_raw_crtm05_CanESM2_2071_2100, filePath = "St_ncin_rcp85_raw_crtm05_CanESM2_2071_2100.nc", version = 4)
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # loadeR::dataInventory {loadeR} is used to check the NetCDF integrity within Santander-Group 
  loadeR::dataInventory("St_ncin_hist_1961_1990_PRECIS.nc")
  loadeR::dataInventory("St_ncin_hist_1961_1990_CanESM2.nc")
  loadeR::dataInventory("St_ncin_rcp85_raw_crtm05_PRECIS_2011_2040.nc")
  loadeR::dataInventory("St_ncin_rcp85_raw_crtm05_HadGEM2_2011_2040.nc")
  loadeR::dataInventory("St_ncin_rcp85_raw_crtm05_MIROC5_2011_2040.nc")
  loadeR::dataInventory("St_ncin_rcp85_raw_crtm05_EARTH_2011_2040.nc")
  loadeR::dataInventory("St_ncin_rcp85_raw_crtm05_MPI_2011_2040.nc")
  loadeR::dataInventory("St_ncin_rcp85_raw_crtm05_CanESM2_2011_2040.nc")
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # loadGridData {loadeR} is used to create Santander-Group NetCDF binary lists for 1961_1990 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  SANT_ncin_hist_1961_1990_IMN <- loadGridData("St_ncin_hist_1961_1990_IMN.nc", var = "Precipitation")
  SANT_ncin_hist_1961_1990_PRECIS <- loadGridData("St_ncin_hist_1961_1990_PRECIS.nc", var = "Precipitation")
  SANT_ncin_hist_1961_1990_CanESM2 <- loadGridData("St_ncin_hist_1961_1990_CanESM2.nc", var = "Precipitation")
  SANT_ncin_hist_1961_1990_MIROC <- loadGridData("St_ncin_hist_1961_1990_MIROC.nc", var = "Precipitation")
  SANT_ncin_hist_1961_1990_EARTH <- loadGridData("St_ncin_hist_1961_1990_EARTH.nc", var = "Precipitation")
  SANT_ncin_hist_1961_1990_HadGEM2 <- loadGridData("St_ncin_hist_1961_1990_HadGEM2.nc", var = "Precipitation")
  SANT_ncin_hist_1961_1990_MPI <- loadGridData("St_ncin_hist_1961_1990_MPI.nc", var = "Precipitation")
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # loadGridData {loadeR} is used to create Santander-Group NetCDF binary lists for 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  SANT_ncin_rcp85_raw_crtm05_PRECIS_2011_2040 <- loadGridData("St_ncin_rcp85_raw_crtm05_PRECIS_2011_2040.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_HadGEM2_2011_2040 <- loadGridData("St_ncin_rcp85_raw_crtm05_HadGEM2_2011_2040.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_MIROC5_2011_2040 <- loadGridData("St_ncin_rcp85_raw_crtm05_MIROC5_2011_2040.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_EARTH_2011_2040 <- loadGridData("St_ncin_rcp85_raw_crtm05_EARTH_2011_2040.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_MPI_2011_2040 <- loadGridData("St_ncin_rcp85_raw_crtm05_MPI_2011_2040.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_CanESM2_2011_2040 <- loadGridData("St_ncin_rcp85_raw_crtm05_CanESM2_2011_2040.nc", var = "Precipitation")
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # loadGridData {loadeR} is used to create Santander-Group NetCDF binary lists for 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  SANT_ncin_rcp85_raw_crtm05_PRECIS_2041_2070 <- loadGridData("St_ncin_rcp85_raw_crtm05_PRECIS_2041_2070.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_HadGEM2_2041_2070 <- loadGridData("St_ncin_rcp85_raw_crtm05_HadGEM2_2041_2070.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_MIROC5_2041_2070 <- loadGridData("St_ncin_rcp85_raw_crtm05_MIROC5_2041_2070.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_EARTH_2041_2070 <- loadGridData("St_ncin_rcp85_raw_crtm05_EARTH_2041_2070.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_MPI_2041_2070 <- loadGridData("St_ncin_rcp85_raw_crtm05_MPI_2041_2070.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_CanESM2_2041_2070 <- loadGridData("St_ncin_rcp85_raw_crtm05_CanESM2_2041_2070.nc", var = "Precipitation")
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # loadGridData {loadeR} is used to create Santander-Group NetCDF binary lists for 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  SANT_ncin_rcp85_raw_crtm05_PRECIS_2071_2100 <- loadGridData("St_ncin_rcp85_raw_crtm05_PRECIS_2071_2100.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_HadGEM2_2071_2100 <- loadGridData("St_ncin_rcp85_raw_crtm05_HadGEM2_2071_2100.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_MIROC5_2071_2100 <- loadGridData("St_ncin_rcp85_raw_crtm05_MIROC5_2071_2100.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_EARTH_2071_2100 <- loadGridData("St_ncin_rcp85_raw_crtm05_EARTH_2071_2100.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_MPI_2071_2100 <- loadGridData("St_ncin_rcp85_raw_crtm05_MPI_2071_2100.nc", var = "Precipitation")
  SANT_ncin_rcp85_raw_crtm05_CanESM2_2071_2100 <- loadGridData("St_ncin_rcp85_raw_crtm05_CanESM2_2071_2100.nc", var = "Precipitation")
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # Temporary NetCDF files created by grid2nc {loadeR.2nc} are removed
  #--------------------------------------------------------------------------------------------------------------------------------------
  file.remove("Temporal_PRECIS_2011_2040.DELTA.BC")
  file.remove("Temporal_HadGEM2_2011_2040.DELTA.BC") 
  file.remove("Temporal_MIROC5_2011_2040.DELTA.BC") 
  file.remove("Temporal_EARTH_2011_2040.DELTA.BC") 
  file.remove("Temporal_MPI_2011_2040.DELTA.BC") 
  file.remove("Temporal_CanESM2_2011_2040.DELTA.BC") 
  
  file.remove("Temporal_PRECIS_2041_2070.DELTA.BC")
  file.remove("Temporal_HadGEM2_2041_2070.DELTA.BC")
  file.remove("Temporal_MIROC5_2041_2070.DELTA.BC")
  file.remove("Temporal_EARTH_2041_2070.DELTA.BC")
  file.remove("Temporal_MPI_2041_2070.DELTA.BC")
  file.remove("Temporal_CanESM2_2041_2070.DELTA.BC") 
  
  file.remove("Temporal_PRECIS_2071_2100.DELTA.BC")
  file.remove("Temporal_HadGEM2_2071_2100.DELTA.BC")
  file.remove("Temporal_MIROC5_2071_2100.DELTA.BC")
  file.remove("Temporal_EARTH_2071_2100.DELTA.BC")
  file.remove("Temporal_MPI_2071_2100.DELTA.BC")
  file.remove("Temporal_CanESM2_2071_2100.DELTA.BC")
  
  file.remove("Temporal_PRECIS_2011_2040.PTR.BC")
  file.remove("Temporal_HadGEM2_2011_2040.PTR.BC")
  file.remove("Temporal_MIROC5_2011_2040.PTR.BC")
  file.remove("Temporal_EARTH_2011_2040.PTR.BC")
  file.remove("Temporal_MPI_2011_2040.PTR.BC")
  file.remove("Temporal_CanESM2_2011_2040.PTR.BC")
  
  file.remove("Temporal_PRECIS_2041_2070.PTR.BC")
  file.remove("Temporal_HadGEM2_2041_2070.PTR.BC")
  file.remove("Temporal_MIROC5_2041_2070.PTR.BC")
  file.remove("Temporal_EARTH_2041_2070.PTR.BC")
  file.remove("Temporal_MPI_2041_2070.PTR.BC")
  file.remove("Temporal_CanESM2_2041_2070.PTR.BC")
  
  file.remove("Temporal_PRECIS_2071_2100.PTR.BC")
  file.remove("Temporal_HadGEM2_2071_2100.PTR.BC")
  file.remove("Temporal_MIROC5_2071_2100.PTR.BC")
  file.remove("Temporal_EARTH_2071_2100.PTR.BC")
  file.remove("Temporal_MPI_2071_2100.PTR.BC")
  file.remove("Temporal_CanESM2_2071_2100.PTR.BC")
  
  file.remove("Temporal_PRECIS_2011_2040.EQM.BC")
  file.remove("Temporal_HadGEM2_2011_2040.EQM.BC")
  file.remove("Temporal_MIROC5_2011_2040.EQM.BC")
  file.remove("Temporal_EARTH_2011_2040.EQM.BC")
  file.remove("Temporal_MPI_2011_2040.EQM.BC")
  file.remove("Temporal_CanESM2_2011_2040.EQM.BC")
  
  file.remove("Temporal_PRECIS_2041_2070.EQM.BC")
  file.remove("Temporal_HadGEM2_2041_2070.EQM.BC")
  file.remove("Temporal_MIROC5_2041_2070.EQM.BC")
  file.remove("Temporal_EARTH_2041_2070.EQM.BC")
  file.remove("Temporal_MPI_2041_2070.EQM.BC")
  file.remove("Temporal_CanESM2_2041_2070.EQM.BC")
  
  file.remove("Temporal_PRECIS_2071_2100.EQM.BC")
  file.remove("Temporal_HadGEM2_2071_2100.EQM.BC")
  file.remove("Temporal_MIROC5_2071_2100.EQM.BC")
  file.remove("Temporal_EARTH_2071_2100.EQM.BC")
  file.remove("Temporal_MPI_2071_2100.EQM.BC")
  file.remove("Temporal_CanESM2_2071_2100.EQM.BC")
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # biasCorrection {downscaleR} is used for bias correction according to Santander-Group
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2011_2040.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_PRECIS, newdata = SANT_ncin_rcp85_raw_crtm05_PRECIS_2011_2040, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_HadGEM2_2011_2040.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_HadGEM2, newdata = SANT_ncin_rcp85_raw_crtm05_HadGEM2_2011_2040, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MIROC5_2011_2040.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MIROC, newdata = SANT_ncin_rcp85_raw_crtm05_MIROC5_2011_2040, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_EARTH_2011_2040.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_EARTH, newdata = SANT_ncin_rcp85_raw_crtm05_EARTH_2011_2040, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MPI_2011_2040.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MPI, newdata = SANT_ncin_rcp85_raw_crtm05_MPI_2011_2040, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_CanESM2_2011_2040.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_CanESM2, newdata = SANT_ncin_rcp85_raw_crtm05_CanESM2_2011_2040, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2041_2070.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_PRECIS, newdata = SANT_ncin_rcp85_raw_crtm05_PRECIS_2041_2070, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_HadGEM2_2041_2070.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_HadGEM2, newdata = SANT_ncin_rcp85_raw_crtm05_HadGEM2_2041_2070, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MIROC5_2041_2070.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MIROC, newdata = SANT_ncin_rcp85_raw_crtm05_MIROC5_2041_2070, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_EARTH_2041_2070.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_EARTH, newdata = SANT_ncin_rcp85_raw_crtm05_EARTH_2041_2070, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MPI_2041_2070.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MPI, newdata = SANT_ncin_rcp85_raw_crtm05_MPI_2041_2070, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_CanESM2_2041_2070.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_CanESM2, newdata = SANT_ncin_rcp85_raw_crtm05_CanESM2_2041_2070, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2071_2100.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_PRECIS, newdata = SANT_ncin_rcp85_raw_crtm05_PRECIS_2071_2100, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_HadGEM2_2071_2100.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_HadGEM2, newdata = SANT_ncin_rcp85_raw_crtm05_HadGEM2_2071_2100, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MIROC5_2071_2100.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MIROC, newdata = SANT_ncin_rcp85_raw_crtm05_MIROC5_2071_2100, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_EARTH_2071_2100.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_EARTH, newdata = SANT_ncin_rcp85_raw_crtm05_EARTH_2071_2100, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MPI_2071_2100.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MPI, newdata = SANT_ncin_rcp85_raw_crtm05_MPI_2071_2100, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_CanESM2_2071_2100.DELTA.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_CanESM2, newdata = SANT_ncin_rcp85_raw_crtm05_CanESM2_2071_2100, method = "delta", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  
  # ******************************
  # PTR
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2011_2040.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_PRECIS, newdata = SANT_ncin_rcp85_raw_crtm05_PRECIS_2011_2040, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_HadGEM2_2011_2040.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_HadGEM2, newdata = SANT_ncin_rcp85_raw_crtm05_HadGEM2_2011_2040, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MIROC5_2011_2040.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MIROC, newdata = SANT_ncin_rcp85_raw_crtm05_MIROC5_2011_2040, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_EARTH_2011_2040.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_EARTH, newdata = SANT_ncin_rcp85_raw_crtm05_EARTH_2011_2040, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MPI_2011_2040.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MPI, newdata = SANT_ncin_rcp85_raw_crtm05_MPI_2011_2040, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_CanESM2_2011_2040.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_CanESM2, newdata = SANT_ncin_rcp85_raw_crtm05_CanESM2_2011_2040, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2041_2070.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_PRECIS, newdata = SANT_ncin_rcp85_raw_crtm05_PRECIS_2041_2070, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_HadGEM2_2041_2070.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_HadGEM2, newdata = SANT_ncin_rcp85_raw_crtm05_HadGEM2_2041_2070, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MIROC5_2041_2070.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MIROC, newdata = SANT_ncin_rcp85_raw_crtm05_MIROC5_2041_2070, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_EARTH_2041_2070.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_EARTH, newdata = SANT_ncin_rcp85_raw_crtm05_EARTH_2041_2070, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MPI_2041_2070.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MPI, newdata = SANT_ncin_rcp85_raw_crtm05_MPI_2041_2070, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_CanESM2_2041_2070.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_CanESM2, newdata = SANT_ncin_rcp85_raw_crtm05_CanESM2_2041_2070, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2071_2100.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_PRECIS, newdata = SANT_ncin_rcp85_raw_crtm05_PRECIS_2071_2100, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_HadGEM2_2071_2100.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_HadGEM2, newdata = SANT_ncin_rcp85_raw_crtm05_HadGEM2_2071_2100, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MIROC5_2071_2100.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MIROC, newdata = SANT_ncin_rcp85_raw_crtm05_MIROC5_2071_2100, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_EARTH_2071_2100.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_EARTH, newdata = SANT_ncin_rcp85_raw_crtm05_EARTH_2071_2100, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MPI_2071_2100.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MPI, newdata = SANT_ncin_rcp85_raw_crtm05_MPI_2071_2100, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_CanESM2_2071_2100.PTR.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_CanESM2, newdata = SANT_ncin_rcp85_raw_crtm05_CanESM2_2071_2100, method = "ptr", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  
  # ******************************
  # EQM
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2011_2040.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_PRECIS, newdata = SANT_ncin_rcp85_raw_crtm05_PRECIS_2011_2040, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_HadGEM2_2011_2040.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_HadGEM2, newdata = SANT_ncin_rcp85_raw_crtm05_HadGEM2_2011_2040, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MIROC5_2011_2040.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MIROC, newdata = SANT_ncin_rcp85_raw_crtm05_MIROC5_2011_2040, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_EARTH_2011_2040.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_EARTH, newdata = SANT_ncin_rcp85_raw_crtm05_EARTH_2011_2040, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MPI_2011_2040.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MPI, newdata = SANT_ncin_rcp85_raw_crtm05_MPI_2011_2040, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_CanESM2_2011_2040.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_CanESM2, newdata = SANT_ncin_rcp85_raw_crtm05_CanESM2_2011_2040, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2041_2070.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_PRECIS, newdata = SANT_ncin_rcp85_raw_crtm05_PRECIS_2041_2070, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_HadGEM2_2041_2070.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_HadGEM2, newdata = SANT_ncin_rcp85_raw_crtm05_HadGEM2_2041_2070, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MIROC5_2041_2070.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MIROC, newdata = SANT_ncin_rcp85_raw_crtm05_MIROC5_2041_2070, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_EARTH_2041_2070.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_EARTH, newdata = SANT_ncin_rcp85_raw_crtm05_EARTH_2041_2070, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MPI_2041_2070.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MPI, newdata = SANT_ncin_rcp85_raw_crtm05_MPI_2041_2070, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_CanESM2_2041_2070.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_CanESM2, newdata = SANT_ncin_rcp85_raw_crtm05_CanESM2_2041_2070, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2071_2100.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_PRECIS, newdata = SANT_ncin_rcp85_raw_crtm05_PRECIS_2071_2100, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_HadGEM2_2071_2100.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_HadGEM2, newdata = SANT_ncin_rcp85_raw_crtm05_HadGEM2_2071_2100, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MIROC5_2071_2100.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MIROC, newdata = SANT_ncin_rcp85_raw_crtm05_MIROC5_2071_2100, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_EARTH_2071_2100.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_EARTH, newdata = SANT_ncin_rcp85_raw_crtm05_EARTH_2071_2100, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_MPI_2071_2100.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_MPI, newdata = SANT_ncin_rcp85_raw_crtm05_MPI_2071_2100, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  Temporal_CanESM2_2071_2100.EQM.BC <- biasCorrection(y = SANT_ncin_hist_1961_1990_IMN, x = SANT_ncin_hist_1961_1990_CanESM2, newdata = SANT_ncin_rcp85_raw_crtm05_CanESM2_2071_2100, method = "eqm", wet.threshold = 0, precipitation = TRUE, max.ncores = 16, ncores = 16)
  
  # Corresponding CRTM05 XY coordinates are converted from WGS84 via ILWIS-GIS
  xxOUT <- c(286080, 311080, 336080, 361080, 386080, 411080, 436080, 461080, 486080, 511080, 536080, 561080, 586080, 611080, 636080, 661080)
  yyOUT <- c(1240234, 1215234, 1190234, 1165234, 1140234, 1115234, 1090234, 1065234, 1040234, 1015234,  990234,  965234,  940234,  915234,  890234)
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # Santander-Group list coordinates Lists XY WGS84 coordinates are replaced by CRTM05
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2011_2040.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_HadGEM2_2011_2040.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_MIROC5_2011_2040.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_EARTH_2011_2040.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_MPI_2011_2040.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_CanESM2_2011_2040.DELTA.BC$xyCoords$x <- xxOUT
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2041_2070.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_HadGEM2_2041_2070.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_MIROC5_2041_2070.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_EARTH_2041_2070.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_MPI_2041_2070.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_CanESM2_2041_2070.DELTA.BC$xyCoords$x <- xxOUT
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2071_2100.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_HadGEM2_2071_2100.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_MIROC5_2071_2100.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_EARTH_2071_2100.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_MPI_2071_2100.DELTA.BC$xyCoords$x <- xxOUT
  Temporal_CanESM2_2071_2100.DELTA.BC$xyCoords$x <- xxOUT
  
  # ******************************
  # PTR
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2011_2040.PTR.BC$xyCoords$x <- xxOUT
  Temporal_HadGEM2_2011_2040.PTR.BC$xyCoords$x <- xxOUT
  Temporal_MIROC5_2011_2040.PTR.BC$xyCoords$x <- xxOUT
  Temporal_EARTH_2011_2040.PTR.BC$xyCoords$x <- xxOUT
  Temporal_MPI_2011_2040.PTR.BC$xyCoords$x <- xxOUT
  Temporal_CanESM2_2011_2040.PTR.BC$xyCoords$x <- xxOUT
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2041_2070.PTR.BC$xyCoords$x <- xxOUT
  Temporal_HadGEM2_2041_2070.PTR.BC$xyCoords$x <- xxOUT
  Temporal_MIROC5_2041_2070.PTR.BC$xyCoords$x <- xxOUT
  Temporal_EARTH_2041_2070.PTR.BC$xyCoords$x <- xxOUT
  Temporal_MPI_2041_2070.PTR.BC$xyCoords$x <- xxOUT
  Temporal_CanESM2_2041_2070.PTR.BC$xyCoords$x <- xxOUT
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2071_2100.PTR.BC$xyCoords$x <- xxOUT
  Temporal_HadGEM2_2071_2100.PTR.BC$xyCoords$x <- xxOUT
  Temporal_MIROC5_2071_2100.PTR.BC$xyCoords$x <- xxOUT
  Temporal_EARTH_2071_2100.PTR.BC$xyCoords$x <- xxOUT
  Temporal_MPI_2071_2100.PTR.BC$xyCoords$x <- xxOUT
  Temporal_CanESM2_2071_2100.PTR.BC$xyCoords$x <- xxOUT
  
  # ******************************
  # EQM
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2011_2040.EQM.BC$xyCoords$x <- xxOUT
  Temporal_HadGEM2_2011_2040.EQM.BC$xyCoords$x <- xxOUT
  Temporal_MIROC5_2011_2040.EQM.BC$xyCoords$x <- xxOUT
  Temporal_EARTH_2011_2040.EQM.BC$xyCoords$x <- xxOUT
  Temporal_MPI_2011_2040.EQM.BC$xyCoords$x <- xxOUT
  Temporal_CanESM2_2011_2040.EQM.BC$xyCoords$x <- xxOUT
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2041_2070.EQM.BC$xyCoords$x <- xxOUT
  Temporal_HadGEM2_2041_2070.EQM.BC$xyCoords$x <- xxOUT
  Temporal_MIROC5_2041_2070.EQM.BC$xyCoords$x <- xxOUT
  Temporal_EARTH_2041_2070.EQM.BC$xyCoords$x <- xxOUT
  Temporal_MPI_2041_2070.EQM.BC$xyCoords$x <- xxOUT
  Temporal_CanESM2_2041_2070.EQM.BC$xyCoords$x <- xxOUT
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2071_2100.EQM.BC$xyCoords$x <- xxOUT
  Temporal_HadGEM2_2071_2100.EQM.BC$xyCoords$x <- xxOUT
  Temporal_MIROC5_2071_2100.EQM.BC$xyCoords$x <- xxOUT
  Temporal_EARTH_2071_2100.EQM.BC$xyCoords$x <- xxOUT
  Temporal_MPI_2071_2100.EQM.BC$xyCoords$x <- xxOUT
  Temporal_CanESM2_2071_2100.EQM.BC$xyCoords$x <- xxOUT
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2011_2040.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_HadGEM2_2011_2040.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_MIROC5_2011_2040.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_EARTH_2011_2040.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_MPI_2011_2040.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_CanESM2_2011_2040.DELTA.BC$xyCoords$y <- yyOUT
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2041_2070.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_HadGEM2_2041_2070.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_MIROC5_2041_2070.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_EARTH_2041_2070.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_MPI_2041_2070.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_CanESM2_2041_2070.DELTA.BC$xyCoords$y <- yyOUT
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2071_2100.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_HadGEM2_2071_2100.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_MIROC5_2071_2100.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_EARTH_2071_2100.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_MPI_2071_2100.DELTA.BC$xyCoords$y <- yyOUT
  Temporal_CanESM2_2071_2100.DELTA.BC$xyCoords$y <- yyOUT
  
  # ******************************
  # PTR
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2011_2040.PTR.BC$xyCoords$y <- yyOUT
  Temporal_HadGEM2_2011_2040.PTR.BC$xyCoords$y <- yyOUT
  Temporal_MIROC5_2011_2040.PTR.BC$xyCoords$y <- yyOUT
  Temporal_EARTH_2011_2040.PTR.BC$xyCoords$y <- yyOUT
  Temporal_MPI_2011_2040.PTR.BC$xyCoords$y <- yyOUT
  Temporal_CanESM2_2011_2040.PTR.BC$xyCoords$y <- yyOUT
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2041_2070.PTR.BC$xyCoords$y <- yyOUT
  Temporal_HadGEM2_2041_2070.PTR.BC$xyCoords$y <- yyOUT
  Temporal_MIROC5_2041_2070.PTR.BC$xyCoords$y <- yyOUT
  Temporal_EARTH_2041_2070.PTR.BC$xyCoords$y <- yyOUT
  Temporal_MPI_2041_2070.PTR.BC$xyCoords$y <- yyOUT
  Temporal_CanESM2_2041_2070.PTR.BC$xyCoords$y <- yyOUT
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2071_2100.PTR.BC$xyCoords$y <- yyOUT
  Temporal_HadGEM2_2071_2100.PTR.BC$xyCoords$y <- yyOUT
  Temporal_MIROC5_2071_2100.PTR.BC$xyCoords$y <- yyOUT
  Temporal_EARTH_2071_2100.PTR.BC$xyCoords$y <- yyOUT
  Temporal_MPI_2071_2100.PTR.BC$xyCoords$y <- yyOUT
  Temporal_CanESM2_2071_2100.PTR.BC$xyCoords$y <- yyOUT
  
  # ******************************
  # EQM
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2011_2040.EQM.BC$xyCoords$y <- yyOUT
  Temporal_HadGEM2_2011_2040.EQM.BC$xyCoords$y <- yyOUT
  Temporal_MIROC5_2011_2040.EQM.BC$xyCoords$y <- yyOUT
  Temporal_EARTH_2011_2040.EQM.BC$xyCoords$y <- yyOUT
  Temporal_MPI_2011_2040.EQM.BC$xyCoords$y <- yyOUT
  Temporal_CanESM2_2011_2040.EQM.BC$xyCoords$y <- yyOUT
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2041_2070.EQM.BC$xyCoords$y <- yyOUT
  Temporal_HadGEM2_2041_2070.EQM.BC$xyCoords$y <- yyOUT
  Temporal_MIROC5_2041_2070.EQM.BC$xyCoords$y <- yyOUT
  Temporal_EARTH_2041_2070.EQM.BC$xyCoords$y <- yyOUT
  Temporal_MPI_2041_2070.EQM.BC$xyCoords$y <- yyOUT
  Temporal_CanESM2_2041_2070.EQM.BC$xyCoords$y <- yyOUT
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  Temporal_PRECIS_2071_2100.EQM.BC$xyCoords$y <- yyOUT
  Temporal_HadGEM2_2071_2100.EQM.BC$xyCoords$y <- yyOUT
  Temporal_MIROC5_2071_2100.EQM.BC$xyCoords$y <- yyOUT
  Temporal_EARTH_2071_2100.EQM.BC$xyCoords$y <- yyOUT
  Temporal_MPI_2071_2100.EQM.BC$xyCoords$y <- yyOUT
  Temporal_CanESM2_2071_2100.EQM.BC$xyCoords$y <- yyOUT
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # grid2nc {loadeR.2nc} is used to externally export temporary NetCDF files
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  grid2nc(Temporal_PRECIS_2011_2040.DELTA.BC, NetCDFOutFile = "Temporal_PRECIS_2011_2040.DELTA.BC.nc")
  grid2nc(Temporal_HadGEM2_2011_2040.DELTA.BC, NetCDFOutFile = "Temporal_HadGEM2_2011_2040.DELTA.BC.nc")
  grid2nc(Temporal_MIROC5_2011_2040.DELTA.BC, NetCDFOutFile = "Temporal_MIROC5_2011_2040.DELTA.BC.nc")
  grid2nc(Temporal_EARTH_2011_2040.DELTA.BC, NetCDFOutFile = "Temporal_EARTH_2011_2040.DELTA.BC.nc")
  grid2nc(Temporal_MPI_2011_2040.DELTA.BC, NetCDFOutFile = "Temporal_MPI_2011_2040.DELTA.BC.nc")
  grid2nc(Temporal_CanESM2_2011_2040.DELTA.BC, NetCDFOutFile = "Temporal_CanESM2_2011_2040.DELTA.BC.nc")
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  grid2nc(Temporal_PRECIS_2041_2070.DELTA.BC, NetCDFOutFile = "Temporal_PRECIS_2041_2070.DELTA.BC.nc")
  grid2nc(Temporal_HadGEM2_2041_2070.DELTA.BC, NetCDFOutFile = "Temporal_HadGEM2_2041_2070.DELTA.BC.nc")
  grid2nc(Temporal_MIROC5_2041_2070.DELTA.BC, NetCDFOutFile = "Temporal_MIROC5_2041_2070.DELTA.BC.nc")
  grid2nc(Temporal_EARTH_2041_2070.DELTA.BC, NetCDFOutFile = "Temporal_EARTH_2041_2070.DELTA.BC.nc")
  grid2nc(Temporal_MPI_2041_2070.DELTA.BC, NetCDFOutFile = "Temporal_MPI_2041_2070.DELTA.BC.nc")
  grid2nc(Temporal_CanESM2_2041_2070.DELTA.BC, NetCDFOutFile = "Temporal_CanESM2_2041_2070.DELTA.BC.nc")
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  grid2nc(Temporal_PRECIS_2071_2100.DELTA.BC, NetCDFOutFile = "Temporal_PRECIS_2071_2100.DELTA.BC.nc")
  grid2nc(Temporal_HadGEM2_2071_2100.DELTA.BC, NetCDFOutFile = "Temporal_HadGEM2_2071_2100.DELTA.BC.nc")
  grid2nc(Temporal_MIROC5_2071_2100.DELTA.BC, NetCDFOutFile = "Temporal_MIROC5_2071_2100.DELTA.BC.nc")
  grid2nc(Temporal_EARTH_2071_2100.DELTA.BC, NetCDFOutFile = "Temporal_EARTH_2071_2100.DELTA.BC.nc")
  grid2nc(Temporal_MPI_2071_2100.DELTA.BC, NetCDFOutFile = "Temporal_MPI_2071_2100.DELTA.BC.nc")
  grid2nc(Temporal_CanESM2_2071_2100.DELTA.BC, NetCDFOutFile = "Temporal_CanESM2_2071_2100.DELTA.BC.nc")
  
  # ******************************
  # PTR
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  grid2nc(Temporal_PRECIS_2011_2040.PTR.BC, NetCDFOutFile = "Temporal_PRECIS_2011_2040.PTR.BC.nc")
  grid2nc(Temporal_HadGEM2_2011_2040.PTR.BC, NetCDFOutFile = "Temporal_HadGEM2_2011_2040.PTR.BC.nc")
  grid2nc(Temporal_MIROC5_2011_2040.PTR.BC, NetCDFOutFile = "Temporal_MIROC5_2011_2040.PTR.BC.nc")
  grid2nc(Temporal_EARTH_2011_2040.PTR.BC, NetCDFOutFile = "Temporal_EARTH_2011_2040.PTR.BC.nc")
  grid2nc(Temporal_MPI_2011_2040.PTR.BC, NetCDFOutFile = "Temporal_MPI_2011_2040.PTR.BC.nc")
  grid2nc(Temporal_CanESM2_2011_2040.PTR.BC, NetCDFOutFile = "Temporal_CanESM2_2011_2040.PTR.BC.nc")
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  grid2nc(Temporal_PRECIS_2041_2070.PTR.BC, NetCDFOutFile = "Temporal_PRECIS_2041_2070.PTR.BC.nc")
  grid2nc(Temporal_HadGEM2_2041_2070.PTR.BC, NetCDFOutFile = "Temporal_HadGEM2_2041_2070.PTR.BC.nc")
  grid2nc(Temporal_MIROC5_2041_2070.PTR.BC, NetCDFOutFile = "Temporal_MIROC5_2041_2070.PTR.BC.nc")
  grid2nc(Temporal_EARTH_2041_2070.PTR.BC, NetCDFOutFile = "Temporal_EARTH_2041_2070.PTR.BC.nc")
  grid2nc(Temporal_MPI_2041_2070.PTR.BC, NetCDFOutFile = "Temporal_MPI_2041_2070.PTR.BC.nc")
  grid2nc(Temporal_CanESM2_2041_2070.PTR.BC, NetCDFOutFile = "Temporal_CanESM2_2041_2070.PTR.BC.nc")
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  grid2nc(Temporal_PRECIS_2071_2100.PTR.BC, NetCDFOutFile = "Temporal_PRECIS_2071_2100.PTR.BC.nc")
  grid2nc(Temporal_HadGEM2_2071_2100.PTR.BC, NetCDFOutFile = "Temporal_HadGEM2_2071_2100.PTR.BC.nc")
  grid2nc(Temporal_MIROC5_2071_2100.PTR.BC, NetCDFOutFile = "Temporal_MIROC5_2071_2100.PTR.BC.nc")
  grid2nc(Temporal_EARTH_2071_2100.PTR.BC, NetCDFOutFile = "Temporal_EARTH_2071_2100.PTR.BC.nc")
  grid2nc(Temporal_MPI_2071_2100.PTR.BC, NetCDFOutFile = "Temporal_MPI_2071_2100.PTR.BC.nc")
  grid2nc(Temporal_CanESM2_2071_2100.PTR.BC, NetCDFOutFile = "Temporal_CanESM2_2071_2100.PTR.BC.nc")
  
  
  # ******************************
  # EQM
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  grid2nc(Temporal_PRECIS_2011_2040.EQM.BC, NetCDFOutFile = "Temporal_PRECIS_2011_2040.EQM.BC.nc")
  grid2nc(Temporal_HadGEM2_2011_2040.EQM.BC, NetCDFOutFile = "Temporal_HadGEM2_2011_2040.EQM.BC.nc")
  grid2nc(Temporal_MIROC5_2011_2040.EQM.BC, NetCDFOutFile = "Temporal_MIROC5_2011_2040.EQM.BC.nc")
  grid2nc(Temporal_EARTH_2011_2040.EQM.BC, NetCDFOutFile = "Temporal_EARTH_2011_2040.EQM.BC.nc")
  grid2nc(Temporal_MPI_2011_2040.EQM.BC, NetCDFOutFile = "Temporal_MPI_2011_2040.EQM.BC.nc")
  grid2nc(Temporal_CanESM2_2011_2040.EQM.BC, NetCDFOutFile = "Temporal_CanESM2_2011_2040.EQM.BC.nc")
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  grid2nc(Temporal_PRECIS_2041_2070.EQM.BC, NetCDFOutFile = "Temporal_PRECIS_2041_2070.EQM.BC.nc")
  grid2nc(Temporal_HadGEM2_2041_2070.EQM.BC, NetCDFOutFile = "Temporal_HadGEM2_2041_2070.EQM.BC.nc")
  grid2nc(Temporal_MIROC5_2041_2070.EQM.BC, NetCDFOutFile = "Temporal_MIROC5_2041_2070.EQM.BC.nc")
  grid2nc(Temporal_EARTH_2041_2070.EQM.BC, NetCDFOutFile = "Temporal_EARTH_2041_2070.EQM.BC.nc")
  grid2nc(Temporal_MPI_2041_2070.EQM.BC, NetCDFOutFile = "Temporal_MPI_2041_2070.EQM.BC.nc")
  grid2nc(Temporal_CanESM2_2041_2070.EQM.BC, NetCDFOutFile = "Temporal_CanESM2_2041_2070.EQM.BC.nc")
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  grid2nc(Temporal_PRECIS_2071_2100.EQM.BC, NetCDFOutFile = "Temporal_PRECIS_2071_2100.EQM.BC.nc")
  grid2nc(Temporal_HadGEM2_2071_2100.EQM.BC, NetCDFOutFile = "Temporal_HadGEM2_2071_2100.EQM.BC.nc")
  grid2nc(Temporal_MIROC5_2071_2100.EQM.BC, NetCDFOutFile = "Temporal_MIROC5_2071_2100.EQM.BC.nc")
  grid2nc(Temporal_EARTH_2071_2100.EQM.BC, NetCDFOutFile = "Temporal_EARTH_2071_2100.EQM.BC.nc")
  grid2nc(Temporal_MPI_2071_2100.EQM.BC, NetCDFOutFile = "Temporal_MPI_2071_2100.EQM.BC.nc")
  grid2nc(Temporal_CanESM2_2071_2100.EQM.BC, NetCDFOutFile = "Temporal_CanESM2_2071_2100.EQM.BC.nc")
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # loadNcdf {hyfo} is used to load grid2nc {loadeR.2nc} NetCDF objects
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2011_2040.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_PRECIS_2011_2040.DELTA.BC.nc", varname = "Precipitation")
  HTemp_HadGEM2_2011_2040.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_HadGEM2_2011_2040.DELTA.BC.nc", varname = "Precipitation")
  HTemp_MIROC5_2011_2040.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_MIROC5_2011_2040.DELTA.BC.nc", varname = "Precipitation")
  HTemp_EARTH_2011_2040.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_EARTH_2011_2040.DELTA.BC.nc", varname = "Precipitation")
  HTemp_MPI_2011_2040.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_MPI_2011_2040.DELTA.BC.nc", varname = "Precipitation")
  HTemp_CanESM2_2011_2040.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_CanESM2_2011_2040.DELTA.BC.nc", varname = "Precipitation")
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2041_2070.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_PRECIS_2041_2070.DELTA.BC.nc", varname = "Precipitation")
  HTemp_HadGEM2_2041_2070.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_HadGEM2_2041_2070.DELTA.BC.nc", varname = "Precipitation")
  HTemp_MIROC5_2041_2070.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_MIROC5_2041_2070.DELTA.BC.nc", varname = "Precipitation")
  HTemp_EARTH_2041_2070.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_EARTH_2041_2070.DELTA.BC.nc", varname = "Precipitation")
  HTemp_MPI_2041_2070.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_MPI_2041_2070.DELTA.BC.nc", varname = "Precipitation")
  HTemp_CanESM2_2041_2070.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_CanESM2_2041_2070.DELTA.BC.nc", varname = "Precipitation")
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2071_2100.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_PRECIS_2071_2100.DELTA.BC.nc", varname = "Precipitation")
  HTemp_HadGEM2_2071_2100.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_HadGEM2_2071_2100.DELTA.BC.nc", varname = "Precipitation")
  HTemp_MIROC5_2071_2100.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_MIROC5_2071_2100.DELTA.BC.nc", varname = "Precipitation")
  HTemp_EARTH_2071_2100.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_EARTH_2071_2100.DELTA.BC.nc", varname = "Precipitation")
  HTemp_MPI_2071_2100.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_MPI_2071_2100.DELTA.BC.nc", varname = "Precipitation")
  HTemp_CanESM2_2071_2100.DELTA.BC.nc <- loadNcdf(filePath= "Temporal_CanESM2_2071_2100.DELTA.BC.nc", varname = "Precipitation")
  
  # ******************************
  # PTR
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2011_2040.PTR.BC.nc <- loadNcdf(filePath= "Temporal_PRECIS_2011_2040.PTR.BC.nc", varname = "Precipitation")
  HTemp_HadGEM2_2011_2040.PTR.BC.nc <- loadNcdf(filePath= "Temporal_HadGEM2_2011_2040.PTR.BC.nc", varname = "Precipitation")
  HTemp_MIROC5_2011_2040.PTR.BC.nc <- loadNcdf(filePath= "Temporal_MIROC5_2011_2040.PTR.BC.nc", varname = "Precipitation")
  HTemp_EARTH_2011_2040.PTR.BC.nc <- loadNcdf(filePath= "Temporal_EARTH_2011_2040.PTR.BC.nc", varname = "Precipitation")
  HTemp_MPI_2011_2040.PTR.BC.nc <- loadNcdf(filePath= "Temporal_MPI_2011_2040.PTR.BC.nc", varname = "Precipitation")
  HTemp_CanESM2_2011_2040.PTR.BC.nc <- loadNcdf(filePath= "Temporal_CanESM2_2011_2040.PTR.BC.nc", varname = "Precipitation")
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2041_2070.PTR.BC.nc <- loadNcdf(filePath= "Temporal_PRECIS_2041_2070.PTR.BC.nc", varname = "Precipitation")
  HTemp_HadGEM2_2041_2070.PTR.BC.nc <- loadNcdf(filePath= "Temporal_HadGEM2_2041_2070.PTR.BC.nc", varname = "Precipitation")
  HTemp_MIROC5_2041_2070.PTR.BC.nc <- loadNcdf(filePath= "Temporal_MIROC5_2041_2070.PTR.BC.nc", varname = "Precipitation")
  HTemp_EARTH_2041_2070.PTR.BC.nc <- loadNcdf(filePath= "Temporal_EARTH_2041_2070.PTR.BC.nc", varname = "Precipitation")
  HTemp_MPI_2041_2070.PTR.BC.nc <- loadNcdf(filePath= "Temporal_MPI_2041_2070.PTR.BC.nc", varname = "Precipitation")
  HTemp_CanESM2_2041_2070.PTR.BC.nc <- loadNcdf(filePath= "Temporal_CanESM2_2041_2070.PTR.BC.nc", varname = "Precipitation")
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2071_2100.PTR.BC.nc <- loadNcdf(filePath= "Temporal_PRECIS_2071_2100.PTR.BC.nc", varname = "Precipitation")
  HTemp_HadGEM2_2071_2100.PTR.BC.nc <- loadNcdf(filePath= "Temporal_HadGEM2_2071_2100.PTR.BC.nc", varname = "Precipitation")
  HTemp_MIROC5_2071_2100.PTR.BC.nc <- loadNcdf(filePath= "Temporal_MIROC5_2071_2100.PTR.BC.nc", varname = "Precipitation")
  HTemp_EARTH_2071_2100.PTR.BC.nc <- loadNcdf(filePath= "Temporal_EARTH_2071_2100.PTR.BC.nc", varname = "Precipitation")
  HTemp_MPI_2071_2100.PTR.BC.nc <- loadNcdf(filePath= "Temporal_MPI_2071_2100.PTR.BC.nc", varname = "Precipitation")
  HTemp_CanESM2_2071_2100.PTR.BC.nc <- loadNcdf(filePath= "Temporal_CanESM2_2071_2100.PTR.BC.nc", varname = "Precipitation")
  
  # ******************************
  # EQM
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2011_2040.EQM.BC.nc <- loadNcdf(filePath= "Temporal_PRECIS_2011_2040.EQM.BC.nc", varname = "Precipitation")
  HTemp_HadGEM2_2011_2040.EQM.BC.nc <- loadNcdf(filePath= "Temporal_HadGEM2_2011_2040.EQM.BC.nc", varname = "Precipitation")
  HTemp_MIROC5_2011_2040.EQM.BC.nc <- loadNcdf(filePath= "Temporal_MIROC5_2011_2040.EQM.BC.nc", varname = "Precipitation")
  HTemp_EARTH_2011_2040.EQM.BC.nc <- loadNcdf(filePath= "Temporal_EARTH_2011_2040.EQM.BC.nc", varname = "Precipitation")
  HTemp_MPI_2011_2040.EQM.BC.nc <- loadNcdf(filePath= "Temporal_MPI_2011_2040.EQM.BC.nc", varname = "Precipitation")
  HTemp_CanESM2_2011_2040.EQM.BC.nc <- loadNcdf(filePath= "Temporal_CanESM2_2011_2040.EQM.BC.nc", varname = "Precipitation")
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2041_2070.EQM.BC.nc <- loadNcdf(filePath= "Temporal_PRECIS_2041_2070.EQM.BC.nc", varname = "Precipitation")
  HTemp_HadGEM2_2041_2070.EQM.BC.nc <- loadNcdf(filePath= "Temporal_HadGEM2_2041_2070.EQM.BC.nc", varname = "Precipitation")
  HTemp_MIROC5_2041_2070.EQM.BC.nc <- loadNcdf(filePath= "Temporal_MIROC5_2041_2070.EQM.BC.nc", varname = "Precipitation")
  HTemp_EARTH_2041_2070.EQM.BC.nc <- loadNcdf(filePath= "Temporal_EARTH_2041_2070.EQM.BC.nc", varname = "Precipitation")
  HTemp_MPI_2041_2070.EQM.BC.nc <- loadNcdf(filePath= "Temporal_MPI_2041_2070.EQM.BC.nc", varname = "Precipitation")
  HTemp_CanESM2_2041_2070.EQM.BC.nc <- loadNcdf(filePath= "Temporal_CanESM2_2041_2070.EQM.BC.nc", varname = "Precipitation")
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2071_2100.EQM.BC.nc <- loadNcdf(filePath= "Temporal_PRECIS_2071_2100.EQM.BC.nc", varname = "Precipitation")
  HTemp_HadGEM2_2071_2100.EQM.BC.nc <- loadNcdf(filePath= "Temporal_HadGEM2_2071_2100.EQM.BC.nc", varname = "Precipitation")
  HTemp_MIROC5_2071_2100.EQM.BC.nc <- loadNcdf(filePath= "Temporal_MIROC5_2071_2100.EQM.BC.nc", varname = "Precipitation")
  HTemp_EARTH_2071_2100.EQM.BC.nc <- loadNcdf(filePath= "Temporal_EARTH_2071_2100.EQM.BC.nc", varname = "Precipitation")
  HTemp_MPI_2071_2100.EQM.BC.nc <- loadNcdf(filePath= "Temporal_MPI_2071_2100.EQM.BC.nc", varname = "Precipitation")
  HTemp_CanESM2_2071_2100.EQM.BC.nc <- loadNcdf(filePath= "Temporal_CanESM2_2071_2100.EQM.BC.nc", varname = "Precipitation")
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # writeNcdf {hyfo} is used to externally saved NetCDF version 4.0
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  writeNcdf(gridData = HTemp_PRECIS_2011_2040.DELTA.BC.nc, filePath = "HTemporal_PRECIS_2011_2040.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_HadGEM2_2011_2040.DELTA.BC.nc, filePath = "HTemporal_HadGEM2_2011_2040.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MIROC5_2011_2040.DELTA.BC.nc, filePath = "HTemporal_MIROC5_2011_2040.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_EARTH_2011_2040.DELTA.BC.nc, filePath = "HTemporal_EARTH_2011_2040.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MPI_2011_2040.DELTA.BC.nc, filePath = "HTemporal_MPI_2011_2040.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_CanESM2_2011_2040.DELTA.BC.nc, filePath = "HTemporal_CanESM2_2011_2040.DELTA.BC.nc", version = 4)
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  writeNcdf(gridData = HTemp_PRECIS_2041_2070.DELTA.BC.nc, filePath = "HTemporal_PRECIS_2041_2070.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_HadGEM2_2041_2070.DELTA.BC.nc, filePath = "HTemporal_HadGEM2_2041_2070.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MIROC5_2041_2070.DELTA.BC.nc, filePath = "HTemporal_MIROC5_2041_2070.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_EARTH_2041_2070.DELTA.BC.nc, filePath = "HTemporal_EARTH_2041_2070.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MPI_2041_2070.DELTA.BC.nc, filePath = "HTemporal_MPI_2041_2070.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_CanESM2_2041_2070.DELTA.BC.nc, filePath = "HTemporal_CanESM2_2041_2070.DELTA.BC.nc", version = 4)
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  writeNcdf(gridData = HTemp_PRECIS_2071_2100.DELTA.BC.nc, filePath = "HTemporal_PRECIS_2071_2100.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_HadGEM2_2071_2100.DELTA.BC.nc, filePath = "HTemporal_HadGEM2_2071_2100.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MIROC5_2071_2100.DELTA.BC.nc, filePath = "HTemporal_MIROC5_2071_2100.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_EARTH_2071_2100.DELTA.BC.nc, filePath = "HTemporal_EARTH_2071_2100.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MPI_2071_2100.DELTA.BC.nc, filePath = "HTemporal_MPI_2071_2100.DELTA.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_CanESM2_2071_2100.DELTA.BC.nc, filePath = "HTemporal_CanESM2_2071_2100.DELTA.BC.nc", version = 4)
  
  # ******************************
  # PTR
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  writeNcdf(gridData = HTemp_PRECIS_2011_2040.PTR.BC.nc, filePath = "HTemporal_PRECIS_2011_2040.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_HadGEM2_2011_2040.PTR.BC.nc, filePath = "HTemporal_HadGEM2_2011_2040.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MIROC5_2011_2040.PTR.BC.nc, filePath = "HTemporal_MIROC5_2011_2040.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_EARTH_2011_2040.PTR.BC.nc, filePath = "HTemporal_EARTH_2011_2040.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MPI_2011_2040.PTR.BC.nc, filePath = "HTemporal_MPI_2011_2040.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_CanESM2_2011_2040.PTR.BC.nc, filePath = "HTemporal_CanESM2_2011_2040.PTR.BC.nc", version = 4)
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  writeNcdf(gridData = HTemp_PRECIS_2041_2070.PTR.BC.nc, filePath = "HTemporal_PRECIS_2041_2070.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_HadGEM2_2041_2070.PTR.BC.nc, filePath = "HTemporal_HadGEM2_2041_2070.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MIROC5_2041_2070.PTR.BC.nc, filePath = "HTemporal_MIROC5_2041_2070.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_EARTH_2041_2070.PTR.BC.nc, filePath = "HTemporal_EARTH_2041_2070.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MPI_2041_2070.PTR.BC.nc, filePath = "HTemporal_MPI_2041_2070.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_CanESM2_2041_2070.PTR.BC.nc, filePath = "HTemporal_CanESM2_2041_2070.PTR.BC.nc", version = 4)
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  writeNcdf(gridData = HTemp_PRECIS_2071_2100.PTR.BC.nc, filePath = "HTemporal_PRECIS_2071_2100.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_HadGEM2_2071_2100.PTR.BC.nc, filePath = "HTemporal_HadGEM2_2071_2100.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MIROC5_2071_2100.PTR.BC.nc, filePath = "HTemporal_MIROC5_2071_2100.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_EARTH_2071_2100.PTR.BC.nc, filePath = "HTemporal_EARTH_2071_2100.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MPI_2071_2100.PTR.BC.nc, filePath = "HTemporal_MPI_2071_2100.PTR.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_CanESM2_2071_2100.PTR.BC.nc, filePath = "HTemporal_CanESM2_2071_2100.PTR.BC.nc", version = 4)
  
  # ******************************
  # EQM
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  writeNcdf(gridData = HTemp_PRECIS_2011_2040.EQM.BC.nc, filePath = "HTemporal_PRECIS_2011_2040.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_HadGEM2_2011_2040.EQM.BC.nc, filePath = "HTemporal_HadGEM2_2011_2040.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MIROC5_2011_2040.EQM.BC.nc, filePath = "HTemporal_MIROC5_2011_2040.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_EARTH_2011_2040.EQM.BC.nc, filePath = "HTemporal_EARTH_2011_2040.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MPI_2011_2040.EQM.BC.nc, filePath = "HTemporal_MPI_2011_2040.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_CanESM2_2011_2040.EQM.BC.nc, filePath = "HTemporal_CanESM2_2011_2040.EQM.BC.nc", version = 4)
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  writeNcdf(gridData = HTemp_PRECIS_2041_2070.EQM.BC.nc, filePath = "HTemporal_PRECIS_2041_2070.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_HadGEM2_2041_2070.EQM.BC.nc, filePath = "HTemporal_HadGEM2_2041_2070.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MIROC5_2041_2070.EQM.BC.nc, filePath = "HTemporal_MIROC5_2041_2070.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_EARTH_2041_2070.EQM.BC.nc, filePath = "HTemporal_EARTH_2041_2070.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MPI_2041_2070.EQM.BC.nc, filePath = "HTemporal_MPI_2041_2070.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_CanESM2_2041_2070.EQM.BC.nc, filePath = "HTemporal_CanESM2_2041_2070.EQM.BC.nc", version = 4)
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  writeNcdf(gridData = HTemp_PRECIS_2071_2100.EQM.BC.nc, filePath = "HTemporal_PRECIS_2071_2100.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_HadGEM2_2071_2100.EQM.BC.nc, filePath = "HTemporal_HadGEM2_2071_2100.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MIROC5_2071_2100.EQM.BC.nc, filePath = "HTemporal_MIROC5_2071_2100.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_EARTH_2071_2100.EQM.BC.nc, filePath = "HTemporal_EARTH_2071_2100.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_MPI_2071_2100.EQM.BC.nc, filePath = "HTemporal_MPI_2071_2100.EQM.BC.nc", version = 4)
  writeNcdf(gridData = HTemp_CanESM2_2071_2100.EQM.BC.nc, filePath = "HTemporal_CanESM2_2071_2100.EQM.BC.nc", version = 4)
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # stack {raster} is used to create a RasterStack object
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2011_2040.DELTA.BC.raster <- stack("HTemporal_PRECIS_2011_2040.DELTA.BC.nc")
  HTemp_HadGEM2_2011_2040.DELTA.BC.raster <- stack("HTemporal_HadGEM2_2011_2040.DELTA.BC.nc")
  HTemp_MIROC5_2011_2040.DELTA.BC.raster <- stack("HTemporal_MIROC5_2011_2040.DELTA.BC.nc")
  HTemp_EARTH_2011_2040.DELTA.BC.raster <- stack("HTemporal_EARTH_2011_2040.DELTA.BC.nc")
  HTemp_MPI_2011_2040.DELTA.BC.raster <- stack("HTemporal_MPI_2011_2040.DELTA.BC.nc")
  HTemp_CanESM2_2011_2040.DELTA.BC.raster <- stack("HTemporal_CanESM2_2011_2040.DELTA.BC.nc")
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2041_2070.DELTA.BC.raster <- stack("HTemporal_PRECIS_2041_2070.DELTA.BC.nc")
  HTemp_HadGEM2_2041_2070.DELTA.BC.raster <- stack("HTemporal_HadGEM2_2041_2070.DELTA.BC.nc")
  HTemp_MIROC5_2041_2070.DELTA.BC.raster <- stack("HTemporal_MIROC5_2041_2070.DELTA.BC.nc")
  HTemp_EARTH_2041_2070.DELTA.BC.raster <- stack("HTemporal_EARTH_2041_2070.DELTA.BC.nc")
  HTemp_MPI_2041_2070.DELTA.BC.raster <- stack("HTemporal_MPI_2041_2070.DELTA.BC.nc")
  HTemp_CanESM2_2041_2070.DELTA.BC.raster <- stack("HTemporal_CanESM2_2041_2070.DELTA.BC.nc")
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2071_2100.DELTA.BC.raster <- stack("HTemporal_PRECIS_2071_2100.DELTA.BC.nc")
  HTemp_HadGEM2_2071_2100.DELTA.BC.raster <- stack("HTemporal_HadGEM2_2071_2100.DELTA.BC.nc")
  HTemp_MIROC5_2071_2100.DELTA.BC.raster <- stack("HTemporal_MIROC5_2071_2100.DELTA.BC.nc")
  HTemp_EARTH_2071_2100.DELTA.BC.raster <- stack("HTemporal_EARTH_2071_2100.DELTA.BC.nc")
  HTemp_MPI_2071_2100.DELTA.BC.raster <- stack("HTemporal_MPI_2071_2100.DELTA.BC.nc")
  HTemp_CanESM2_2071_2100.DELTA.BC.raster <- stack("HTemporal_CanESM2_2071_2100.DELTA.BC.nc")
  
  # ******************************
  # PTR
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2011_2040.PTR.BC.raster <- stack("HTemporal_PRECIS_2011_2040.PTR.BC.nc")
  HTemp_HadGEM2_2011_2040.PTR.BC.raster <- stack("HTemporal_HadGEM2_2011_2040.PTR.BC.nc")
  HTemp_MIROC5_2011_2040.PTR.BC.raster <- stack("HTemporal_MIROC5_2011_2040.PTR.BC.nc")
  HTemp_EARTH_2011_2040.PTR.BC.raster <- stack("HTemporal_EARTH_2011_2040.PTR.BC.nc")
  HTemp_MPI_2011_2040.PTR.BC.raster <- stack("HTemporal_MPI_2011_2040.PTR.BC.nc")
  HTemp_CanESM2_2011_2040.PTR.BC.raster <- stack("HTemporal_CanESM2_2011_2040.PTR.BC.nc")
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2041_2070.PTR.BC.raster <- stack("HTemporal_PRECIS_2041_2070.PTR.BC.nc")
  HTemp_HadGEM2_2041_2070.PTR.BC.raster <- stack("HTemporal_HadGEM2_2041_2070.PTR.BC.nc")
  HTemp_MIROC5_2041_2070.PTR.BC.raster <- stack("HTemporal_MIROC5_2041_2070.PTR.BC.nc")
  HTemp_EARTH_2041_2070.PTR.BC.raster <- stack("HTemporal_EARTH_2041_2070.PTR.BC.nc")
  HTemp_MPI_2041_2070.PTR.BC.raster <- stack("HTemporal_MPI_2041_2070.PTR.BC.nc")
  HTemp_CanESM2_2041_2070.PTR.BC.raster <- stack("HTemporal_CanESM2_2041_2070.PTR.BC.nc")
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2071_2100.PTR.BC.raster <- stack("HTemporal_PRECIS_2071_2100.PTR.BC.nc")
  HTemp_HadGEM2_2071_2100.PTR.BC.raster <- stack("HTemporal_HadGEM2_2071_2100.PTR.BC.nc")
  HTemp_MIROC5_2071_2100.PTR.BC.raster <- stack("HTemporal_MIROC5_2071_2100.PTR.BC.nc")
  HTemp_EARTH_2071_2100.PTR.BC.raster <- stack("HTemporal_EARTH_2071_2100.PTR.BC.nc")
  HTemp_MPI_2071_2100.PTR.BC.raster <- stack("HTemporal_MPI_2071_2100.PTR.BC.nc")
  HTemp_CanESM2_2071_2100.PTR.BC.raster <- stack("HTemporal_CanESM2_2071_2100.PTR.BC.nc")
  
  # ******************************
  # EQM
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2011_2040.EQM.BC.raster <- stack("HTemporal_PRECIS_2011_2040.EQM.BC.nc")
  HTemp_HadGEM2_2011_2040.EQM.BC.raster <- stack("HTemporal_HadGEM2_2011_2040.EQM.BC.nc")
  HTemp_MIROC5_2011_2040.EQM.BC.raster <- stack("HTemporal_MIROC5_2011_2040.EQM.BC.nc")
  HTemp_EARTH_2011_2040.EQM.BC.raster <- stack("HTemporal_EARTH_2011_2040.EQM.BC.nc")
  HTemp_MPI_2011_2040.EQM.BC.raster <- stack("HTemporal_MPI_2011_2040.EQM.BC.nc")
  HTemp_CanESM2_2011_2040.EQM.BC.raster <- stack("HTemporal_CanESM2_2011_2040.EQM.BC.nc")
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2041_2070.EQM.BC.raster <- stack("HTemporal_PRECIS_2041_2070.EQM.BC.nc")
  HTemp_HadGEM2_2041_2070.EQM.BC.raster <- stack("HTemporal_HadGEM2_2041_2070.EQM.BC.nc")
  HTemp_MIROC5_2041_2070.EQM.BC.raster <- stack("HTemporal_MIROC5_2041_2070.EQM.BC.nc")
  HTemp_EARTH_2041_2070.EQM.BC.raster <- stack("HTemporal_EARTH_2041_2070.EQM.BC.nc")
  HTemp_MPI_2041_2070.EQM.BC.raster <- stack("HTemporal_MPI_2041_2070.EQM.BC.nc")
  HTemp_CanESM2_2041_2070.EQM.BC.raster <- stack("HTemporal_CanESM2_2041_2070.EQM.BC.nc")
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2071_2100.EQM.BC.raster <- stack("HTemporal_PRECIS_2071_2100.EQM.BC.nc")
  HTemp_HadGEM2_2071_2100.EQM.BC.raster <- stack("HTemporal_HadGEM2_2071_2100.EQM.BC.nc")
  HTemp_MIROC5_2071_2100.EQM.BC.raster <- stack("HTemporal_MIROC5_2071_2100.EQM.BC.nc")
  HTemp_EARTH_2071_2100.EQM.BC.raster <- stack("HTemporal_EARTH_2071_2100.EQM.BC.nc")
  HTemp_MPI_2071_2100.EQM.BC.raster <- stack("HTemporal_MPI_2071_2100.EQM.BC.nc")
  HTemp_CanESM2_2071_2100.EQM.BC.raster <- stack("HTemporal_CanESM2_2071_2100.EQM.BC.nc")
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # CRTM05 projection is assigned to raster layer
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  crs(HTemp_PRECIS_2011_2040.DELTA.BC.raster) <- CRTM05
  crs(HTemp_HadGEM2_2011_2040.DELTA.BC.raster) <- CRTM05 
  crs(HTemp_MIROC5_2011_2040.DELTA.BC.raster) <- CRTM05 
  crs(HTemp_EARTH_2011_2040.DELTA.BC.raster) <- CRTM05 
  crs(HTemp_MPI_2011_2040.DELTA.BC.raster) <- CRTM05 
  crs(HTemp_CanESM2_2011_2040.DELTA.BC.raster) <- CRTM05 
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  crs(HTemp_PRECIS_2041_2070.DELTA.BC.raster) <- CRTM05 
  crs(HTemp_HadGEM2_2041_2070.DELTA.BC.raster) <- CRTM05 
  crs(HTemp_MIROC5_2041_2070.DELTA.BC.raster) <- CRTM05 
  crs(HTemp_EARTH_2041_2070.DELTA.BC.raster) <- CRTM05 
  crs(HTemp_MPI_2041_2070.DELTA.BC.raster) <- CRTM05 
  crs(HTemp_CanESM2_2041_2070.DELTA.BC.raster) <- CRTM05 
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  crs(HTemp_PRECIS_2071_2100.DELTA.BC.raster) <- CRTM05
  crs(HTemp_HadGEM2_2071_2100.DELTA.BC.raster) <- CRTM05
  crs(HTemp_MIROC5_2071_2100.DELTA.BC.raster) <- CRTM05
  crs(HTemp_EARTH_2071_2100.DELTA.BC.raster) <- CRTM05
  crs(HTemp_MPI_2071_2100.DELTA.BC.raster) <- CRTM05
  crs(HTemp_CanESM2_2071_2100.DELTA.BC.raster) <- CRTM05
  
  # ******************************
  # PTR
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  crs(HTemp_PRECIS_2011_2040.PTR.BC.raster) <- CRTM05
  crs(HTemp_HadGEM2_2011_2040.PTR.BC.raster) <- CRTM05
  crs(HTemp_MIROC5_2011_2040.PTR.BC.raster) <- CRTM05
  crs(HTemp_EARTH_2011_2040.PTR.BC.raster) <- CRTM05
  crs(HTemp_MPI_2011_2040.PTR.BC.raster) <- CRTM05
  crs(HTemp_CanESM2_2011_2040.PTR.BC.raster) <- CRTM05
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  crs(HTemp_PRECIS_2041_2070.PTR.BC.raster) <- CRTM05
  crs(HTemp_HadGEM2_2041_2070.PTR.BC.raster) <- CRTM05
  crs(HTemp_MIROC5_2041_2070.PTR.BC.raster) <- CRTM05
  crs(HTemp_EARTH_2041_2070.PTR.BC.raster) <- CRTM05
  crs(HTemp_MPI_2041_2070.PTR.BC.raster) <- CRTM05
  crs(HTemp_CanESM2_2041_2070.PTR.BC.raster) <- CRTM05
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  crs(HTemp_PRECIS_2071_2100.PTR.BC.raster) <- CRTM05
  crs(HTemp_HadGEM2_2071_2100.PTR.BC.raster) <- CRTM05
  crs(HTemp_MIROC5_2071_2100.PTR.BC.raster) <- CRTM05
  crs(HTemp_EARTH_2071_2100.PTR.BC.raster) <- CRTM05
  crs(HTemp_MPI_2071_2100.PTR.BC.raster) <- CRTM05
  crs(HTemp_CanESM2_2071_2100.PTR.BC.raster) <- CRTM05
  
  # ******************************
  # EQM
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  crs(HTemp_PRECIS_2011_2040.EQM.BC.raster) <- CRTM05
  crs(HTemp_HadGEM2_2011_2040.EQM.BC.raster) <- CRTM05
  crs(HTemp_MIROC5_2011_2040.EQM.BC.raster) <- CRTM05
  crs(HTemp_EARTH_2011_2040.EQM.BC.raster) <- CRTM05
  crs(HTemp_MPI_2011_2040.EQM.BC.raster) <- CRTM05
  crs(HTemp_CanESM2_2011_2040.EQM.BC.raster) <- CRTM05
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  crs(HTemp_PRECIS_2041_2070.EQM.BC.raster) <- CRTM05
  crs(HTemp_HadGEM2_2041_2070.EQM.BC.raster) <- CRTM05
  crs(HTemp_MIROC5_2041_2070.EQM.BC.raster) <- CRTM05
  crs(HTemp_EARTH_2041_2070.EQM.BC.raster) <- CRTM05
  crs(HTemp_MPI_2041_2070.EQM.BC.raster) <- CRTM05
  crs(HTemp_CanESM2_2041_2070.EQM.BC.raster) <- CRTM05
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  crs(HTemp_PRECIS_2071_2100.EQM.BC.raster) <- CRTM05
  crs(HTemp_HadGEM2_2071_2100.EQM.BC.raster) <- CRTM05
  crs(HTemp_MIROC5_2071_2100.EQM.BC.raster) <- CRTM05
  crs(HTemp_EARTH_2071_2100.EQM.BC.raster) <- CRTM05
  crs(HTemp_MPI_2071_2100.EQM.BC.raster) <- CRTM05
  crs(HTemp_CanESM2_2071_2100.EQM.BC.raster) <- CRTM05
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # stack {flip} is used to flip a RasterStack object
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2011_2040.DELTA.BC.raster <- flip(HTemp_PRECIS_2011_2040.DELTA.BC.raster, direction ="y")
  HTemp_HadGEM2_2011_2040.DELTA.BC.raster <- flip(HTemp_HadGEM2_2011_2040.DELTA.BC.raster, direction ="y")
  HTemp_MIROC5_2011_2040.DELTA.BC.raster <- flip(HTemp_MIROC5_2011_2040.DELTA.BC.raster, direction ="y")
  HTemp_EARTH_2011_2040.DELTA.BC.raster <- flip(HTemp_EARTH_2011_2040.DELTA.BC.raster, direction ="y")
  HTemp_MPI_2011_2040.DELTA.BC.raster <- flip(HTemp_MPI_2011_2040.DELTA.BC.raster, direction ="y")
  HTemp_CanESM2_2011_2040.DELTA.BC.raster <- flip(HTemp_CanESM2_2011_2040.DELTA.BC.raster, direction ="y")
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2041_2070.DELTA.BC.raster <- flip(HTemp_PRECIS_2041_2070.DELTA.BC.raster, direction ="y")
  HTemp_HadGEM2_2041_2070.DELTA.BC.raster <- flip(HTemp_HadGEM2_2041_2070.DELTA.BC.raster, direction ="y")
  HTemp_MIROC5_2041_2070.DELTA.BC.raster <- flip(HTemp_MIROC5_2041_2070.DELTA.BC.raster, direction ="y")
  HTemp_EARTH_2041_2070.DELTA.BC.raster <- flip(HTemp_EARTH_2041_2070.DELTA.BC.raster, direction ="y")
  HTemp_MPI_2041_2070.DELTA.BC.raster <- flip(HTemp_MPI_2041_2070.DELTA.BC.raster, direction ="y")
  HTemp_CanESM2_2041_2070.DELTA.BC.raster <- flip(HTemp_CanESM2_2041_2070.DELTA.BC.raster, direction ="y")
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2071_2100.DELTA.BC.raster <- flip(HTemp_PRECIS_2071_2100.DELTA.BC.raster, direction ="y")
  HTemp_HadGEM2_2071_2100.DELTA.BC.raster <- flip(HTemp_HadGEM2_2071_2100.DELTA.BC.raster, direction ="y")
  HTemp_MIROC5_2071_2100.DELTA.BC.raster <- flip(HTemp_MIROC5_2071_2100.DELTA.BC.raster, direction ="y")
  HTemp_EARTH_2071_2100.DELTA.BC.raster <- flip(HTemp_EARTH_2071_2100.DELTA.BC.raster, direction ="y")
  HTemp_MPI_2071_2100.DELTA.BC.raster <- flip(HTemp_MPI_2071_2100.DELTA.BC.raster, direction ="y")
  HTemp_CanESM2_2071_2100.DELTA.BC.raster <- flip(HTemp_CanESM2_2071_2100.DELTA.BC.raster, direction ="y")
  
  # ******************************
  # PTR
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2011_2040.PTR.BC.raster <- flip(HTemp_PRECIS_2011_2040.PTR.BC.raster, direction ="y")
  HTemp_HadGEM2_2011_2040.PTR.BC.raster <- flip(HTemp_HadGEM2_2011_2040.PTR.BC.raster, direction ="y")
  HTemp_MIROC5_2011_2040.PTR.BC.raster <- flip(HTemp_MIROC5_2011_2040.PTR.BC.raster, direction ="y")
  HTemp_EARTH_2011_2040.PTR.BC.raster <- flip(HTemp_EARTH_2011_2040.PTR.BC.raster, direction ="y")
  HTemp_MPI_2011_2040.PTR.BC.raster <- flip(HTemp_MPI_2011_2040.PTR.BC.raster, direction ="y")
  HTemp_CanESM2_2011_2040.PTR.BC.raster <- flip(HTemp_CanESM2_2011_2040.PTR.BC.raster, direction ="y")
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2041_2070.PTR.BC.raster <- flip(HTemp_PRECIS_2041_2070.PTR.BC.raster, direction ="y")
  HTemp_HadGEM2_2041_2070.PTR.BC.raster <- flip(HTemp_HadGEM2_2041_2070.PTR.BC.raster, direction ="y")
  HTemp_MIROC5_2041_2070.PTR.BC.raster <- flip(HTemp_MIROC5_2041_2070.PTR.BC.raster, direction ="y")
  HTemp_EARTH_2041_2070.PTR.BC.raster <- flip(HTemp_EARTH_2041_2070.PTR.BC.raster, direction ="y")
  HTemp_MPI_2041_2070.PTR.BC.raster <- flip(HTemp_MPI_2041_2070.PTR.BC.raster, direction ="y")
  HTemp_CanESM2_2041_2070.PTR.BC.raster <- flip(HTemp_CanESM2_2041_2070.PTR.BC.raster, direction ="y")
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2071_2100.PTR.BC.raster <- flip(HTemp_PRECIS_2071_2100.PTR.BC.raster, direction ="y")
  HTemp_HadGEM2_2071_2100.PTR.BC.raster <- flip(HTemp_HadGEM2_2071_2100.PTR.BC.raster, direction ="y")
  HTemp_MIROC5_2071_2100.PTR.BC.raster <- flip(HTemp_MIROC5_2071_2100.PTR.BC.raster, direction ="y")
  HTemp_EARTH_2071_2100.PTR.BC.raster <- flip(HTemp_EARTH_2071_2100.PTR.BC.raster, direction ="y")
  HTemp_MPI_2071_2100.PTR.BC.raster <- flip(HTemp_MPI_2071_2100.PTR.BC.raster, direction ="y")
  HTemp_CanESM2_2071_2100.PTR.BC.raster <- flip(HTemp_CanESM2_2071_2100.PTR.BC.raster, direction ="y")
  
  # ******************************
  # EQM
  # ******************************
  
  # 2011_2040 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2011_2040.EQM.BC.raster <- flip(HTemp_PRECIS_2011_2040.EQM.BC.raster, direction ="y")
  HTemp_HadGEM2_2011_2040.EQM.BC.raster <- flip(HTemp_HadGEM2_2011_2040.EQM.BC.raster, direction ="y")
  HTemp_MIROC5_2011_2040.EQM.BC.raster <- flip(HTemp_MIROC5_2011_2040.EQM.BC.raster, direction ="y")
  HTemp_EARTH_2011_2040.EQM.BC.raster <- flip(HTemp_EARTH_2011_2040.EQM.BC.raster, direction ="y")
  HTemp_MPI_2011_2040.EQM.BC.raster <- flip(HTemp_MPI_2011_2040.EQM.BC.raster, direction ="y")
  HTemp_CanESM2_2011_2040.EQM.BC.raster <- flip(HTemp_CanESM2_2011_2040.EQM.BC.raster, direction ="y")
  
  # 2041_2070 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2041_2070.EQM.BC.raster <- flip(HTemp_PRECIS_2041_2070.EQM.BC.raster, direction ="y")
  HTemp_HadGEM2_2041_2070.EQM.BC.raster <- flip(HTemp_HadGEM2_2041_2070.EQM.BC.raster, direction ="y")
  HTemp_MIROC5_2041_2070.EQM.BC.raster <- flip(HTemp_MIROC5_2041_2070.EQM.BC.raster, direction ="y")
  HTemp_EARTH_2041_2070.EQM.BC.raster <- flip(HTemp_EARTH_2041_2070.EQM.BC.raster, direction ="y")
  HTemp_MPI_2041_2070.EQM.BC.raster <- flip(HTemp_MPI_2041_2070.EQM.BC.raster, direction ="y")
  HTemp_CanESM2_2041_2070.EQM.BC.raster <- flip(HTemp_CanESM2_2041_2070.EQM.BC.raster, direction ="y")
  
  # 2071_2100 period	
  #--------------------------------------------------------------------------------------------------------------------------------------	
  HTemp_PRECIS_2071_2100.EQM.BC.raster <- flip(HTemp_PRECIS_2071_2100.EQM.BC.raster, direction ="y")
  HTemp_HadGEM2_2071_2100.EQM.BC.raster <- flip(HTemp_HadGEM2_2071_2100.EQM.BC.raster, direction ="y")
  HTemp_MIROC5_2071_2100.EQM.BC.raster <- flip(HTemp_MIROC5_2071_2100.EQM.BC.raster, direction ="y")
  HTemp_EARTH_2071_2100.EQM.BC.raster <- flip(HTemp_EARTH_2071_2100.EQM.BC.raster, direction ="y")
  HTemp_MPI_2071_2100.EQM.BC.raster <- flip(HTemp_MPI_2071_2100.EQM.BC.raster, direction ="y")
  HTemp_CanESM2_2071_2100.EQM.BC.raster <- flip(HTemp_CanESM2_2071_2100.EQM.BC.raster, direction ="y")
  
  # Ensamble median is calculated. WARNING !!!!! Time Consuming !!!!!
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_median_Ensamble_2011_2040_DELTA <- overlay(HTemp_PRECIS_2011_2040.DELTA.BC.raster,
                                                   HTemp_HadGEM2_2011_2040.DELTA.BC.raster,
                                                   HTemp_MIROC5_2011_2040.DELTA.BC.raster,
                                                   HTemp_EARTH_2011_2040.DELTA.BC.raster,
                                                   HTemp_MPI_2011_2040.DELTA.BC.raster,
                                                   HTemp_CanESM2_2011_2040.DELTA.BC.raster,
                                                   fun=median)
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_median_Ensamble_2041_2070_DELTA <- overlay(HTemp_PRECIS_2041_2070.DELTA.BC.raster,
                                                   HTemp_HadGEM2_2041_2070.DELTA.BC.raster,
                                                   HTemp_MIROC5_2041_2070.DELTA.BC.raster,
                                                   HTemp_EARTH_2041_2070.DELTA.BC.raster,
                                                   HTemp_MPI_2041_2070.DELTA.BC.raster,
                                                   HTemp_CanESM2_2041_2070.DELTA.BC.raster,
                                                   fun=median)
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_median_Ensamble_2071_2100_DELTA <- overlay(HTemp_PRECIS_2071_2100.DELTA.BC.raster,
                                                   HTemp_HadGEM2_2071_2100.DELTA.BC.raster,
                                                   HTemp_MIROC5_2071_2100.DELTA.BC.raster,
                                                   HTemp_EARTH_2071_2100.DELTA.BC.raster,
                                                   HTemp_MPI_2071_2100.DELTA.BC.raster,
                                                   HTemp_CanESM2_2071_2100.DELTA.BC.raster,
                                                   fun=median)
  
  # ******************************
  # PTR
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_median_Ensamble_2011_2040_PTR <- overlay(HTemp_PRECIS_2011_2040.PTR.BC.raster,
                                                 HTemp_HadGEM2_2011_2040.PTR.BC.raster,
                                                 HTemp_MIROC5_2011_2040.PTR.BC.raster,
                                                 HTemp_EARTH_2011_2040.PTR.BC.raster,
                                                 HTemp_MPI_2011_2040.PTR.BC.raster,
                                                 HTemp_CanESM2_2011_2040.PTR.BC.raster,
                                                 fun=median)
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_median_Ensamble_2041_2070_PTR <- overlay(HTemp_PRECIS_2041_2070.PTR.BC.raster,
                                                 HTemp_HadGEM2_2041_2070.PTR.BC.raster,
                                                 HTemp_MIROC5_2041_2070.PTR.BC.raster,
                                                 HTemp_EARTH_2041_2070.PTR.BC.raster,
                                                 HTemp_MPI_2041_2070.PTR.BC.raster,
                                                 HTemp_CanESM2_2041_2070.PTR.BC.raster,
                                                 fun=median)
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_median_Ensamble_2071_2100_PTR <- overlay(HTemp_PRECIS_2071_2100.PTR.BC.raster,
                                                 HTemp_HadGEM2_2071_2100.PTR.BC.raster,
                                                 HTemp_MIROC5_2071_2100.PTR.BC.raster,
                                                 HTemp_EARTH_2071_2100.PTR.BC.raster,
                                                 HTemp_MPI_2071_2100.PTR.BC.raster,
                                                 HTemp_CanESM2_2071_2100.PTR.BC.raster,
                                                 fun=median)
  
  # ******************************
  # EQM
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_median_Ensamble_2011_2040_EQM <- overlay(HTemp_PRECIS_2011_2040.EQM.BC.raster,
                                                 HTemp_HadGEM2_2011_2040.EQM.BC.raster,
                                                 HTemp_MIROC5_2011_2040.EQM.BC.raster,
                                                 HTemp_EARTH_2011_2040.EQM.BC.raster,
                                                 HTemp_MPI_2011_2040.EQM.BC.raster,
                                                 HTemp_CanESM2_2011_2040.EQM.BC.raster,
                                                 fun=median)
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_median_Ensamble_2041_2070_EQM <- overlay(HTemp_PRECIS_2041_2070.EQM.BC.raster,
                                                 HTemp_HadGEM2_2041_2070.EQM.BC.raster,
                                                 HTemp_MIROC5_2041_2070.EQM.BC.raster,
                                                 HTemp_EARTH_2041_2070.EQM.BC.raster,
                                                 HTemp_MPI_2041_2070.EQM.BC.raster,
                                                 HTemp_CanESM2_2041_2070.EQM.BC.raster,
                                                 fun=median)
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_median_Ensamble_2071_2100_EQM <- overlay(HTemp_PRECIS_2071_2100.EQM.BC.raster,
                                                 HTemp_HadGEM2_2071_2100.EQM.BC.raster,
                                                 HTemp_MIROC5_2071_2100.EQM.BC.raster,
                                                 HTemp_EARTH_2071_2100.EQM.BC.raster,
                                                 HTemp_MPI_2071_2100.EQM.BC.raster,
                                                 HTemp_CanESM2_2071_2100.EQM.BC.raster,
                                                 fun=median)
  
  # Ensamble mean is calculated. WARNING !!!!! Time Consuming !!!!!
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_mean_Ensamble_2011_2040_DELTA <- overlay(HTemp_PRECIS_2011_2040.DELTA.BC.raster,
                                                 HTemp_HadGEM2_2011_2040.DELTA.BC.raster,
                                                 HTemp_MIROC5_2011_2040.DELTA.BC.raster,
                                                 HTemp_EARTH_2011_2040.DELTA.BC.raster,
                                                 HTemp_MPI_2011_2040.DELTA.BC.raster,
                                                 HTemp_CanESM2_2011_2040.DELTA.BC.raster,
                                                 fun=mean)
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_mean_Ensamble_2041_2070_DELTA <- overlay(HTemp_PRECIS_2041_2070.DELTA.BC.raster,
                                                 HTemp_HadGEM2_2041_2070.DELTA.BC.raster,
                                                 HTemp_MIROC5_2041_2070.DELTA.BC.raster,
                                                 HTemp_EARTH_2041_2070.DELTA.BC.raster,
                                                 HTemp_MPI_2041_2070.DELTA.BC.raster,
                                                 HTemp_CanESM2_2041_2070.DELTA.BC.raster,
                                                 fun=mean)
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_mean_Ensamble_2071_2100_DELTA <- overlay(HTemp_PRECIS_2071_2100.DELTA.BC.raster,
                                                 HTemp_HadGEM2_2071_2100.DELTA.BC.raster,
                                                 HTemp_MIROC5_2071_2100.DELTA.BC.raster,
                                                 HTemp_EARTH_2071_2100.DELTA.BC.raster,
                                                 HTemp_MPI_2071_2100.DELTA.BC.raster,
                                                 HTemp_CanESM2_2071_2100.DELTA.BC.raster,
                                                 fun=mean)
  
  # ******************************
  # PTR
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_mean_Ensamble_2011_2040_PTR <- overlay(HTemp_PRECIS_2011_2040.PTR.BC.raster,
                                               HTemp_HadGEM2_2011_2040.PTR.BC.raster,
                                               HTemp_MIROC5_2011_2040.PTR.BC.raster,
                                               HTemp_EARTH_2011_2040.PTR.BC.raster,
                                               HTemp_MPI_2011_2040.PTR.BC.raster,
                                               HTemp_CanESM2_2011_2040.PTR.BC.raster,
                                               fun=mean)
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_mean_Ensamble_2041_2070_PTR <- overlay(HTemp_PRECIS_2041_2070.PTR.BC.raster,
                                               HTemp_HadGEM2_2041_2070.PTR.BC.raster,
                                               HTemp_MIROC5_2041_2070.PTR.BC.raster,
                                               HTemp_EARTH_2041_2070.PTR.BC.raster,
                                               HTemp_MPI_2041_2070.PTR.BC.raster,
                                               HTemp_CanESM2_2041_2070.PTR.BC.raster,
                                               fun=mean)
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_mean_Ensamble_2071_2100_PTR <- overlay(HTemp_PRECIS_2071_2100.PTR.BC.raster,
                                               HTemp_HadGEM2_2071_2100.PTR.BC.raster,
                                               HTemp_MIROC5_2071_2100.PTR.BC.raster,
                                               HTemp_EARTH_2071_2100.PTR.BC.raster,
                                               HTemp_MPI_2071_2100.PTR.BC.raster,
                                               HTemp_CanESM2_2071_2100.PTR.BC.raster,
                                               fun=mean)
  
  # ******************************
  # EQM
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_mean_Ensamble_2011_2040_EQM <- overlay(HTemp_PRECIS_2011_2040.EQM.BC.raster,
                                               HTemp_HadGEM2_2011_2040.EQM.BC.raster,
                                               HTemp_MIROC5_2011_2040.EQM.BC.raster,
                                               HTemp_EARTH_2011_2040.EQM.BC.raster,
                                               HTemp_MPI_2011_2040.EQM.BC.raster,
                                               HTemp_CanESM2_2011_2040.EQM.BC.raster,
                                               fun=mean)
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_mean_Ensamble_2041_2070_EQM <- overlay(HTemp_PRECIS_2041_2070.EQM.BC.raster,
                                               HTemp_HadGEM2_2041_2070.EQM.BC.raster,
                                               HTemp_MIROC5_2041_2070.EQM.BC.raster,
                                               HTemp_EARTH_2041_2070.EQM.BC.raster,
                                               HTemp_MPI_2041_2070.EQM.BC.raster,
                                               HTemp_CanESM2_2041_2070.EQM.BC.raster,
                                               fun=mean)
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_mean_Ensamble_2071_2100_EQM <- overlay(HTemp_PRECIS_2071_2100.EQM.BC.raster,
                                               HTemp_HadGEM2_2071_2100.EQM.BC.raster,
                                               HTemp_MIROC5_2071_2100.EQM.BC.raster,
                                               HTemp_EARTH_2071_2100.EQM.BC.raster,
                                               HTemp_MPI_2071_2100.EQM.BC.raster,
                                               HTemp_CanESM2_2071_2100.EQM.BC.raster,
                                               fun=mean)
  
  # Ensamble sd is calculated. WARNING !!!!! Time Consuming !!!!!
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_sd_Ensamble_2011_2040_DELTA <- overlay(HTemp_PRECIS_2011_2040.DELTA.BC.raster,
                                               HTemp_HadGEM2_2011_2040.DELTA.BC.raster,
                                               HTemp_MIROC5_2011_2040.DELTA.BC.raster,
                                               HTemp_EARTH_2011_2040.DELTA.BC.raster,
                                               HTemp_MPI_2011_2040.DELTA.BC.raster,
                                               HTemp_CanESM2_2011_2040.DELTA.BC.raster,
                                               fun=sd)
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_sd_Ensamble_2041_2070_DELTA <- overlay(HTemp_PRECIS_2041_2070.DELTA.BC.raster,
                                               HTemp_HadGEM2_2041_2070.DELTA.BC.raster,
                                               HTemp_MIROC5_2041_2070.DELTA.BC.raster,
                                               HTemp_EARTH_2041_2070.DELTA.BC.raster,
                                               HTemp_MPI_2041_2070.DELTA.BC.raster,
                                               HTemp_CanESM2_2041_2070.DELTA.BC.raster,
                                               fun=sd)
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_sd_Ensamble_2071_2100_DELTA <- overlay(HTemp_PRECIS_2071_2100.DELTA.BC.raster,
                                               HTemp_HadGEM2_2071_2100.DELTA.BC.raster,
                                               HTemp_MIROC5_2071_2100.DELTA.BC.raster,
                                               HTemp_EARTH_2071_2100.DELTA.BC.raster,
                                               HTemp_MPI_2071_2100.DELTA.BC.raster,
                                               HTemp_CanESM2_2071_2100.DELTA.BC.raster,
                                               fun=sd)
  
  # ******************************
  # PTR
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_sd_Ensamble_2011_2040_PTR <- overlay(HTemp_PRECIS_2011_2040.PTR.BC.raster,
                                             HTemp_HadGEM2_2011_2040.PTR.BC.raster,
                                             HTemp_MIROC5_2011_2040.PTR.BC.raster,
                                             HTemp_EARTH_2011_2040.PTR.BC.raster,
                                             HTemp_MPI_2011_2040.PTR.BC.raster,
                                             HTemp_CanESM2_2011_2040.PTR.BC.raster,
                                             fun=sd)
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_sd_Ensamble_2041_2070_PTR <- overlay(HTemp_PRECIS_2041_2070.PTR.BC.raster,
                                             HTemp_HadGEM2_2041_2070.PTR.BC.raster,
                                             HTemp_MIROC5_2041_2070.PTR.BC.raster,
                                             HTemp_EARTH_2041_2070.PTR.BC.raster,
                                             HTemp_MPI_2041_2070.PTR.BC.raster,
                                             HTemp_CanESM2_2041_2070.PTR.BC.raster,
                                             fun=sd)
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_sd_Ensamble_2071_2100_PTR <- overlay(HTemp_PRECIS_2071_2100.PTR.BC.raster,
                                             HTemp_HadGEM2_2071_2100.PTR.BC.raster,
                                             HTemp_MIROC5_2071_2100.PTR.BC.raster,
                                             HTemp_EARTH_2071_2100.PTR.BC.raster,
                                             HTemp_MPI_2071_2100.PTR.BC.raster,
                                             HTemp_CanESM2_2071_2100.PTR.BC.raster,
                                             fun=sd)
  
  # ******************************
  # EQM
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_sd_Ensamble_2011_2040_EQM <- overlay(HTemp_PRECIS_2011_2040.EQM.BC.raster,
                                             HTemp_HadGEM2_2011_2040.EQM.BC.raster,
                                             HTemp_MIROC5_2011_2040.EQM.BC.raster,
                                             HTemp_EARTH_2011_2040.EQM.BC.raster,
                                             HTemp_MPI_2011_2040.EQM.BC.raster,
                                             HTemp_CanESM2_2011_2040.EQM.BC.raster,
                                             fun=sd)
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_sd_Ensamble_2041_2070_EQM <- overlay(HTemp_PRECIS_2041_2070.EQM.BC.raster,
                                             HTemp_HadGEM2_2041_2070.EQM.BC.raster,
                                             HTemp_MIROC5_2041_2070.EQM.BC.raster,
                                             HTemp_EARTH_2041_2070.EQM.BC.raster,
                                             HTemp_MPI_2041_2070.EQM.BC.raster,
                                             HTemp_CanESM2_2041_2070.EQM.BC.raster,
                                             fun=sd)
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  HTemp_sd_Ensamble_2071_2100_EQM <- overlay(HTemp_PRECIS_2071_2100.EQM.BC.raster,
                                             HTemp_HadGEM2_2071_2100.EQM.BC.raster,
                                             HTemp_MIROC5_2071_2100.EQM.BC.raster,
                                             HTemp_EARTH_2071_2100.EQM.BC.raster,
                                             HTemp_MPI_2071_2100.EQM.BC.raster,
                                             HTemp_CanESM2_2071_2100.EQM.BC.raster,
                                             fun=sd)
  # A simple plot is requested
  plot(HTemp_median_Ensamble_2011_2040_DELTA[[1]])
  plot(HTemp_mean_Ensamble_2011_2040_DELTA[[1]])
  plot(HTemp_sd_Ensamble_2011_2040_DELTA[[1]])
  
  #--------------------------------------------------------------------------------------------------------------------------------------
  # MEAN Rasterstack objects are exported to GeoTIFF format
  #--------------------------------------------------------------------------------------------------------------------------------------
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeRaster(HTemp_PRECIS_2011_2040.DELTA.BC.raster, paste0("PRECIS_2011_2040_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_HadGEM2_2011_2040.DELTA.BC.raster, paste0("HadGEM2_2011_2040_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MIROC5_2011_2040.DELTA.BC.raster, paste0("MIROC5_2011_2040_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_EARTH_2011_2040.DELTA.BC.raster, paste0("EARTH_2011_2040_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MPI_2011_2040.DELTA.BC.raster, paste0("MPI_2011_2040_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_CanESM2_2011_2040.DELTA.BC.raster, paste0("CanESM2_2011_2040_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  # ******************************
  # PTR
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeRaster(HTemp_PRECIS_2011_2040.PTR.BC.raster, paste0("PRECIS_2011_2040_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_HadGEM2_2011_2040.PTR.BC.raster, paste0("HadGEM2_2011_2040_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MIROC5_2011_2040.PTR.BC.raster, paste0("MIROC5_2011_2040_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_EARTH_2011_2040.PTR.BC.raster, paste0("EARTH_2011_2040_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MPI_2011_2040.PTR.BC.raster, paste0("MPI_2011_2040_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_CanESM2_2011_2040.PTR.BC.raster, paste0("CanESM2_2011_2040_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  # ******************************
  # EQM
  # ******************************
  
  # 2011_2040 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeRaster(HTemp_PRECIS_2011_2040.EQM.BC.raster, paste0("PRECIS_2011_2040_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_HadGEM2_2011_2040.EQM.BC.raster, paste0("HadGEM2_2011_2040_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MIROC5_2011_2040.EQM.BC.raster, paste0("MIROC5_2011_2040_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_EARTH_2011_2040.EQM.BC.raster, paste0("EARTH_2011_2040_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MPI_2011_2040.EQM.BC.raster, paste0("MPI_2011_2040_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_CanESM2_2011_2040.EQM.BC.raster, paste0("CanESM2_2011_2040_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeRaster(HTemp_PRECIS_2041_2070.DELTA.BC.raster, paste0("PRECIS_2041_2070_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_HadGEM2_2041_2070.DELTA.BC.raster, paste0("HadGEM2_2041_2070_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MIROC5_2041_2070.DELTA.BC.raster, paste0("MIROC5_2041_2070_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_EARTH_2041_2070.DELTA.BC.raster, paste0("EARTH_2041_2070_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MPI_2041_2070.DELTA.BC.raster, paste0("MPI_2041_2070_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_CanESM2_2041_2070.DELTA.BC.raster, paste0("CanESM2_2041_2070_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  # ******************************
  # PTR
  # ******************************
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeRaster(HTemp_PRECIS_2041_2070.PTR.BC.raster, paste0("PRECIS_2041_2070_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_HadGEM2_2041_2070.PTR.BC.raster, paste0("HadGEM2_2041_2070_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MIROC5_2041_2070.PTR.BC.raster, paste0("MIROC5_2041_2070_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_EARTH_2041_2070.PTR.BC.raster, paste0("EARTH_2041_2070_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MPI_2041_2070.PTR.BC.raster, paste0("MPI_2041_2070_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_CanESM2_2041_2070.PTR.BC.raster, paste0("CanESM2_2041_2070_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  # ******************************
  # EQM
  # ******************************
  
  # 2041_2070 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeRaster(HTemp_PRECIS_2041_2070.EQM.BC.raster, paste0("PRECIS_2041_2070_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_HadGEM2_2041_2070.EQM.BC.raster, paste0("HadGEM2_2041_2070_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MIROC5_2041_2070.EQM.BC.raster, paste0("MIROC5_2041_2070_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_EARTH_2041_2070.EQM.BC.raster, paste0("EARTH_2041_2070_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MPI_2041_2070.EQM.BC.raster, paste0("MPI_2041_2070_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_CanESM2_2041_2070.EQM.BC.raster, paste0("CanESM2_2041_2070_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  
  # ******************************
  # DELTA
  # ******************************
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeRaster(HTemp_PRECIS_2071_2100.DELTA.BC.raster, paste0("PRECIS_2071_2100_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_HadGEM2_2071_2100.DELTA.BC.raster, paste0("HadGEM2_2071_2100_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MIROC5_2071_2100.DELTA.BC.raster, paste0("MIROC5_2071_2100_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_EARTH_2071_2100.DELTA.BC.raster, paste0("EARTH_2071_2100_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MPI_2071_2100.DELTA.BC.raster, paste0("MPI_2071_2100_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_CanESM2_2071_2100.DELTA.BC.raster, paste0("CanESM2_2071_2100_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  # ******************************
  # PTR
  # ******************************
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeRaster(HTemp_PRECIS_2071_2100.PTR.BC.raster, paste0("PRECIS_2071_2100_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_HadGEM2_2071_2100.PTR.BC.raster, paste0("HadGEM2_2071_2100_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MIROC5_2071_2100.PTR.BC.raster, paste0("MIROC5_2071_2100_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_EARTH_2071_2100.PTR.BC.raster, paste0("EARTH_2071_2100_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MPI_2071_2100.PTR.BC.raster, paste0("MPI_2071_2100_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_CanESM2_2071_2100.PTR.BC.raster, paste0("CanESM2_2071_2100_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  # ******************************
  # EQM
  # ******************************
  
  # 2071_2100 period
  #--------------------------------------------------------------------------------------------------------------------------------------
  writeRaster(HTemp_PRECIS_2071_2100.EQM.BC.raster, paste0("PRECIS_2071_2100_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_HadGEM2_2071_2100.EQM.BC.raster, paste0("HadGEM2_2071_2100_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MIROC5_2071_2100.EQM.BC.raster, paste0("MIROC5_2071_2100_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_EARTH_2071_2100.EQM.BC.raster, paste0("EARTH_2071_2100_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_MPI_2071_2100.EQM.BC.raster, paste0("MPI_2071_2100_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  writeRaster(HTemp_CanESM2_2071_2100.EQM.BC.raster, paste0("CanESM2_2071_2100_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE) 
  
  # ******************************
  # DELTA
  # ******************************
  
  writeRaster(HTemp_median_Ensamble_2011_2040_DELTA, paste0("Median_2011_2040_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_median_Ensamble_2041_2070_DELTA, paste0("Median_2041_2070_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_median_Ensamble_2071_2100_DELTA, paste0("Median_2071_2100_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  writeRaster(HTemp_mean_Ensamble_2011_2040_DELTA, paste0("Mean_2011_2040_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_mean_Ensamble_2041_2070_DELTA, paste0("Mean_2041_2070_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_mean_Ensamble_2071_2100_DELTA, paste0("Mean_2071_2100_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  writeRaster(HTemp_sd_Ensamble_2011_2040_DELTA, paste0("SD_2011_2040_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_sd_Ensamble_2041_2070_DELTA, paste0("SD_2041_2070_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_sd_Ensamble_2071_2100_DELTA, paste0("SD_2071_2100_DELTA_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  # ******************************
  # PTR
  # ******************************
  
  writeRaster(HTemp_median_Ensamble_2011_2040_PTR, paste0("Median_2011_2040_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_median_Ensamble_2041_2070_PTR, paste0("Median_2041_2070_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_median_Ensamble_2071_2100_PTR, paste0("Median_2071_2100_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  writeRaster(HTemp_mean_Ensamble_2011_2040_PTR, paste0("Mean_2011_2040_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_mean_Ensamble_2041_2070_PTR, paste0("Mean_2041_2070_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_mean_Ensamble_2071_2100_PTR, paste0("Mean_2071_2100_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  writeRaster(HTemp_sd_Ensamble_2011_2040_PTR, paste0("SD_2011_2040_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_sd_Ensamble_2041_2070_PTR, paste0("SD_2041_2070_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_sd_Ensamble_2071_2100_PTR, paste0("SD_2071_2100_PTR_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  # ******************************
  # EQM
  # ******************************
  
  writeRaster(HTemp_median_Ensamble_2011_2040_EQM, paste0("Median_2011_2040_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_median_Ensamble_2041_2070_EQM, paste0("Median_2041_2070_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_median_Ensamble_2071_2100_EQM, paste0("Median_2071_2100_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  writeRaster(HTemp_mean_Ensamble_2011_2040_EQM, paste0("Mean_2011_2040_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_mean_Ensamble_2041_2070_EQM, paste0("Mean_2041_2070_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_mean_Ensamble_2071_2100_EQM, paste0("Mean_2071_2100_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
  writeRaster(HTemp_sd_Ensamble_2011_2040_EQM, paste0("SD_2011_2040_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_sd_Ensamble_2041_2070_EQM, paste0("SD_2041_2070_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  writeRaster(HTemp_sd_Ensamble_2071_2100_EQM, paste0("SD_2071_2100_EQM_BC_rcp85_",V.select.month[i],".tif"), format="GTiff", overwrite = TRUE)
  
} # Main loop is closed

#--------------------------------------------------------------------------------------------------------------------------------------
# END of code
#--------------------------------------------------------------------------------------------------------------------------------------